@@ -111,7 +111,7 @@ class PdbBreakpoint(Op):
 
             print("\n")
             print("-------------------------------------------------")
-            print("Conditional breakpoint '%s' activated\n" % self.name)
+            print(f"Conditional breakpoint '{self.name}' activated\n")
             print("The monitored variables are stored, in order,")
             print("in the list variable 'monitored' as NumPy arrays.\n")
             print("Their contents can be altered and, when execution")
@@ -145,7 +145,7 @@ class PdbBreakpoint(Op):
     def grad(self, inputs, output_gradients):
         return [DisconnectedType()()] + output_gradients
 
-    def infer_shape(self, inputs, input_shapes):
+    def infer_shape(self, fgraph, inputs, input_shapes):
         # Return the shape of every input but the condition (first input)
         return input_shapes[1:]
 
