@@ -328,7 +328,7 @@ class OpFromGraph(Op):
         **kwargs,
     ):
         if not isinstance(outputs, list):
-            raise TypeError("outputs must be list, got %s" % type(outputs))
+            raise TypeError(f"outputs must be list, got {type(outputs)}")
         for i in inputs + outputs:
             if not isinstance(i, gof.Variable):
                 raise TypeError("inputs and outputs must be Variable instances", i)
@@ -476,8 +476,7 @@ class OpFromGraph(Op):
             goverrides_l = lop_op
             if len(goverrides_l) != inp_len:
                 raise ValueError(
-                    "Need to override %d gradients, got %d"
-                    % (inp_len, len(goverrides_l)),
+                    f"Need to override {int(inp_len)} gradients, got {len(goverrides_l)}",
                     goverrides_l,
                 )
             # compute non-overriding downsteam grads from upstreams grads
@@ -516,7 +515,7 @@ class OpFromGraph(Op):
             if not isinstance(goverrides_l, list):
                 raise TypeError(
                     "Gradient/L_op overriding function should return a list, "
-                    'got "%s"' % type(goverrides_l)
+                    f'got "{type(goverrides_l)}"'
                 )
             all_grads_l, all_grads_ov_l = zip(
                 *[
@@ -527,7 +526,7 @@ class OpFromGraph(Op):
             if len(all_grads_l) != len(local_inputs):
                 raise ValueError(
                     "Gradient/L_op overriding function should return list of "
-                    "%d outputs, got %d" % (inp_len, len(all_grads_l))
+                    f"{int(inp_len)} outputs, got {len(all_grads_l)}"
                 )
         all_grads_l = list(all_grads_l)
         all_grads_ov_l = list(all_grads_ov_l)
@@ -592,7 +591,7 @@ class OpFromGraph(Op):
             roverrides_l = rop_op
             if len(roverrides_l) != out_len:
                 raise ValueError(
-                    "Need to override %d Rop, got %d" % (out_len, len(roverrides_l)),
+                    f"Need to override {int(out_len)} Rop, got {len(roverrides_l)}",
                     roverrides_l,
                 )
             # get outputs that does not have Rop override
@@ -643,8 +642,10 @@ class OpFromGraph(Op):
             )
             if len(all_rops_l) != out_len:
                 raise ValueError(
-                    "Rop overriding function %s should return list of "
-                    "%d outputs, got %d" % (self._rop_op, out_len, len(all_rops_l)),
+                    (
+                        f"Rop overriding function {self._rop_op} should return list of "
+                        f"{int(out_len)} outputs, got {len(all_rops_l)}",
+                    ),
                     rop_op,
                 )
             all_rops_l = list(all_rops_l)
@@ -732,7 +733,7 @@ class OpFromGraph(Op):
         num_expected_inps = len(self.local_inputs) - len(self.shared_inputs)
         if len(inputs) != num_expected_inps:
             raise ValueError(
-                "Expected %d inputs, got %d" % (num_expected_inps, len(inputs))
+                f"Expected {int(num_expected_inps)} inputs, got {len(inputs)}"
             )
         inputs = [
             inp_t.filter_variable(inp) for inp, inp_t in zip(inputs, self.input_types)
@@ -779,7 +780,7 @@ class OpFromGraph(Op):
 
         return list(map(list, cpmat_self))
 
-    def infer_shape(self, node, shapes):
+    def infer_shape(self, fgraph, node, shapes):
 
         out_shp = infer_shape(self.local_outputs, self.local_inputs, shapes)
 
@@ -818,7 +819,7 @@ class OpFromGraph(Op):
 
 
 @local_optimizer([OpFromGraph])
-def inline_ofg_expansion(node):
+def inline_ofg_expansion(fgraph, node):
     """
     This optimization expands internal graph of OpFromGraph.
     Only performed if node.op.is_inline == True
