@@ -13,6 +13,7 @@ import sys
 from io import StringIO
 from itertools import chain
 from itertools import product as itertools_product
+from warnings import warn
 
 import numpy as np
 
@@ -53,11 +54,6 @@ class NoDuplicateOptWarningFilter(logging.Filter):
 _logger.addFilter(NoDuplicateOptWarningFilter())
 
 
-########################
-#
-# Exceptions
-#
-########################
 class DebugModeError(Exception):
     """
     Generic Exception raised to indicate an internal theano problem.
@@ -146,7 +142,7 @@ class BadThunkOutput(DebugModeError):
                 scalar_values.append(ipt)
             else:
                 scalar_values.append("not shown")
-        print("  Inputs values: %s" % scalar_values, file=sio)
+        print(f"  Inputs values: {scalar_values}", file=sio)
         print("  Bad Variable:", self.r, file=sio)
         print("  thunk1  :", self.thunk1, file=sio)
         print("  thunk2  :", self.thunk2, file=sio)
@@ -232,7 +228,7 @@ class BadDestroyMap(DebugModeError):
             )
             print("", file=sio)
         except Exception as e:
-            print("(Numpy-hints failed with: %s)" % str(e), file=sio)
+            print(f"(Numpy-hints failed with: {e})", file=sio)
         print(
             "  Hint: this can also be caused by a deficient "
             "values_eq_approx() or __eq__() implementation "
@@ -344,31 +340,22 @@ class InvalidValueError(DebugModeError):
         hint = self.hint
         specific_hint = self.specific_hint
         context = debugprint(r, prefix="  ", depth=12, file=StringIO()).getvalue()
-        return (
-            """InvalidValueError
-        type(variable) = %(type_r)s
-        variable       = %(r)s
-        type(value)    = %(type_v)s
-        dtype(value)   = %(v_dtype)s
-        shape(value)   = %(v_shape)s
-        value          = %(v_val)s
-        min(value)     = %(v_min)s
-        max(value)     = %(v_max)s
-        isfinite       = %(v_isfinite)s
-        client_node    = %(client_node)s
-        hint           = %(hint)s
-        specific_hint  = %(specific_hint)s
-        context        = ...\n%(context)s
+        return f"""InvalidValueError
+        type(variable) = {type_r}
+        variable       = {r}
+        type(value)    = {type_v}
+        dtype(value)   = {v_dtype}
+        shape(value)   = {v_shape}
+        value          = {v_val}
+        min(value)     = {v_min}
+        max(value)     = {v_max}
+        isfinite       = {v_isfinite}
+        client_node    = {client_node}
+        hint           = {hint}
+        specific_hint  = {specific_hint}
+        context        = ...
+{context}
         """
-            % locals()
-        )
-
-
-########################
-#
-# Private Functions
-#
-########################
 
 
 def str_diagnostic(expected, value, rtol, atol):
@@ -477,7 +464,6 @@ def debugprint(
     scan_inner_to_outer_inputs=None,
     smap=None,
     used_ids=None,
-    print_clients=False,
 ):
     """
     Print the graph leading to `r` to given depth.
@@ -525,8 +511,6 @@ def debugprint(
         Internal. Used to pass information when recursing.
         It is a dict from obj to the id used for it.
         It wasn't always printed, but at least a reference to it was printed.
-    print_clients
-        If True, we will print the clients of nodes when they have more then one clients.
     """
     if depth == 0:
         return
@@ -541,7 +525,7 @@ def debugprint(
         scan_ops = []
 
     if print_type:
-        type_str = " <%s>" % r.type
+        type_str = f" <{r.type}>"
     else:
         type_str = ""
 
@@ -557,11 +541,11 @@ def debugprint(
         elif obj == "output":
             id_str = "output"
         elif ids == "id":
-            id_str = "[id %s]" % str(id(r))
+            id_str = f"[id {id(r)}]"
         elif ids == "int":
-            id_str = "[id %s]" % str(len(used_ids))
+            id_str = f"[id {len(used_ids)}]"
         elif ids == "CHAR":
-            id_str = "[id %s]" % char_from_number(len(used_ids))
+            id_str = f"[id {char_from_number(len(used_ids))}]"
         elif ids == "":
             id_str = ""
         if get_printed:
@@ -604,38 +588,14 @@ def debugprint(
         if len(a.outputs) == 1:
             idx = ""
         else:
-            idx = ".%i" % a.outputs.index(r)
+            idx = f".{a.outputs.index(r)}"
         data = ""
         if smap:
             data = " " + str(smap.get(a.outputs[0], ""))
         clients = ""
-        if print_clients and len(getattr(r, "clients", [])) > 1:
-
-            def get_index(c):
-                try:
-                    return order.index(c)
-                except ValueError:
-                    return ""
-
-            clients = " clients:" + str(
-                [(get_id_str(c, False), get_index(c)) for c, i in r.clients]
-            )
         if profile is None or a not in profile.apply_time:
             print(
-                "%s%s%s %s%s '%s' %s %s %s%s%s"
-                % (
-                    prefix,
-                    a.op,
-                    idx,
-                    id_str,
-                    type_str,
-                    r_name,
-                    destroy_map_str,
-                    view_map_str,
-                    o,
-                    data,
-                    clients,
-                ),
+                f"{prefix}{a.op}{idx} {id_str}{type_str} '{r_name}' {destroy_map_str} {view_map_str} {o}{data}{clients}",
                 file=file,
             )
         else:
@@ -648,7 +608,7 @@ def debugprint(
             if len(a.outputs) == 1:
                 idx = ""
             else:
-                idx = ".%i" % a.outputs.index(r)
+                idx = f".{a.outputs.index(r)}"
             print(
                 "%s%s%s %s%s '%s' %s %s %s%s%s --> "
                 "%8.2es %4.1f%% %8.2es %4.1f%%"
@@ -703,7 +663,6 @@ def debugprint(
                         scan_inner_to_outer_inputs=scan_inner_to_outer_inputs,
                         smap=smap,
                         used_ids=used_ids,
-                        print_clients=print_clients,
                     )
     else:
         if scan_inner_to_outer_inputs is not None and r in scan_inner_to_outer_inputs:
@@ -716,7 +675,7 @@ def debugprint(
             else:
                 outer_id_str = get_id_str(outer_r)
             print(
-                "{}{} {}{} -> {}".format(prefix, r, id_str, type_str, outer_id_str),
+                f"{prefix}{r} {id_str}{type_str} -> {outer_id_str}",
                 file=file,
             )
         else:
@@ -725,7 +684,7 @@ def debugprint(
             if smap:
                 data = " " + str(smap.get(r, ""))
             id_str = get_id_str(r)
-            print("{}{} {}{}{}".format(prefix, r, id_str, type_str, data), file=file)
+            print(f"{prefix}{r} {id_str}{type_str}{data}", file=file)
 
     return file
 
@@ -817,10 +776,8 @@ def _check_inputs(
                 continue
             if out_var is not in_var:
                 _logger.warning(
-                    "Optimization Warning: input idx %d marked "
-                    "as destroyed was not changed for node '%s'",
-                    ii[0],
-                    str(node),
+                    f"Optimization Warning: input idx {int(ii[0])} marked "
+                    f"as destroyed was not changed for node '{node}'"
                 )
 
     vmap = getattr(node.op, "view_map", {})
@@ -846,11 +803,9 @@ def _check_inputs(
                 continue
             if not may_share:
                 _logger.warning(
-                    "Optimization Warning: input idx %d marked "
+                    f"Optimization Warning: input idx {int(ii[0])} marked "
                     "as viewed but new memory allocated by node "
-                    "'%s'",
-                    ii[0],
-                    str(node),
+                    f"'{node}'"
                 )
 
     for r_idx, r in enumerate(node.inputs):
@@ -875,7 +830,7 @@ def _check_inputs(
     return actually_inplace_outputs
 
 
-def _check_viewmap(node, storage_map):
+def _check_viewmap(fgraph, node, storage_map):
     """
     This functions raises a BadViewMap exception when it detects the
     following:
@@ -928,7 +883,7 @@ def _check_viewmap(node, storage_map):
             raise BadViewMap(node, oi, outstorage, list(bad_alias.values()))
 
         # if its not aliased to input, check output->output aliasing
-        if not good_alias and _is_used_in_graph(onode):
+        if not good_alias and _is_used_in_graph(fgraph, onode):
             for other_oi, other_onode in enumerate(node.outputs):
                 if other_oi == oi:
                     continue
@@ -937,14 +892,14 @@ def _check_viewmap(node, storage_map):
                 # check to see if we share memory with this other output
                 # this is not a problem if the node is not actually used
                 if (
-                    _is_used_in_graph(other_onode)
+                    _is_used_in_graph(fgraph, other_onode)
                     and hasattr(other_onode.type, "may_share_memory")
                     and other_onode.type.may_share_memory(outstorage, other_storage)
                 ):
                     raise BadViewMap(node, oi, outstorage, out_alias_idx=other_oi)
 
 
-def _is_used_in_graph(var):
+def _is_used_in_graph(fgraph, var):
     """
 
     Returns
@@ -953,7 +908,7 @@ def _is_used_in_graph(var):
         True if `var` is used by another node in the graph.
 
     """
-    return not (var.clients == [("output", 1)] or var.clients == [])
+    return not (fgraph.clients[var] == [("output", 1)] or fgraph.clients[var] == [])
 
 
 def _check_strides_match(a, b, warn_err, op):
@@ -980,7 +935,7 @@ def _check_strides_match(a, b, warn_err, op):
         if warn_err == 2:
             raise e
         else:
-            print("WARNING:", e, file=sys.stderr)
+            warn(str(e))
 
 
 def _lessbroken_deepcopy(a):
@@ -1307,14 +1262,14 @@ def _get_preallocated_maps(
         out_broadcastable = rev_out_broadcastable[::-1]
 
     if "strided" in prealloc_modes or "ALL" in prealloc_modes:
-        check_ndim = config.DebugMode.check_preallocated_output_ndim
+        check_ndim = config.DebugMode__check_preallocated_output_ndim
         # Initial allocation
         init_strided = {}
         for r in considered_outputs:
             if isinstance(r.type, (TensorType, GpuArrayType)):
                 # Create a buffer twice as large in every dimension,
                 # except if broadcastable, or for dimensions above
-                # config.DebugMode.check_preallocated_output_ndim
+                # config.DebugMode__check_preallocated_output_ndim
                 buf_shape = []
                 for s, b in zip(r_vals[r].shape, r.broadcastable):
                     if b or ((r.ndim - len(buf_shape)) > check_ndim):
@@ -1353,7 +1308,7 @@ def _get_preallocated_maps(
                 steps = [step_signs[0]] * len(out_broadcastable[:-check_ndim])
                 steps += [s * step_size for s in step_signs[1:]]
 
-                name = "strided%s" % str(tuple(steps))
+                name = f"strided{tuple(steps)}"
                 for r in considered_outputs:
                     if r in init_strided:
                         strides = []
@@ -1387,7 +1342,7 @@ def _get_preallocated_maps(
                 shape_diff[dim] = diff
 
                 wrong_size = {}
-                name = "wrong_size%s" % str(tuple(shape_diff))
+                name = f"wrong_size{tuple(shape_diff)}"
 
                 for r in considered_outputs:
                     if isinstance(r.type, (TensorType, GpuArrayType)):
@@ -1406,6 +1361,7 @@ def _get_preallocated_maps(
 
 
 def _check_preallocated_output(
+    fgraph,
     node,
     thunk,
     prealloc_modes,
@@ -1432,7 +1388,7 @@ def _check_preallocated_output(
             fn = getattr(node.op, fn_attr_name, None)
             if not fn or not hasattr(fn, "maker") or not hasattr(fn.maker, "mode"):
                 _logger.warning(
-                    "Expected theano function not found in %s.%s", node.op, fn_attr_name
+                    f"Expected theano function not found in {node.op}.{fn_attr_name}"
                 )
             else:
                 if isinstance(fn.maker.mode, DebugMode):
@@ -1470,13 +1426,13 @@ def _check_preallocated_output(
             inplace_outs,
             init_outputs,
         ):
-            _logger.debug("  name = %s", name)
+            _logger.debug(f"  name = {name}")
 
-            thunk_name = "{} with {} output".format(perform, name)
+            thunk_name = f"{perform} with {name} output"
 
             if not out_map:
                 # Map is empty, there is no need to execute thunk() again
-                _logger.warning("%s: out_map is empty", name)
+                _logger.warning(f"{name}: out_map is empty")
                 continue
 
             # Copy the inputs over, if they were marked as destroyed or viewed
@@ -1513,7 +1469,7 @@ def _check_preallocated_output(
                 warn_input_not_reused=False,
             )
 
-            _check_viewmap(node, storage_map)
+            _check_viewmap(fgraph, node, storage_map)
 
             for r in node.outputs:
                 if not check_eq(r, r_vals[r], storage_map[r][0]):
@@ -1899,8 +1855,7 @@ class _Linker(gof.link.LocalLinker):
 
             if not self.maker.mode.check_c_code and thunks_py[-1] is None:
                 _logger.warning(
-                    "Op %s doesn't have a perform, "
-                    "forcing check of the C code" % node.op
+                    f"Op {node.op} doesn't have a perform, forcing check of the C code"
                 )
                 node.op.prepare_node(node, storage_map, compute_map, "c")
                 thunk = node.op.make_c_thunk(
@@ -1917,8 +1872,8 @@ class _Linker(gof.link.LocalLinker):
                 else:
                     _logger.warning(
                         "We won't check the perform function "
-                        "of node '%s' but we will check its "
-                        "make_thunk function" % node
+                        f"of node '{node}' but we will check its "
+                        "make_thunk function"
                     )
                     thunks_py[-1] = thunk_other
 
@@ -1934,7 +1889,7 @@ class _Linker(gof.link.LocalLinker):
             ]
 
         # Precompute some things for storage pre-allocation
-        def_val = int(config.unittests.rseed)
+        def_val = int(config.unittests__rseed)
 
         #####
         # This is the function that runs when you evaluate the graph
@@ -1947,8 +1902,7 @@ class _Linker(gof.link.LocalLinker):
             #####
             _logger.debug("starting a DebugMode call")
             _logger.debug(
-                "self.maker.mode.check_preallocated_output: %s",
-                self.maker.mode.check_preallocated_output,
+                f"self.maker.mode.check_preallocated_output: {self.maker.mode.check_preallocated_output}"
             )
             for x in no_recycling_map:
                 x[0] = None
@@ -1988,14 +1942,14 @@ class _Linker(gof.link.LocalLinker):
                                 raise InvalidValueError(
                                     r,
                                     storage_map[r][0],
-                                    hint=("Graph Input '%s' is missing" % str(r)),
+                                    hint=f"Graph Input '{r}' is missing",
                                 )
                             raise InvalidValueError(
                                 r,
                                 storage_map[r][0],
                                 hint=(
-                                    "Graph Input '%s' has invalid value "
-                                    "%s" % (r, storage_map[r][0])
+                                    f"Graph Input '{r}' has invalid value "
+                                    f"{storage_map[r][0]}"
                                 ),
                             )
                         r_vals[r] = storage_map[r][0]
@@ -2025,7 +1979,7 @@ class _Linker(gof.link.LocalLinker):
                 for i, (thunk_py, thunk_c, node) in enumerate(
                     zip(thunks_py, thunks_c, order)
                 ):
-                    _logger.debug("%i - starting node %i %s", i, i, node)
+                    _logger.debug(f"{i} - starting node {i} {node}")
 
                     # put a copy of each input into the storage_map
                     # also, check that inputs have valid values
@@ -2042,7 +1996,7 @@ class _Linker(gof.link.LocalLinker):
                     # storage will be None
                     if thunk_py:
                         _logger.debug(
-                            "%i - running thunk_py with None as " "output storage", i
+                            f"{i} - running thunk_py with None as " "output storage"
                         )
                         try:
                             thunk_py()
@@ -2061,8 +2015,8 @@ class _Linker(gof.link.LocalLinker):
                                 raise
                             opt = str(reason[0][0])
                             msg = (
-                                "An optimization (probably %s) inserted an "
-                                "apply node that raise an error." % opt
+                                f"An optimization (probably {opt}) inserted an "
+                                "apply node that raise an error."
                                 + "\nThe information we have about this "
                                 "optimizations is:"
                                 + str(reason[0][1])
@@ -2075,7 +2029,7 @@ class _Linker(gof.link.LocalLinker):
                             exc_type, exc_value, exc_trace = sys.exc_info()
                             exc_value = new_e
                             raise_with_op(
-                                node, thunk_c, (exc_type, exc_value, exc_trace)
+                                fgraph, node, thunk_c, (exc_type, exc_value, exc_trace)
                             )
 
                     if thunk_py:
@@ -2089,7 +2043,7 @@ class _Linker(gof.link.LocalLinker):
                                     hint="perform output",
                                     specific_hint=hint2,
                                 )
-                        warn_inp = config.DebugMode.warn_input_not_reused
+                        warn_inp = config.DebugMode__warn_input_not_reused
                         py_inplace_outs = _check_inputs(
                             node,
                             storage_map,
@@ -2100,7 +2054,7 @@ class _Linker(gof.link.LocalLinker):
                             perform="py",
                             warn_input_not_reused=warn_inp,
                         )
-                        _check_viewmap(node, storage_map)
+                        _check_viewmap(fgraph, node, storage_map)
 
                         # Retrieve each output from the storage_map.
                         # The return values of this first run will be
@@ -2114,11 +2068,11 @@ class _Linker(gof.link.LocalLinker):
                         if self.maker.mode.check_preallocated_output:
                             prealloc_modes = self.maker.mode.check_preallocated_output
                             _logger.debug(
-                                "%i - calling _check_preallocated_output "
-                                "with thunk_py",
-                                i,
+                                f"{i} - calling _check_preallocated_output "
+                                "with thunk_py"
                             )
                             _check_preallocated_output(
+                                fgraph=fgraph,
                                 node=node,
                                 thunk=thunk_py,
                                 prealloc_modes=prealloc_modes,
@@ -2160,7 +2114,7 @@ class _Linker(gof.link.LocalLinker):
 
                             clobber = False
 
-                        _logger.debug("%i - running thunk_c", i)
+                        _logger.debug(f"{i} - running thunk_c")
                         # First time, with None in output_storage
                         try:
                             thunk_c()
@@ -2174,8 +2128,8 @@ class _Linker(gof.link.LocalLinker):
                                 raise
                             opt = str(reason[0][0])
                             msg = (
-                                "An optimization (probably %s) inserted "
-                                "an apply node that raise an error." % opt
+                                f"An optimization (probably {opt}) inserted "
+                                "an apply node that raise an error."
                                 + "\nThe information we have about this "
                                 "optimizations is:"
                                 + str(reason[0][1])
@@ -2188,7 +2142,7 @@ class _Linker(gof.link.LocalLinker):
                             exc_type, exc_value, exc_trace = sys.exc_info()
                             exc_value = new_e
                             raise_with_op(
-                                node, thunk_c, (exc_type, exc_value, exc_trace)
+                                fgraph, node, thunk_c, (exc_type, exc_value, exc_trace)
                             )
 
                         for r in node.outputs:
@@ -2211,7 +2165,7 @@ class _Linker(gof.link.LocalLinker):
                                     node.op,
                                 )
 
-                        warn_inp = config.DebugMode.warn_input_not_reused
+                        warn_inp = config.DebugMode__warn_input_not_reused
                         c_inplace_outs = _check_inputs(
                             node,
                             storage_map,
@@ -2223,7 +2177,7 @@ class _Linker(gof.link.LocalLinker):
                             warn_input_not_reused=warn_inp,
                         )
 
-                        _check_viewmap(node, storage_map)
+                        _check_viewmap(fgraph, node, storage_map)
 
                         # Check with Python result
                         for r in node.outputs:
@@ -2256,14 +2210,14 @@ class _Linker(gof.link.LocalLinker):
                                 try:
                                     thunk_c()
                                 except Exception:
-                                    raise_with_op(node, thunk_c)
+                                    raise_with_op(fgraph, node, thunk_c)
 
                             _logger.debug(
-                                "%i - calling _check_preallocated_output "
+                                f"{i} - calling _check_preallocated_output "
                                 "with thunk_c",
-                                i,
                             )
                             _check_preallocated_output(
+                                fgraph=fgraph,
                                 node=node,
                                 thunk=thunk,
                                 prealloc_modes=prealloc_modes,
@@ -2283,13 +2237,13 @@ class _Linker(gof.link.LocalLinker):
                     # clear everything out of the storage_map
                     for r in node.inputs:
                         storage_map[r][0] = None
-                    _logger.debug("%i - done with node", i)
+                    _logger.debug(f"{i} - done with node")
                     for r in node.outputs:
                         if r not in r_vals:
                             idx = order.index(node)
                             assert thunks_py[idx] is None, node
                             assert thunks_c[idx] is None, node
-                            raise Exception("No code run for %s" % node)
+                            raise Exception(f"No code run for {node}")
 
                 if False:
                     # This could be useful to help finding refcount problem.
@@ -2506,7 +2460,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
                 l0 = fgraph0.equivalence_tracker.event_list
                 if li != l0:
                     infolog = StringIO()
-                    print("WARNING: Optimization process is unstable...", file=infolog)
+                    print("Optimization process is unstable...", file=infolog)
                     print(
                         "  (HINT: Ops that the nodes point to must compare " "equal)",
                         file=infolog,
@@ -2567,9 +2521,9 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
                             o, _output_guard(o), reason="output_guard"
                         )
                     raise Exception(
-                        "Output variable %s required output_guard, "
+                        f"Output variable {o} required output_guard, "
                         "how was this output left unprotected against "
-                        "destructive operations?" % o
+                        "destructive operations?"
                     )
 
                 except gof.InconsistencyError:
@@ -2617,13 +2571,6 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
         ]
 
 
-########################
-#
-# API symbol: DebugMode
-#
-########################
-
-
 class DebugMode(Mode):
     """
     Evaluation Mode that detects internal theano errors.
@@ -2663,33 +2610,33 @@ class DebugMode(Mode):
 
     """
 
-    stability_patience = config.DebugMode.patience
+    stability_patience = config.DebugMode__patience
     """
     When checking for the stability of optimization, recompile the
     graph this many times.
 
     """
 
-    check_c_code = config.DebugMode.check_c
+    check_c_code = config.DebugMode__check_c
     """
     Should we evaluate (and check) the `c_code` implementations?
 
     """
 
-    check_py_code = config.DebugMode.check_py
+    check_py_code = config.DebugMode__check_py
     """
     Should we evaluate (and check) the `perform` implementations?
     Always checked if no `c_code`.
 
     """
 
-    check_isfinite = config.DebugMode.check_finite
+    check_isfinite = config.DebugMode__check_finite
     """
     Should we check for (and complain about) NaN/Inf ndarray elements?
 
     """
 
-    require_matching_strides = config.DebugMode.check_strides
+    require_matching_strides = config.DebugMode__check_strides
     """
     Should we check for (and complain about) Ops whose python and C
     outputs are ndarrays with different strides? (This can catch bugs,
@@ -2697,7 +2644,7 @@ class DebugMode(Mode):
 
     """
 
-    check_preallocated_output = config.DebugMode.check_preallocated_output
+    check_preallocated_output = config.DebugMode__check_preallocated_output
     check_preallocated_output = check_preallocated_output.split(":")
     """
     List of strings representing ways to pre-allocate output memory in
