@@ -58,14 +58,14 @@ def alias_root(v):
         return v
 
 
-def view_tree_set(v, treeset):
+def view_tree_set(fgraph, v, treeset):
     """
     Add to `treeset` all variables that are views of v, given that v is
     not a view.
 
     """
     treeset.add(v)
-    for cl, v_input_pos_to_cl in v.clients:
+    for cl, v_input_pos_to_cl in fgraph.clients[v]:
         if cl == "output":
             continue
         vmap = getattr(cl.op, "view_map", {})
@@ -73,7 +73,7 @@ def view_tree_set(v, treeset):
         for opos, iposlist in chain(vmap.items(), dmap.items()):
             if v_input_pos_to_cl in iposlist:
                 if cl.outputs[opos] not in treeset:
-                    view_tree_set(cl.outputs[opos], treeset)
+                    view_tree_set(fgraph, cl.outputs[opos], treeset)
 
 
 def infer_reuse_pattern(fgraph, outputs_to_disown):
@@ -89,7 +89,7 @@ def infer_reuse_pattern(fgraph, outputs_to_disown):
     """
     rval = set()
     for o in outputs_to_disown:
-        view_tree_set(alias_root(o), rval)
+        view_tree_set(fgraph, alias_root(o), rval)
     # remove from rval all of the inputs, constants, values.
     rval = {r for r in rval if r.owner is not None}
 
@@ -478,12 +478,12 @@ class Function:
                 try:
                     s = finder[item]
                 except KeyError:
-                    raise TypeError("Unknown input or state: %s" % str(item))
+                    raise TypeError(f"Unknown input or state: {item}")
                 if s is DUPLICATE:
                     raise TypeError(
-                        "Ambiguous name: %s - please check the "
+                        f"Ambiguous name: {item} - please check the "
                         "names of the inputs of your function "
-                        "for duplicates." % str(item)
+                        "for duplicates."
                     )
                 if isinstance(s, gof.Container):
                     return s.value
@@ -496,14 +496,12 @@ class Function:
                 except KeyError:
                     # Print informative error message.
                     msg = get_info_on_inputs(named_inputs, n_unnamed_inputs)
-                    raise TypeError(
-                        "Unknown input or state: {}. {}".format(str(item), msg)
-                    )
+                    raise TypeError(f"Unknown input or state: {item}. {msg}")
                 if s is DUPLICATE:
                     raise TypeError(
-                        "Ambiguous name: %s - please check the "
+                        f"Ambiguous name: {item} - please check the "
                         "names of the inputs of your function "
-                        "for duplicates." % str(item)
+                        "for duplicates."
                     )
                 if isinstance(s, gof.Container):
                     s.value = value
@@ -664,7 +662,7 @@ class Function:
             # Check if given ShareVariables exist
             for sv in swap.keys():
                 if sv not in exist_svs:
-                    raise ValueError("SharedVariable: %s not found" % (sv.name))
+                    raise ValueError(f"SharedVariable: {sv.name} not found")
 
             # Swap SharedVariable in fgraph and In instances
             for index, (i, in_v) in enumerate(zip(ins, fg_cpy.inputs)):
@@ -871,7 +869,7 @@ class Function:
                                 + argument_name
                                 + " to "
                                 + function_name
-                                + " at index %d (0-based). %s" % (i, where)
+                                + f" at index {int(i)} (0-based). {where}"
                                 + e.args[0],
                             )
                         else:
@@ -880,7 +878,7 @@ class Function:
                                 + argument_name
                                 + " to "
                                 + function_name
-                                + " at index %d (0-based). %s" % (i, where),
+                                + f" at index {int(i)} (0-based). {where}"
                             ) + e.args
                         restore_defaults()
                         raise
@@ -950,20 +948,17 @@ class Function:
                 if c.required and not c.provided:
                     restore_defaults()
                     raise TypeError(
-                        "Missing required input: %s"
-                        % getattr(self.inv_finder[c], "variable", self.inv_finder[c])
+                        f"Missing required input: {getattr(self.inv_finder[c], 'variable', self.inv_finder[c])}"
                     )
                 if c.provided > 1:
                     restore_defaults()
                     raise TypeError(
-                        "Multiple values for input: %s"
-                        % getattr(self.inv_finder[c], "variable", self.inv_finder[c])
+                        f"Multiple values for input: {getattr(self.inv_finder[c], 'variable', self.inv_finder[c])}"
                     )
                 if c.implicit and c.provided > 0:
                     restore_defaults()
                     raise TypeError(
-                        "Tried to provide value for implicit input: %s"
-                        % getattr(self.inv_finder[c], "variable", self.inv_finder[c])
+                        f"Tried to provide value for implicit input: {getattr(self.inv_finder[c], 'variable', self.inv_finder[c])}"
                     )
 
         # Do the actual work
@@ -984,6 +979,7 @@ class Function:
                 if hasattr(self.fn, "thunks"):
                     thunk = self.fn.thunks[self.fn.position_of_error]
                 gof.link.raise_with_op(
+                    self.maker.fgraph,
                     node=self.fn.nodes[self.fn.position_of_error],
                     thunk=thunk,
                     storage_map=getattr(self.fn, "storage_map", None),
@@ -1143,9 +1139,9 @@ def _pickle_Function(f):
                         if f.pickle_aliased_memory_strategy == "warn":
                             _logger.warning(
                                 "aliased relationship between "
-                                "Function arguments %s, %s "
+                                f"Function arguments {d_i}, {d_j} "
                                 "will not be preserved by "
-                                "un-pickling operation" % (str(d_i), str(d_j))
+                                "un-pickling operation"
                             )
                         else:
                             raise AliasedMemoryError(d_i, d_j)
@@ -1210,7 +1206,7 @@ def insert_deepcopy(fgraph, wrapped_inputs, wrapped_outputs):
 
     for i in range(len(fgraph.outputs)):
         views_of_output_i = set()
-        view_tree_set(alias_root(fgraph.outputs[i]), views_of_output_i)
+        view_tree_set(fgraph, alias_root(fgraph.outputs[i]), views_of_output_i)
         copied = False
         # do not allow outputs to be aliased
         for j in range(i + 1, len(fgraph.outputs)):
@@ -1331,9 +1327,8 @@ class FunctionMaker:
                 raise TypeError("Expected two elements in the list or tuple.", input)
         else:
             raise TypeError(
-                "Unknown input type: %s (%s), expected Variable " "instance",
-                type(input),
-                input,
+                f"Unknown input type: {type(input)} ({input}), expected Variable "
+                "instance"
             )
 
     @staticmethod
@@ -1357,7 +1352,7 @@ class FunctionMaker:
         elif isinstance(output, gof.Variable):
             return SymbolicOutput(output)
         else:
-            raise TypeError("Unknown output type: %s (%s)", type(output), output)
+            raise TypeError(f"Unknown output type: {type(output)} ({output})")
 
     def optimize_graph_with_cache(self, optimizer, inputs, outputs):
         # This function is not finished
@@ -1381,7 +1376,7 @@ class FunctionMaker:
             else:
                 # create graph_db
                 with open(graph_db_file, "wb") as f:
-                    print("create new graph_db in %s" % graph_db_file)
+                    print(f"create new graph_db in {graph_db_file}")
             # load the graph_db dictionary
             try:
                 with open(graph_db_file, "rb") as f:
@@ -1459,28 +1454,6 @@ class FunctionMaker:
                         t1 = output_new
                         t2 = f2.outputs[i]
 
-                        # Used to remove "already used by another graph error
-                        def removeAllFgraph(remove):
-                            if hasattr(remove, "fgraph"):
-                                del remove.fgraph
-                            if hasattr(remove, "owner"):
-                                if remove.owner is None:
-                                    pass
-                                else:
-                                    if hasattr(remove.owner, "fgraph"):
-                                        del remove.owner.fgraph
-                                    if hasattr(remove.owner, "inputs"):
-                                        remove.owner.inputs = [
-                                            removeAllFgraph(i)
-                                            for i in remove.owner.inputs
-                                        ]
-                                        for o in remove.owner.outputs:
-                                            if hasattr(o, "fgraph"):
-                                                del o.fgraph
-                            return remove
-
-                        t2 = removeAllFgraph(t2)
-
                         givens = dict(
                             zip(gof.graph.inputs([t1]), gof.graph.inputs([t2]))
                         )
@@ -1507,7 +1480,7 @@ class FunctionMaker:
             return found_graph_in_db
 
         graph_db = load_graph_db()
-        print("loaded graph_db from %s, size=%d" % (graph_db_file, len(graph_db)))
+        print(f"loaded graph_db from {graph_db_file}, size={len(graph_db)}")
         found_graph = find_same_graph_in_db(graph_db)
         if found_graph:
             self.fgraph = found_graph
@@ -1611,12 +1584,12 @@ class FunctionMaker:
         optimizer, linker = mode.optimizer, copy.copy(mode.linker)
         if need_opt:
             compute_test_value_orig = theano.config.compute_test_value
-            limit_orig = theano.config.traceback.limit
+            limit_orig = theano.config.traceback__limit
             # Why we add stack on node when it get done in output var?
             try:
                 # optimize the fgraph
                 theano.config.compute_test_value = theano.config.compute_test_value_opt
-                theano.config.traceback.limit = theano.config.traceback.compile_limit
+                theano.config.traceback__limit = theano.config.traceback__compile_limit
                 start_optimizer = time.time()
 
                 # In case there is an error during optimization.
@@ -1633,13 +1606,13 @@ class FunctionMaker:
 
                 end_optimizer = time.time()
                 opt_time = end_optimizer - start_optimizer
-                _logger.debug("Optimizing took %f seconds", opt_time)
+                _logger.debug(f"Optimizing took {opt_time:f} seconds")
 
                 # Add deep copy to respect the memory interface
                 insert_deepcopy(fgraph, inputs, outputs + additional_outputs)
             finally:
                 theano.config.compute_test_value = compute_test_value_orig
-                theano.config.traceback.limit = limit_orig
+                theano.config.traceback__limit = limit_orig
 
                 # If the optimizer got interrupted
                 if opt_time is None:
@@ -1666,8 +1639,7 @@ class FunctionMaker:
         if not hasattr(linker, "accept"):
             raise ValueError(
                 "'linker' parameter of FunctionMaker should be "
-                "a Linker with an accept method or one of %s"
-                % list(theano.compile.mode.predefined_linkers.keys())
+                f"a Linker with an accept method or one of {list(theano.compile.mode.predefined_linkers.keys())}"
             )
 
         # the 'no_borrow' outputs are the ones for which that we can't
@@ -1844,20 +1816,20 @@ class FunctionMaker:
         # Get a function instance
         start_linker = time.time()
         start_import_time = theano.gof.cmodule.import_time
-        limit_orig = theano.config.traceback.limit
+        limit_orig = theano.config.traceback__limit
         try:
-            theano.config.traceback.limit = theano.config.traceback.compile_limit
+            theano.config.traceback__limit = theano.config.traceback__compile_limit
             _fn, _i, _o = self.linker.make_thunk(
                 input_storage=input_storage_lists, storage_map=storage_map
             )
         finally:
-            theano.config.traceback.limit = limit_orig
+            theano.config.traceback__limit = limit_orig
 
         end_linker = time.time()
 
         linker_time = end_linker - start_linker
         theano.compile.profiling.total_time_linker += linker_time
-        _logger.debug("Linker took %f seconds", linker_time)
+        _logger.debug(f"Linker took {linker_time:f} seconds")
         if self.profile:
             self.profile.linker_time += linker_time
             _fn.time_thunks = self.profile.flag_time_thunks
@@ -2035,7 +2007,7 @@ def convert_function_input(input):
     elif isinstance(input, (list, tuple)):
         orig = input
         if not input:
-            raise TypeError("Nonsensical input specification: %s" % input)
+            raise TypeError(f"Nonsensical input specification: {input}")
         if isinstance(input[0], str):
             name = input[0]
             input = input[1:]
@@ -2044,8 +2016,8 @@ def convert_function_input(input):
         if isinstance(input[0], (list, tuple)):
             if len(input[0]) != 2 or len(input) != 2:
                 raise TypeError(
-                    "Invalid input syntax: %s (check "
-                    "documentation or use an In instance)" % orig
+                    f"Invalid input syntax: {orig} (check "
+                    "documentation or use an In instance)"
                 )
             (variable, update), value = input
         elif isinstance(input[0], gof.Variable):
@@ -2055,8 +2027,8 @@ def convert_function_input(input):
                 (variable, value), update = input, None
             else:
                 raise TypeError(
-                    "Invalid input syntax: %s (check "
-                    "documentation or use an In instance)" % orig
+                    f"Invalid input syntax: {orig} (check "
+                    "documentation or use an In instance)"
                 )
         elif isinstance(input[0], SymbolicInput):
             if len(input) == 1:
@@ -2068,29 +2040,28 @@ def convert_function_input(input):
                 input.value = value
                 return input
         else:
-            raise TypeError("The input specification is not valid: %s" % input)
+            raise TypeError(f"The input specification is not valid: {input}")
 
         if not isinstance(variable, gof.Variable):
             raise TypeError(
-                "Unknown input type: %s, expected Variable "
-                "instance" % type(variable),
+                f"Unknown input type: {type(variable)}, expected Variable instance",
                 variable,
             )
         if update is not None and not isinstance(update, gof.Variable):
             raise TypeError(
-                "Unknown update type: %s, expected Variable " "instance" % type(update),
+                f"Unknown update type: {type(update)}, expected Variable instance",
                 update,
             )
         if value is not None and isinstance(value, (gof.Variable, SymbolicInput)):
             raise TypeError(
-                "The value for input %s should not be a Variable "
-                "or SymbolicInput instance (got: %s)" % (variable, value)
+                f"The value for input {variable} should not be a Variable "
+                f"or SymbolicInput instance (got: {value})"
             )
 
         return In(variable, name=name, value=value, update=update)
     else:
         raise TypeError(
-            "Unknown input type: %s, expected Variable instance" % type(input), input
+            f"Unknown input type: {type(input)}, expected Variable instance", input
         )
 
 
@@ -2121,10 +2092,10 @@ def get_info_on_inputs(named_inputs, n_unnamed_inputs):
             else:
                 # Use plural.
                 msg = (
-                    "The function has %s inputs, but none of them is named,"
+                    f"The function has {n_unnamed_inputs} inputs, but none of them is named,"
                     " and thus they cannot be assigned through keyword "
                     "arguments (use 'name=...' in a Variable's "
-                    "constructor to give it a name)." % n_unnamed_inputs
+                    "constructor to give it a name)."
                 )
     else:
         if n_unnamed_inputs == 0:
@@ -2135,17 +2106,9 @@ def get_info_on_inputs(named_inputs, n_unnamed_inputs):
             )
         else:
             msg = (
-                "The function has %s named input%s (%s), and %s unnamed "
-                "input%s which thus cannot be accessed through keyword "
-                "argument%s (use 'name=...' in a variable's constructor "
+                f"The function has {n_named_inputs} named input{get_plural(n_named_inputs)} ({', '.join(named_inputs)}), and {n_unnamed_inputs} unnamed "
+                f"input{get_plural(n_unnamed_inputs)} which thus cannot be accessed through keyword "
+                f"argument{get_plural(n_unnamed_inputs)} (use 'name=...' in a variable's constructor "
                 "to give it a name)."
-                % (
-                    n_named_inputs,
-                    get_plural(n_named_inputs),
-                    ", ".join(named_inputs),
-                    n_unnamed_inputs,
-                    get_plural(n_unnamed_inputs),
-                    get_plural(n_unnamed_inputs),
-                )
             )
     return msg
