@@ -7,8 +7,7 @@ from theano.compile.mode import Mode
 
 
 class MonitorMode(Mode):
-    """
-    `MonitorMode` is a debug mode to easily step through function execution.
+    """A debug mode that facilitates stepping through function execution.
 
     Its default behavior is to behave like the 'FAST_RUN' mode. By providing
     either a `pre_func` (called before a node is executed) or a `post_func`
@@ -22,12 +21,13 @@ class MonitorMode(Mode):
     ----------
     pre_func
         A function to call before executing a thunk, with arguments:
+        - the `FunctionGraph`
         - the thunk index
-        - the Apply node
+        - the `Apply` node
         - the thunk to be called
     post_func
-        A function to call after executing a thunk, with the same three
-        arguments as `pre_func`.
+        A function to call after executing a thunk, with the same arguments as
+        `pre_func`.
     optimizer
         The optimizer to use. One may use for instance 'fast_compile' to skip
         optimizations.
@@ -64,16 +64,16 @@ class MonitorMode(Mode):
         self.post_func = post_func
         super().__setstate__((lnk, opt))
 
-    def eval(self, i, node, fn):
+    def eval(self, fgraph, i, node, fn):
         """
         The method that calls the thunk `fn`.
 
         """
         if self.pre_func is not None:
-            self.pre_func(i, node, fn)
+            self.pre_func(fgraph, i, node, fn)
         fn()
         if self.post_func is not None:
-            self.post_func(i, node, fn)
+            self.post_func(fgraph, i, node, fn)
 
     def clone(self, link_kwargs=None, optimizer="", **kwargs):
         """
@@ -94,7 +94,7 @@ class MonitorMode(Mode):
         return new_mode
 
 
-def detect_nan(i, node, fn):
+def detect_nan(fgraph, i, node, fn):
     for output in fn.outputs:
         if (
             not isinstance(output[0], np.random.RandomState)
