@@ -52,12 +52,12 @@ def _atexit_print_fn():
     if config.profile:
         to_sum = []
 
-        if config.profiling.destination == "stderr":
+        if config.profiling__destination == "stderr":
             destination_file = sys.stderr
-        elif config.profiling.destination == "stdout":
+        elif config.profiling__destination == "stdout":
             destination_file = sys.stdout
         else:
-            destination_file = open(config.profiling.destination, "w")
+            destination_file = open(config.profiling__destination, "w")
 
         # Reverse sort in the order of compile+exec time
         for ps in sorted(
@@ -70,8 +70,8 @@ def _atexit_print_fn():
             ):
                 ps.summary(
                     file=destination_file,
-                    n_ops_to_print=config.profiling.n_ops,
-                    n_apply_to_print=config.profiling.n_apply,
+                    n_ops_to_print=config.profiling__n_ops,
+                    n_apply_to_print=config.profiling__n_apply,
                 )
                 if not isinstance(ps, ScanProfileStats):
                     to_sum.append(ps)
@@ -82,8 +82,8 @@ def _atexit_print_fn():
             # Make a global profile
             cum = copy.copy(to_sum[0])
             msg = (
-                "Sum of all(%d) printed profiles at exit excluding Scan op"
-                " profile." % len(to_sum)
+                f"Sum of all({len(to_sum)}) printed profiles at exit excluding Scan op"
+                " profile."
             )
             cum.message = msg
             for ps in to_sum[1:]:
@@ -130,8 +130,8 @@ def _atexit_print_fn():
 
             cum.summary(
                 file=destination_file,
-                n_ops_to_print=config.profiling.n_ops,
-                n_apply_to_print=config.profiling.n_apply,
+                n_ops_to_print=config.profiling__n_ops,
+                n_apply_to_print=config.profiling__n_apply,
             )
 
     if config.print_global_stats:
@@ -148,25 +148,21 @@ def print_global_stats():
            -- on linker
     """
 
-    if config.profiling.destination == "stderr":
+    if config.profiling__destination == "stderr":
         destination_file = sys.stderr
-    elif config.profiling.destination == "stdout":
+    elif config.profiling__destination == "stdout":
         destination_file = sys.stdout
     else:
-        destination_file = open(config.profiling.destination, "w")
+        destination_file = open(config.profiling__destination, "w")
 
     print("=" * 50, file=destination_file)
     print(
-        "Global stats: ",
-        "Time elasped since Theano import = %6.3fs, "
-        "Time spent in Theano functions = %6.3fs, "
-        "Time spent compiling Theano functions: "
-        " optimzation = %6.3fs, linker = %6.3fs "
-        % (
-            time.time() - theano_imported_time,
-            total_fct_exec_time,
-            total_graph_opt_time,
-            total_time_linker,
+        (
+            "Global stats: ",
+            f"Time elasped since Theano import = {time.time() - theano_imported_time:6.3f}s, "
+            f"Time spent in Theano functions = {total_fct_exec_time:6.3f}s, "
+            "Time spent compiling Theano functions: "
+            f" optimization = {total_graph_opt_time:6.3f}s, linker = {total_time_linker:6.3f}s ",
         ),
         file=destination_file,
     )
@@ -234,11 +230,11 @@ class ProfileStats:
     #
 
     apply_time = None
-    # dict from node -> float runtime
+    # dict from `(FunctionGraph, Variable)` to float runtime
     #
 
     apply_callcount = None
-    # dict from node -> number of executions
+    # dict from `(FunctionGraph, Variable)` to number of executions
     #
 
     apply_cimpl = None
@@ -279,12 +275,12 @@ class ProfileStats:
 
     linker_make_thunk_time = {}
 
-    line_width = config.profiling.output_line_width
+    line_width = config.profiling__output_line_width
 
     nb_nodes = -1
-    # The number of nodes in the graph. We need the infomartion
-    # separatly in case we print the profile when the function wasn't
-    # executed or if there is lazy operation in the graph.
+    # The number of nodes in the graph. We need the information separately in
+    # case we print the profile when the function wasn't executed, or if there
+    # is a lazy operation in the graph.
 
     optimizer_profile = None
     # None or tuple (the optimizer, the profile it returned)
@@ -317,23 +313,24 @@ class ProfileStats:
             and gpu_checks
             and hasattr(theano, "gpuarray")
             and theano.gpuarray.pygpu_activated
-            and not config.profiling.ignore_first_call
+            and not config.profiling__ignore_first_call
         ):
             warnings.warn(
-                "Theano flag profiling.ignore_first_call is False. "
+                "Theano flag profiling__ignore_first_call is False. "
                 "This cause bad profiling result in the gpu "
                 "back-end, as sometimes we compile at the first call."
             )
 
         self.apply_callcount = {}
         self.output_size = {}
+        # Keys are `(FunctionGraph, Variable)`
         self.apply_time = {}
         self.apply_cimpl = {}
         self.variable_shape = {}
         self.variable_strides = {}
         self.variable_offset = {}
         if flag_time_thunks is None:
-            self.flag_time_thunks = config.profiling.time_thunks
+            self.flag_time_thunks = config.profiling__time_thunks
         else:
             self.flag_time_thunks = flag_time_thunks
         self.__dict__.update(kwargs)
@@ -344,7 +341,7 @@ class ProfileStats:
             if not _atexit_registered:
                 atexit.register(_atexit_print_fn)
                 _atexit_registered = True
-        self.ignore_first_call = theano.config.profiling.ignore_first_call
+        self.ignore_first_call = theano.config.profiling__ignore_first_call
 
     def class_time(self):
         """
@@ -353,7 +350,7 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by class on demand
         rval = {}
-        for node, t in self.apply_time.items():
+        for (fgraph, node), t in self.apply_time.items():
             typ = type(node.op)
             rval.setdefault(typ, 0)
             rval[typ] += t
@@ -366,7 +363,7 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by class on demand
         rval = {}
-        for node, count in self.apply_callcount.items():
+        for (fgraph, node), count in self.apply_callcount.items():
             typ = type(node.op)
             rval.setdefault(typ, 0)
             rval[typ] += count
@@ -379,7 +376,7 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by class on demand
         rval = {}
-        for node, count in self.apply_callcount.items():
+        for (fgraph, node), count in self.apply_callcount.items():
             typ = type(node.op)
             rval.setdefault(typ, 0)
             rval[typ] += 1
@@ -392,7 +389,7 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by class on demand
         rval = {}
-        for node in self.apply_callcount:
+        for (fgraph, node) in self.apply_callcount:
             typ = type(node.op)
             if self.apply_cimpl[node]:
                 impl = "C "
@@ -410,22 +407,22 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by Op on demand
         rval = {}
-        for node, t in self.apply_time.items():
+        for (fgraph, node), t in self.apply_time.items():
             rval.setdefault(node.op, 0)
             rval[node.op] += t
         return rval
 
-    def fill_node_total_time(self, node, total_times):
+    def fill_node_total_time(self, fgraph, node, total_times):
         """
-        node -> fill total time icluding its parents (returns nothing)
+        node -> fill total time including its parents (returns nothing)
 
         """
         # timing is stored by node, we compute total time on demand
-        total = self.apply_time[node]
+        total = self.apply_time.get((fgraph, node), 0.0)
         for parent in node.get_parents():
-            if parent.owner in self.apply_time:
+            if (fgraph, parent.owner) in self.apply_time:
                 if parent.owner not in total_times:
-                    self.fill_node_total_time(parent.owner, total_times)
+                    self.fill_node_total_time(fgraph, parent.owner, total_times)
                 total += total_times[parent.owner]
         total_times[node] = total
 
@@ -435,9 +432,9 @@ class ProfileStats:
 
         """
         rval = {}
-        for node in self.apply_time:
+        for (fgraph, node) in self.apply_time:
             if node not in rval:
-                self.fill_node_total_time(node, rval)
+                self.fill_node_total_time(fgraph, node, rval)
         return rval
 
     def op_callcount(self):
@@ -447,7 +444,7 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by Op on demand
         rval = {}
-        for node, count in self.apply_callcount.items():
+        for (fgraph, node), count in self.apply_callcount.items():
             rval.setdefault(node.op, 0)
             rval[node.op] += count
         return rval
@@ -459,7 +456,7 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by Op on demand
         rval = {}
-        for node, count in self.apply_callcount.items():
+        for (fgraph, node), count in self.apply_callcount.items():
             rval.setdefault(node.op, 0)
             rval[node.op] += 1
         return rval
@@ -471,7 +468,7 @@ class ProfileStats:
         """
         # timing is stored by node, we compute timing by Op on demand
         rval = {}
-        for node in self.apply_callcount:
+        for (fgraph, node) in self.apply_callcount:
             if self.apply_cimpl[node]:
                 rval[node.op] = "C "
             else:
@@ -726,14 +723,20 @@ class ProfileStats:
 
         topos = {}  # Only do the topo once per fct.
         atimes = []
-        for a, t in self.apply_time.items():
-            if a.fgraph not in topos:
-                topo = a.fgraph.toposort()
-                topos[a.fgraph] = topo
+        for (fgraph, a), t in self.apply_time.items():
+            if fgraph not in topos:
+                topo = fgraph.toposort()
+                topos[fgraph] = topo
             else:
-                topo = topos[a.fgraph]
+                topo = topos[fgraph]
             atimes.append(
-                (t * 100 / local_time, t, a, topo.index(a), self.apply_callcount[a])
+                (
+                    t * 100 / local_time,
+                    t,
+                    a,
+                    topo.index(a),
+                    self.apply_callcount[(fgraph, a)],
+                )
             )
         del topos
 
@@ -752,8 +755,8 @@ class ProfileStats:
                     [self.variable_shape[var] for var in a.inputs],
                     [self.variable_shape[var] for var in a.outputs],
                 )
-                flops = "%8.1f" % (fl / 1024.0 / 1024)
-                flops_s = "%10.1f" % (fl / 1024.0 / 1024 / 1024 / t)
+                flops = f"{fl / 1024.0 / 1024:8.1f}"
+                flops_s = f"{fl / 1024.0 / 1024 / 1024 / t:10.1f}"
             else:
                 flops = "        "
                 flops_s = "          "
@@ -779,11 +782,10 @@ class ProfileStats:
                 st = self.variable_strides.get(var, "no strides")
                 off = self.variable_offset.get(var, "")
                 if off != "":
-                    off = ", offset=%s" % off
+                    off = f", offset={off}"
                 dtype = getattr(var, "dtype", "no dtype")
                 print(
-                    "    input %d: dtype=%s, shape=%s, strides=%s%s"
-                    % (idx, dtype, sh, st, off),
+                    f"    input {int(idx)}: dtype={dtype}, shape={sh}, strides={st}{off}",
                     file=file,
                 )
             for idx, var in enumerate(a.outputs):
@@ -791,11 +793,10 @@ class ProfileStats:
                 st = self.variable_strides.get(var, "no strides")
                 off = self.variable_offset.get(var, "")
                 if off != "":
-                    off = ", offset=%s" % off
+                    off = f", offset={off}"
                 dtype = getattr(var, "dtype", "no dtype")
                 print(
-                    "    output %d: dtype=%s, shape=%s, strides=%s%s"
-                    % (idx, dtype, sh, st, off),
+                    f"    output {int(idx)}: dtype={dtype}, shape={sh}, strides={st}{off}",
                     file=file,
                 )
             # Same as before, this I've sacrificied some information making
@@ -815,43 +816,42 @@ class ProfileStats:
     def summary_function(self, file):
         print("Function profiling", file=file)
         print("==================", file=file)
-        print("  Message: %s" % self.message, file=file)
+        print(f"  Message: {self.message}", file=file)
         print(
-            "  Time in %i calls to Function.__call__: %es"
-            % (self.fct_callcount, self.fct_call_time),
+            f"  Time in {self.fct_callcount} calls to Function.__call__: {self.fct_call_time:e}s",
             file=file,
         )
         if self.fct_call_time > 0:
             print(
-                "  Time in Function.fn.__call__: %es (%.3f%%)"
-                % (self.vm_call_time, 100 * self.vm_call_time / self.fct_call_time),
+                f"  Time in Function.fn.__call__: {self.vm_call_time}s ({100 * self.vm_call_time / self.fct_call_time:.3f}%)",
                 file=file,
             )
             local_time = sum(self.apply_time.values())
             if local_time > 0:
                 print(
-                    "  Time in thunks: %es (%.3f%%)"
-                    % (local_time, 100 * local_time / self.fct_call_time),
+                    f"  Time in thunks: {local_time}s ({100 * local_time / self.fct_call_time:.3f}%)",
                     file=file,
                 )
-        print("  Total compile time: %es" % self.compile_time, file=file)
-        print("    Number of Apply nodes: %d" % self.nb_nodes, file=file)
-        print("    Theano Optimizer time: %es" % self.optimizer_time, file=file)
-        print("       Theano validate time: %es" % self.validate_time, file=file)
+        print(f"  Total compile time: {self.compile_time:e}s", file=file)
+        print(f"    Number of Apply nodes: {int(self.nb_nodes)}", file=file)
+        print(f"    Theano Optimizer time: {self.optimizer_time:e}s", file=file)
+        print(f"       Theano validate time: {self.validate_time:e}s", file=file)
         print(
-            "    Theano Linker time (includes C, CUDA code "
-            "generation/compiling): %es" % self.linker_time,
+            (
+                "    Theano Linker time (includes C, CUDA code "
+                f"generation/compiling): {self.linker_time}s"
+            ),
             file=file,
         )
-        print("       Import time %es" % self.import_time, file=file)
+        print(f"       Import time {self.import_time:e}s", file=file)
         print(
-            "       Node make_thunk time %es" % self.linker_node_make_thunks, file=file
+            f"       Node make_thunk time {self.linker_node_make_thunks:e}s", file=file
         )
 
         for node, t in sorted(
             self.linker_make_thunk_time.items(), key=operator.itemgetter(1)
         )[::-1][:5]:
-            print("           Node {} time {:e}s".format(node, t), file=file)
+            print(f"           Node {node} time {t:e}s", file=file)
         print("", file=file)
 
         # The validation time is a subset of optimizer_time
@@ -860,23 +860,23 @@ class ProfileStats:
 
     def summary_globals(self, file):
         print(
-            "Time in all call to theano.grad() %es" % theano.gradient.grad_time,
+            f"Time in all call to theano.grad() {theano.gradient.grad_time:e}s",
             file=file,
         )
         total_time = time.time() - theano_imported_time
-        print("Time since theano import %.3fs" % (total_time), file=file)
+        print(f"Time since theano import {total_time:.3f}s", file=file)
 
     def summary_memory(self, file, N=None):
         fct_memory = {}  # fgraph->dict(node->[outputs size])
         fct_shapes = {}  # fgraph->dict(node->[outputs shapes]))
         var_mem = {}  # variable->size in bytes; don't include input variables
-        node_mem = {}  # node->total outputs size (only dense outputs)
+        node_mem = {}  # (fgraph, node)->total outputs size (only dense outputs)
 
-        for node in self.apply_callcount:
-            fct_memory.setdefault(node.fgraph, {})
-            fct_memory[node.fgraph].setdefault(node, [])
-            fct_shapes.setdefault(node.fgraph, {})
-            fct_shapes[node.fgraph].setdefault(node, [])
+        for (fgraph, node) in self.apply_callcount:
+            fct_memory.setdefault(fgraph, {})
+            fct_memory[fgraph].setdefault(node, [])
+            fct_shapes.setdefault(fgraph, {})
+            fct_shapes[fgraph].setdefault(node, [])
             sum_dense = 0
             for out in node.outputs:
                 if out in self.variable_shape:
@@ -890,9 +890,9 @@ class ProfileStats:
                     v = 0  # 'Variable isn't created'
 
                 var_mem[out] = v
-                fct_memory[node.fgraph][node].append(v)
-                fct_shapes[node.fgraph][node].append(sh)
-            node_mem[node] = sum_dense
+                fct_memory[fgraph][node].append(v)
+                fct_shapes[fgraph][node].append(sh)
+            node_mem[(fgraph, node)] = sum_dense
         del v
 
         # Find the function that used the most of that statistic
@@ -1086,7 +1086,7 @@ class ProfileStats:
             # Initial executable_nodes
             executable_nodes = set()
             for var in fgraph.inputs:
-                for c, _ in var.clients:
+                for c, _ in fgraph.clients[var]:
                     if c != "output":
                         deps = c.inputs + c.destroy_dependencies
                         if all(compute_map[v][0] for v in deps):
@@ -1212,7 +1212,7 @@ class ProfileStats:
                         done_dict[frozen_set] = max_mem_count
 
                         for var in node.outputs:
-                            for c, _ in var.clients:
+                            for c, _ in fgraph.clients[var]:
                                 if c != "output":
                                     deps = c.inputs + c.destroy_dependencies
                                     if all(compute_map[v][0] for v in deps):
@@ -1329,7 +1329,7 @@ class ProfileStats:
                 stats[i] = compute_max_stats(running_memory, stats[i])
 
             # Config: whether print min memory peak
-            if config.profiling.min_peak_memory:
+            if config.profiling__min_peak_memory:
                 node_list = fgraph.apply_nodes
                 ttt = time.time()
                 min_peak = count_minimum_peak(node_list, fgraph, nodes_mem)
@@ -1354,30 +1354,23 @@ class ProfileStats:
             (_, new_max_running_max_memory_size, _, _) = stats2
 
             print(
-                "        CPU: %dKB (%dKB)"
-                % (
-                    (
-                        int(round(new_max_running_max_memory_size[1] / 1024.0)),
-                        int(round(max_running_max_memory_size[1] / 1024.0)),
-                    )
+                (
+                    f"        CPU: {int(round(new_max_running_max_memory_size[1] / 1024.0))}KB "
+                    f"({int(round(max_running_max_memory_size[1] / 1024.0))}KB)"
                 ),
                 file=file,
             )
             print(
-                "        GPU: %dKB (%dKB)"
-                % (
-                    (
-                        int(round(new_max_running_max_memory_size[2] / 1024.0)),
-                        int(round(max_running_max_memory_size[2] / 1024.0)),
-                    )
+                (
+                    f"        GPU: {int(round(new_max_running_max_memory_size[2] / 1024.0))}KB "
+                    f"({int(round(max_running_max_memory_size[2] / 1024.0))}KB)"
                 ),
                 file=file,
             )
             print(
-                "        CPU + GPU: %dKB (%dKB)"
-                % (
-                    int(round(new_max_running_max_memory_size[0] / 1024.0)),
-                    int(round(max_running_max_memory_size[0] / 1024.0)),
+                (
+                    f"        CPU + GPU: {int(round(new_max_running_max_memory_size[0] / 1024.0))}KB "
+                    f"({int(round(max_running_max_memory_size[0] / 1024.0))}KB)"
                 ),
                 file=file,
             )
@@ -1398,16 +1391,15 @@ class ProfileStats:
             file=file,
         )
         print(
-            "        CPU: %dKB" % int(round(new_max_node_memory_size[1] / 1024.0)),
+            f"        CPU: {int(round(new_max_node_memory_size[1] / 1024.0))}KB",
             file=file,
         )
         print(
-            "        GPU: %dKB" % int(round(new_max_node_memory_size[2] / 1024.0)),
+            f"        GPU: {int(round(new_max_node_memory_size[2] / 1024.0))}KB",
             file=file,
         )
         print(
-            "        CPU + GPU: %dKB"
-            % int(round(new_max_node_memory_size[0] / 1024.0)),
+            f"        CPU + GPU: {int(round(new_max_node_memory_size[0] / 1024.0))}KB",
             file=file,
         )
         print("---", file=file)
@@ -1415,8 +1407,7 @@ class ProfileStats:
         if min_max_peak:
             print(
                 "    Minimum peak from all valid apply node order is "
-                "%dKB(took %.3fs to compute)"
-                % (int(round(min_max_peak / 1024.0)), min_peak_time),
+                f"{int(round(min_max_peak / 1024.0))}KB(took {min_peak_time:3f}s to compute)",
                 file=file,
             )
 
@@ -1435,24 +1426,24 @@ class ProfileStats:
         print("", file=file)
         items = list(node_mem.items())
         items.sort(key=lambda a: a[1], reverse=True)
-        for idx, (node, node_outputs_size) in enumerate(items[:N]):
+        for idx, ((fgraph, node), node_outputs_size) in enumerate(items[:N]):
             code = ["c"] * len(node.outputs)
             for out, inp in getattr(node.op, "destroy_map", {}).items():
                 code[out] = "i"
             for out, inp in getattr(node.op, "view_map", {}).items():
                 code[out] = "v"
-            shapes = str(fct_shapes[node.fgraph][node])
+            shapes = str(fct_shapes[fgraph][node])
 
             if all([hasattr(out.type, "get_size") for out in node.outputs]):
-                size = "%9dB" % node_outputs_size
-                if node_outputs_size < config.profiling.min_memory_size:
+                size = "{node_outputs_size:9d}B"
+                if node_outputs_size < config.profiling__min_memory_size:
                     N = idx
                     break
             else:
-                size = "%10s" % "Unknown"
+                size = "   Unknown"
 
             print(
-                "     {}  {} {} {}".format(size, shapes, " ".join(code), node),
+                f"     {size}  {shapes} {' '.join(code)} {node}",
                 file=file,
             )
 
@@ -1461,18 +1452,20 @@ class ProfileStats:
         if size_sum_dense == 0:
             p = "0%"
         else:
-            p = "(%.2f%%)" % (float(sum_remaining) / size_sum_dense * 100)
+            p = f"({float(sum_remaining) / size_sum_dense * 100:.2f}%)"
         print(
-            "   ... (remaining %i Apply account for %4dB/%dB (%s) of the"
-            " Apply with dense outputs sizes)"
-            % (max(0, len(node_mem) - N), sum_remaining, size_sum_dense, p),
+            (
+                f"   ... (remaining {max(0, len(node_mem) - N)} Apply account for "
+                f"{sum_remaining:4d}B/{size_sum_dense :d}B ({p}) of the"
+                " Apply with dense outputs sizes)"
+            ),
             file=file,
         )
         print("", file=file)
         if N == 0:
             print(
                 "    All Apply nodes have output sizes that take less "
-                "than %dB." % config.profiling.min_memory_size,
+                f"than {int(config.profiling__min_memory_size)}B.",
                 file=file,
             )
         print(
@@ -1498,11 +1491,11 @@ class ProfileStats:
         elif self.fct_callcount > 0:
             print(
                 "  No execution time accumulated "
-                "(hint: try config profiling.time_thunks=1)",
+                "(hint: try config profiling__time_thunks=1)",
                 file=file,
             )
-        if config.profiling.debugprint:
-            fcts = {n.fgraph for n in self.apply_time.keys()}
+        if config.profiling__debugprint:
+            fcts = {fgraph for (fgraph, n) in self.apply_time.keys()}
             theano.printing.debugprint(fcts, print_type=True)
         if self.variable_shape or self.variable_strides:
             self.summary_memory(file, n_apply_to_print)
@@ -1625,49 +1618,51 @@ class ProfileStats:
             printed_tip = True
 
         # tip 2
-        if not config.lib.amdlibm and any(
-            [amdlibm_speed_up(a.op) for a in self.apply_time]
+        if not config.lib__amblibm and any(
+            [amdlibm_speed_up(a.op) for (fgraph, a) in self.apply_time]
         ):
             print(
                 "  - Try installing amdlibm and set the Theano flag "
-                "lib.amdlibm=True. This speeds up only some Elemwise "
+                "lib__amblibm=True. This speeds up only some Elemwise "
                 "operation.",
                 file=file,
             )
             printed_tip = True
 
         # tip 3
-        if not config.lib.amdlibm and any(
+        if not config.lib__amblibm and any(
             [
                 exp_float32_op(a.op) and a.inputs[0].dtype == "float32"
-                for a in self.apply_time
+                for (fgraph, a) in self.apply_time
             ]
         ):
             print(
                 "  - With the default gcc libm, exp in float32 is slower "
                 "than in float64! Try Theano flag floatX=float64, or "
-                "install amdlibm and set the theano flags lib.amdlibm=True",
+                "install amdlibm and set the theano flags lib__amblibm=True",
                 file=file,
             )
             printed_tip = True
 
         # tip 4
-        for a in self.apply_time:
+        for (fgraph, a) in self.apply_time:
             node = a
             if isinstance(node.op, T.Dot) and all(
                 [len(i.type.broadcastable) == 2 for i in node.inputs]
             ):
                 print(
-                    "  - You have a dot operation that was not optimized to"
-                    " dot22 (which is faster). Make sure the inputs are "
-                    "float32 or float64, and are the same for both inputs. "
-                    "Currently they are: %s" % [i.type for i in node.inputs],
+                    (
+                        "  - You have a dot operation that was not optimized to"
+                        " dot22 (which is faster). Make sure the inputs are "
+                        "float32 or float64, and are the same for both inputs. "
+                        f"Currently they are: {[i.type for i in node.inputs]}"
+                    ),
                     file=file,
                 )
                 printed_tip = True
 
         # tip 5
-        for a in self.apply_time:
+        for (fgraph, a) in self.apply_time:
             node = a
             if isinstance(node.op, RandomFunction):
                 printed_tip = True
@@ -1687,13 +1682,15 @@ class ProfileStats:
                 break
 
         # tip 6
-        for a in self.apply_time:
+        for (fgraph, a) in self.apply_time:
             node = a
             if isinstance(node.op, T.Dot) and len({i.dtype for i in node.inputs}) != 1:
                 print(
-                    "  - You have a dot operation that has different dtype "
-                    " for inputs (%s). Make sure that the inputs have same "
-                    " dtype." % [i.type for i in node.inputs],
+                    (
+                        "  - You have a dot operation that has different dtype "
+                        f" for inputs ({[i.type for i in node.inputs]}). Make sure that the inputs have same "
+                        " dtype."
+                    ),
                     file=file,
                 )
                 printed_tip = True
@@ -1703,7 +1700,7 @@ class ProfileStats:
         import theano.tensor.signal.pool as pool
         from theano.tensor.nnet import LogSoftmax
 
-        for a in self.apply_time:
+        for (fgraph, a) in self.apply_time:
             node = a
             if isinstance(node.op, pool.Pool):
                 if not theano.gpuarray.dnn.dnn_present():
@@ -1767,12 +1764,12 @@ class ScanProfileStats(ProfileStats):
         else:
             print("Scan Op profiling", file=file)
         print("==================", file=file)
-        print("  Message: %s" % self.message, file=file)
+        print(f"  Message: {self.message}", file=file)
 
         print(
             (
-                "  Time in %i calls of the op (for a total of %i "
-                "steps) %es" % (self.callcount, self.nbsteps, self.call_time)
+                f"  Time in {self.callcount} calls of the op (for a total of {self.nbsteps} "
+                f"steps) {self.call_time:3}s"
             ),
             file=file,
         )
@@ -1781,16 +1778,14 @@ class ScanProfileStats(ProfileStats):
         if self.call_time > 0:
             val = self.vm_call_time * 100 / self.call_time
         print(
-            "  Total time spent in calling the VM %es (%.3f%%)"
-            % (self.vm_call_time, val),
+            f"  Total time spent in calling the VM {self.vm_call_time:e}s ({val:.3f}%)",
             file=file,
         )
         val = 100
         if self.call_time > 0:
             val = 100.0 - self.vm_call_time * 100 / self.call_time
         print(
-            "  Total overhead (computing slices..) %es (%.3f%%)"
-            % (self.call_time - self.vm_call_time, val),
+            f"  Total overhead (computing slices..) {self.call_time - self.vm_call_time:e}s ({val:.3f}%)",
             file=file,
         )
         print("", file=file)
