@@ -5,6 +5,7 @@ Defines Linkers that deal with C implementations.
 import logging
 import os
 import sys
+from collections import defaultdict
 from copy import copy
 from io import StringIO
 
@@ -174,8 +175,8 @@ def code_gen(blocks):
     tail = ""
     for block in blocks:
         decl += block.declare
-        head = head + ("\n{\n%s" % block.behavior)
-        tail = ("%s\n}\n" % block.cleanup) + tail
+        head = f"{head}\n{{\n{block.behavior}"
+        tail = f"{block.cleanup}\n}}\n{tail}"
     return decl + head + tail
 
 
@@ -223,22 +224,22 @@ def struct_gen(args, struct_builders, blocks, sub):
         #     be executed if any step in the constructor fails and the
         #     latter only at destruction time.
         struct_decl += block.declare
-        struct_init_head = struct_init_head + ("\n%s" % block.behavior)
+        struct_init_head = struct_init_head + f"\n{block.behavior}"
         struct_cleanup += block.cleanup
 
     behavior = code_gen(blocks)
 
     # declares the storage
-    storage_decl = "\n".join(["PyObject* %s;" % arg for arg in args])
+    storage_decl = "\n".join([f"PyObject* {arg};" for arg in args])
     # in the constructor, sets the storage to the arguments
-    storage_set = "\n".join(["this->{} = {};".format(arg, arg) for arg in args])
+    storage_set = "\n".join([f"this->{arg} = {arg};" for arg in args])
     # increments the storage's refcount in the constructor
-    storage_incref = "\n".join(["Py_XINCREF(%s);" % arg for arg in args])
+    storage_incref = "\n".join([f"Py_XINCREF({arg});" for arg in args])
     # decrements the storage's refcount in the destructor
-    storage_decref = "\n".join(["Py_XDECREF(this->%s);" % arg for arg in args])
+    storage_decref = "\n".join([f"Py_XDECREF(this->{arg});" for arg in args])
 
     args_names = ", ".join(args)
-    args_decl = ", ".join(["PyObject* %s" % arg for arg in args])
+    args_decl = ", ".join([f"PyObject* {arg}" for arg in args])
 
     # The following code stores the exception data in __ERROR, which
     # is a special field of the struct. __ERROR is a list of length 3
@@ -335,7 +336,7 @@ def struct_gen(args, struct_builders, blocks, sub):
 # with handling of the py_<name> variable.
 
 
-def get_nothing(r, name, sub):
+def get_nothing(fgraph, r, name, sub):
     """
     WRITEME
 
@@ -343,7 +344,7 @@ def get_nothing(r, name, sub):
     return ""
 
 
-def get_c_declare(r, name, sub):
+def get_c_declare(fgraph, r, name, sub):
     """
     Wrapper around c_declare that declares py_name.
 
@@ -356,23 +357,20 @@ def get_c_declare(r, name, sub):
     if any(
         [
             getattr(c.op, "check_input", config.check_input)
-            for (c, _) in r.clients
+            for (c, _) in fgraph.clients[r]
             if not isinstance(c, str)
         ]
     ) or (r.owner and getattr(r.owner.op, "check_input", config.check_input)):
         c_declare = r.type.c_declare(name, sub, True)
     else:
         c_declare = r.type.c_declare(name, sub, False)
-    pre = (
-        """
-    PyObject* py_%(name)s;
+    pre = f"""
+    PyObject* py_{name};
     """
-        % locals()
-    )
     return pre + c_declare
 
 
-def get_c_init(r, name, sub):
+def get_c_init(fgraph, r, name, sub):
     """
     Wrapper around c_init that initializes py_name to Py_None.
 
@@ -388,7 +386,7 @@ def get_c_init(r, name, sub):
     return pre + r.type.c_init(name, sub)
 
 
-def get_c_extract(r, name, sub):
+def get_c_extract(fgraph, r, name, sub):
     """
     Wrapper around c_extract that initializes py_name from storage.
 
@@ -402,7 +400,7 @@ def get_c_extract(r, name, sub):
     if any(
         [
             getattr(c.op, "check_input", config.check_input)
-            for (c, _) in r.clients
+            for (c, _) in fgraph.clients[r]
             if not isinstance(c, str)
         ]
     ):
@@ -412,7 +410,7 @@ def get_c_extract(r, name, sub):
         if any(
             [
                 getattr(c.op, "check_broadcast", True)
-                for (c, _) in r.clients
+                for (c, _) in fgraph.clients[r]
                 if not isinstance(c, str)
             ]
         ):
@@ -435,7 +433,7 @@ def get_c_extract(r, name, sub):
     return pre + c_extract
 
 
-def get_c_extract_out(r, name, sub):
+def get_c_extract_out(fgraph, r, name, sub):
     """
     Wrapper around c_extract_out that initializes py_name from storage.
 
@@ -472,7 +470,7 @@ def get_c_extract_out(r, name, sub):
     return pre + c_extract
 
 
-def get_c_cleanup(r, name, sub):
+def get_c_cleanup(fgraph, r, name, sub):
     """
     Wrapper around c_cleanup that decrefs py_name.
 
@@ -486,7 +484,7 @@ def get_c_cleanup(r, name, sub):
     return r.type.c_cleanup(name, sub) + post
 
 
-def get_c_sync(r, name, sub):
+def get_c_sync(fgraph, r, name, sub):
     """
     Wrapper around c_sync that syncs py_name with storage.
 
@@ -504,7 +502,7 @@ def get_c_sync(r, name, sub):
     )
 
 
-def apply_policy(policy, r, name, sub):
+def apply_policy(fgraph, policy, r, name, sub):
     """
     Apply the list of policies to name.r,sub
 
@@ -524,12 +522,12 @@ def apply_policy(policy, r, name, sub):
     if isinstance(policy, (list, tuple)):
         ret = ""
         for sub_policy in policy:
-            ret += sub_policy(r, name, sub)
+            ret += sub_policy(fgraph, r, name, sub)
         return ret
-    return policy(r, name, sub)
+    return policy(fgraph, r, name, sub)
 
 
-def struct_variable_codeblocks(variable, policies, id, symbol_table, sub):
+def struct_variable_codeblocks(fgraph, variable, policies, id, symbol_table, sub):
     """
     Update "sub" dict and create two codeblocks with different failure modes
 
@@ -553,26 +551,28 @@ def struct_variable_codeblocks(variable, policies, id, symbol_table, sub):
 
     """
 
-    name = "V%i" % id
+    name = f"V{id}"
     if variable not in symbol_table:
         symbol_table[variable] = name
     sub = dict(sub)
     #    sub['name'] = name
     sub["id"] = id
     sub["fail"] = failure_code_init(sub)
-    sub["py_ptr"] = "py_%s" % name
-    sub["stor_ptr"] = "storage_%s" % name
+    sub["py_ptr"] = f"py_{name}"
+    sub["stor_ptr"] = f"storage_{name}"
     # struct_declare, struct_behavior, struct_cleanup, sub)
     struct_builder = CodeBlock(
-        *[apply_policy(policy, variable, name, sub) for policy in policies[0]] + [sub]
+        *[apply_policy(fgraph, policy, variable, name, sub) for policy in policies[0]]
+        + [sub]
     )
     sub["id"] = id + 1
     sub["fail"] = failure_code(sub)
-    sub["py_ptr"] = "py_%s" % name
-    sub["stor_ptr"] = "storage_%s" % name
+    sub["py_ptr"] = f"py_{name}"
+    sub["stor_ptr"] = f"storage_{name}"
     # run_declare, run_behavior, run_cleanup, sub)
     block = CodeBlock(
-        *[apply_policy(policy, variable, name, sub) for policy in policies[1]] + [sub]
+        *[apply_policy(fgraph, policy, variable, name, sub) for policy in policies[1]]
+        + [sub]
     )
 
     return struct_builder, block
@@ -625,7 +625,7 @@ class CLinker(link.Linker):
         # list(fgraph.variables)
         # We need to include the unused inputs in our variables,
         # otherwise we can't pass them to the module.
-        self.variables = [var for var in self.inputs if not len(var.clients)]
+        self.variables = [var for var in self.inputs if not len(fgraph.clients[var])]
         self.variables += graph.variables(self.inputs, self.outputs)
 
         # This adds a hidden input which is the params for each node
@@ -639,10 +639,10 @@ class CLinker(link.Linker):
                 if params in self.node_params:
                     var = self.node_params[params]
                     assert var.type == node.params_type
-                    var.clients.append((node, "params"))
+                    fgraph.clients[var].append((node, "params"))
                 else:
                     var = graph.Constant(node.params_type, params)
-                    var.clients = [(node, "params")]
+                    fgraph.clients[var] = [(node, "params")]
                     self.node_params[params] = var
                     self.variables.append(var)
 
@@ -786,7 +786,7 @@ class CLinker(link.Linker):
                 )
 
             builder, block = struct_variable_codeblocks(
-                variable, policy, id, symbol, sub
+                self.fgraph, variable, policy, id, symbol, sub
             )
 
             # each Variable generates two CodeBlocks, one to
@@ -817,7 +817,7 @@ class CLinker(link.Linker):
             # This ensures that, when defining functions in support code,
             # we cannot have two different functions, in different modules,
             # that have the same name.
-            name = "node_<<<<HASH_PLACEHOLDER>>>>_%i" % node_num
+            name = f"node_<<<<HASH_PLACEHOLDER>>>>_{node_num}"
             isyms = [symbol[r] for r in node.inputs]
             osyms = [symbol[r] for r in node.outputs]
 
@@ -888,10 +888,10 @@ class CLinker(link.Linker):
             try:
                 behavior = op.c_code(node, name, isyms, osyms, sub)
             except utils.MethodNotDefined:
-                raise NotImplementedError("%s cannot produce C code" % op)
-            assert isinstance(behavior, str), (
-                str(node.op) + " didn't return a string for c_code"
-            )
+                raise NotImplementedError(f"{op} cannot produce C code")
+            assert isinstance(
+                behavior, str
+            ), f"{node.op} didn't return a string for c_code"
             # To help understand what is following. It help read the c code.
             # This prevent different op that generate the same c code
             # to be merged, I suppose this won't happen...
@@ -902,7 +902,7 @@ class CLinker(link.Linker):
             except utils.MethodNotDefined:
                 cleanup = ""
 
-            _logger.info("compiling un-versioned Apply %s", str(node))
+            _logger.info(f"compiling un-versioned Apply {node}")
 
             blocks.append(CodeBlock("", behavior, cleanup, sub))
             tasks.append((node, "code", id))
@@ -921,13 +921,13 @@ class CLinker(link.Linker):
         # compare equal to equivalent Constant instances.
         args = []
         args += [
-            "storage_%s" % symbol[variable]
+            f"storage_{symbol[variable]}"
             for variable in utils.uniq(self.inputs + self.outputs + self.orphans)
         ]
 
         # <<<<HASH_PLACEHOLDER>>>> will be replaced by a hash of the whole
         # code in the file, including support code, in DynamicModule.code.
-        struct_name = "__struct_compiled_op_%s" % "<<<<HASH_PLACEHOLDER>>>>"
+        struct_name = f"__struct_compiled_op_{'<<<<HASH_PLACEHOLDER>>>>'}"
         struct_code = struct_gen(
             args, init_blocks, blocks, dict(failure_var=failure_var, name=struct_name)
         )
@@ -967,7 +967,7 @@ class CLinker(link.Linker):
         The support code from Variables is added before the support code from Ops.This might contain duplicates.
         """
         ret = []
-        if config.cmodule.debug:
+        if config.cmodule__debug:
             ret.append(
                 """
             #ifndef DEBUG
@@ -1381,6 +1381,7 @@ class CLinker(link.Linker):
             def __init__(self, inputs, outputs):
                 self.inputs = inputs
                 self.outputs = outputs
+                self.clients = defaultdict(list)
 
             def toposort(self):
                 # Calling io_toposort() here is fine because the results will
@@ -1459,7 +1460,7 @@ class CLinker(link.Linker):
             ndarray_c_version = np.core.multiarray._get_ndarray_c_version()
         else:
             ndarray_c_version = np.core._multiarray_umath._get_ndarray_c_version()
-        sig.append("NPY_ABI_VERSION=0x%X" % ndarray_c_version)
+        sig.append(f"NPY_ABI_VERSION=0x{ndarray_c_version:X}")
         if c_compiler:
             sig.append("c_compiler_str=" + c_compiler.version_str())
 
@@ -1513,7 +1514,9 @@ class CLinker(link.Linker):
                 if i.owner is None:
                     assert all(all(out is not None for out in o.outputs) for o in order)
                     assert all(input.owner is None for input in fgraph.inputs)
-                    raise Exception("what is this?", (i, type(i), i.clients, fgraph))
+                    raise Exception(
+                        f"Owner of {i} (clients {fgraph.clients.get(i)}) is None"
+                    )
 
                 if i in fgraph.outputs:
                     isig = (
@@ -1571,7 +1574,7 @@ class CLinker(link.Linker):
         for ipos, var in [
             (i, var)
             for i, var in enumerate(fgraph.inputs)
-            if not len(getattr(var, "clients", []))
+            if not len(fgraph.clients[var])
         ]:
             sig.append((var.type, in_sig(var, -1, ipos)))
 
@@ -1605,7 +1608,7 @@ class CLinker(link.Linker):
         src_code = mod.code()
         get_lock()
         try:
-            _logger.debug("LOCATION %s", str(location))
+            _logger.debug(f"LOCATION {location}")
             module = c_compiler.compile_str(
                 module_name=mod.code_hash,
                 src_code=src_code,
@@ -1743,12 +1746,12 @@ class CLinker(link.Linker):
         print("     return NULL;", file=code)
         print("  }", file=code)
         print(
-            "  %(struct_name)s* struct_ptr = new %(struct_name)s();" % locals(),
+            f"  {struct_name}* struct_ptr = new {struct_name}();",
             file=code,
         )
         print(
             "  if (struct_ptr->init(",
-            ",".join("PyTuple_GET_ITEM(argtuple, %i)" % n for n in range(n_args)),
+            ",".join(f"PyTuple_GET_ITEM(argtuple, {n})" for n in range(n_args)),
             ") != 0) {",
             file=code,
         )
@@ -2103,7 +2106,7 @@ class DualLinker(link.Linker):
                     for output1, output2 in zip(thunk1.outputs, thunk2.outputs):
                         self.checker(output1, output2)
                 except Exception:
-                    link.raise_with_op(node1)
+                    link.raise_with_op(fgraph, node1)
 
         return f, i1, o1
 
