@@ -1,23 +1,21 @@
-"""
-fg.py: fg stands for FunctionGraph
-Contains the FunctionGraph class and exception
-types that it can raise.
-
-"""
+"""A container for specifying and manipulating a graph with distinct inputs and outputs."""
 import time
 from collections import OrderedDict
 from io import StringIO
 
 import theano
 from theano import config
-from theano.gof import graph, toolbox, utils
+from theano.gof import toolbox, utils
+from theano.gof.graph import Apply, Constant, Variable
+from theano.gof.graph import as_string as graph_as_string
+from theano.gof.graph import clone as clone_graph
+from theano.gof.graph import clone_get_equiv, io_toposort
+from theano.gof.graph import ops as ops_between
+from theano.gof.graph import variables as variables_between
 from theano.gof.utils import TestValueError, get_variable_trace_string
 from theano.misc.ordered_set import OrderedSet
 
 
-NullType = None
-
-
 class InconsistencyError(Exception):
     """
     This exception should be thrown by listeners to FunctionGraph when the
@@ -45,42 +43,38 @@ class MissingInputError(Exception):
 
 class FunctionGraph(utils.object2):
     """
-    A FunctionGraph represents a subgraph bound by a set of input variables and
+    A `FunctionGraph` represents a subgraph bound by a set of input variables and
     a set of output variables, ie a subgraph that specifies a theano function.
     The inputs list should contain all the inputs on which the outputs depend.
-    Variables of type Constant are not counted as inputs.
+    `Variable`s of type `Constant` are not counted as inputs.
 
-    The FunctionGraph supports the replace operation which allows to replace a
-    variable in the subgraph by another, e.g. replace (x + x).out by (2
-    * x).out. This is the basis for optimization in theano.
+    The `FunctionGraph` supports the replace operation which allows to replace
+    a variable in the subgraph by another, e.g. replace ``(x + x).out`` by ``(2
+    * x).out``. This is the basis for optimization in Theano.
 
     This class is also responsible for verifying that a graph is valid
     (ie, all the dtypes and broadcast patterns are compatible with the
-    way the the Variables are used) and for annotating the Variables with
-    a .clients field that specifies which Apply nodes use the variable.
-    The .clients field combined with the .owner field and the Apply nodes'
-    .inputs field allows the graph to be traversed in both directions.
+    way the the `Variable`s are used) and for tracking the `Variable`s with
+    a `clients` field that specifies which `Apply` nodes use the `Variable`.
+    The `clients` field combined with the `Variable.owner` field and the
+    `Apply` nodes' `Apply.inputs` field allows the graph to be traversed in
+    both directions.
 
     It can also be extended with new features using
-    FunctionGraph.attach_feature(<toolbox.Feature instance>).
-    See toolbox.Feature for event types and documentation.
-    Extra features allow the FunctionGraph to verify new properties of
+    `FunctionGraph.attach_feature`(<toolbox.Feature instance>).
+    See `toolbox.Feature` for event types and documentation.
+    Extra features allow the `FunctionGraph` to verify new properties of
     a graph as it is optimized.
-    # TODO: are there other things features can do to the fgraph?
 
-    Historically, the FunctionGraph was called an Env. Keep this in mind
+    Historically, the `FunctionGraph` was called an ``Env``. Keep this in mind
     while reading out-of-date documentation, e-mail support threads, etc.
 
-    The constructor creates a FunctionGraph which operates on the subgraph
+    The constructor creates a `FunctionGraph` which operates on the subgraph
     bound by the inputs and outputs sets.
 
     This class keeps a pointer to the inputs and outputs, and also modifies
     them.
 
-    #TODO: document what variables are[not] set in the FunctionGraph when a
-    feature is added via the constructor. How constructed is the
-    FunctionGraph?
-
     Parameters
     ----------
     inputs
@@ -105,20 +99,28 @@ class FunctionGraph(utils.object2):
 
         Parameters
         ----------
-        inputs : list of variables
+        inputs : list of theano.gof.graph.Variable
             Inputs nodes of the graph, usually declared by the user
-        outputs : list of variables
+        outputs : list of theano.gof.graph.Variable
             Outputs nodes of the graph.
         clone : boolean
             If true, we will clone the graph. This is useful to remove the
             constant cache problem.
-        update_mapping : dictionary
+        features : list of theano.gof.toolbox.Feature
+            A list of features to be added to the `FunctionGraph`.
+        update_mapping : dict
             Mapping between the inputs with updates and the outputs
             corresponding to their updates.
         """
 
         if clone:
-            inputs, outputs = graph.clone(inputs, outputs)
+            inputs, outputs = clone_graph(inputs, outputs)
+
+        if not isinstance(inputs, list):
+            raise TypeError("Argument `inputs` should be a list")
+
+        if not isinstance(outputs, list):
+            raise TypeError("Argument `outputs` should be a list")
 
         self.execute_callbacks_time = 0
         self.execute_callbacks_times = {}
@@ -126,8 +128,6 @@ class FunctionGraph(utils.object2):
         if features is None:
             features = []
 
-        # XXX: Unless I'm missing something (but there's no documentation,
-        # so I probably am) this should be a set.
         self._features = []
 
         # All apply nodes in the subgraph defined by inputs and
@@ -139,69 +139,83 @@ class FunctionGraph(utils.object2):
         # outputs even if they aren't used in the graph.
         self.variables = set()
 
-        self.inputs = list(inputs)
+        # TODO FIXME: We should *not* be using a list created elsewhere!
         self.outputs = outputs
+        self.clients = {}
 
         for f in features:
             self.attach_feature(f)
+
         self.attach_feature(toolbox.ReplaceValidate())
 
-        for input in self.inputs:
-            if input.owner is not None:
+        self.inputs = []
+        for in_var in inputs:
+            if in_var.owner is not None:
                 raise ValueError(
-                    "One of the provided inputs is the output of"
+                    "One of the provided inputs is the output of "
                     "an already existing node. "
                     "If that is okay, either discard that "
                     "input's owner or use graph.clone."
                 )
-            self.__setup_r__(input)
-            self.variables.add(input)
+
+            self.add_input(in_var, check=False)
 
         for output in outputs:
-            self.__import_r__(output, reason="init")
+            self.import_var(output, reason="init")
         for i, output in enumerate(outputs):
-            output.clients.append(("output", i))
+            self.clients[output].append(("output", i))
 
         self.profile = None
         self.update_mapping = update_mapping
 
-    def add_input(self, input):
-        if input not in self.inputs:
-            self.inputs.append(input)
-            self.__setup_r__(input)
-            self.variables.add(input)
+    def add_input(self, var, check=True):
+        """Add a new variable as an input to this `FunctionGraph`.
 
-    def __setup_r__(self, r):
-        if hasattr(r, "fgraph") and r.fgraph is not None and r.fgraph is not self:
-            raise Exception("%s is already owned by another fgraph" % r)
-        r.fgraph = self
-        r.clients = []
-        # self.execute_callbacks('on_setup_variable', r)
+        Parameters
+        ----------
+        var : theano.gof.graph.Variable
 
-    def __setup_node__(self, node):
-        # sets up node so it belongs to this fgraph
-        if hasattr(node, "fgraph") and node.fgraph is not self:
-            raise Exception("%s is already owned by another fgraph" % node)
+        """
+        if check and var in self.inputs:
+            return
+
+        self.inputs.append(var)
+        self.setup_var(var)
+        self.variables.add(var)
+
+    def setup_var(self, var):
+        """Set up a variable so it belongs to this `FunctionGraph`.
+
+        Parameters
+        ----------
+        var : theano.gof.graph.Variable
+
+        """
+        self.clients.setdefault(var, [])
+
+    def setup_node(self, node):
+        """Set up node so it belongs to this `FunctionGraph`.
+
+        Parameters
+        ----------
+        node : theano.gof.graph.Apply
+
+        """
         if hasattr(node.op, "view_map") and not all(
             isinstance(view, (list, tuple)) for view in node.op.view_map.values()
         ):
             raise Exception(
-                "Op '%s' have a bad view map '%s',"
+                f"Op '{node.op}' have a bad view map '{node.op.view_map}',"
                 " the values must be tuples or lists."
-                % (str(node.op), str(node.op.view_map))
             )
         if hasattr(node.op, "destroy_map") and not all(
             isinstance(destroy, (list, tuple))
             for destroy in node.op.destroy_map.values()
         ):
             raise Exception(
-                "Op '%s' have a bad destroy map '%s',"
+                f"Op '{node.op}' have a bad destroy map '{node.op.destroy_map}',"
                 " the values must be tuples or lists."
-                % (str(node.op), str(node.op.destroy_map))
             )
-        node.fgraph = self
-        node.deps = {}
-        # self.execute_callbacks('on_setup_node', node)
 
     def disown(self):
         """
@@ -213,12 +227,7 @@ class FunctionGraph(utils.object2):
         """
         for f in self._features:
             self.remove_feature(f)
-        for apply_node in self.apply_nodes:
-            del apply_node.fgraph
-            del apply_node.deps
-        for variable in self.variables:
-            del variable.fgraph
-            del variable.clients
+        self.clients = {}
         self.apply_nodes = set()
         self.variables = set()
         self.inputs = None
@@ -226,125 +235,128 @@ class FunctionGraph(utils.object2):
         self.profile = None
         self.update_mapping = None
 
-    # clients #
-    def clients(self, r):
-        """
-        Set of all the (node, i) pairs such that node.inputs[i] is r.
-        Told differently, a list of (node,i) such that each node have
-        r as input at index i.
+    def get_clients(self, var):
+        """Return a list of all the `(node, i)` pairs such that `node.inputs[i]` is `var`."""
+        return self.clients[var]
 
-        """
-        return r.clients
-
-    def __add_client__(self, r, new_client):
-        """
-        Updates the list of clients of r with new_clients.
+    def add_client(self, var, new_client):
+        """Update the clients of `var` with `new_clients`.
 
         Parameters
         ----------
-        r
-            Variable.
-        new_client
-            (node, i) pair such that node.inputs[i] is r.
+        var : Variable.
+        new_client : (Apply, int)
+            A `(node, i)` pair such that `node.inputs[i]` is `var`.
 
         """
-        # Ne need to do the assert as it is always True. The logic
-        # that call __add_client__ is valid. When the client list is
-        # long, the check it time consuming, so we don't enable it by
-        # default.
-        # assert not new_client in r.clients
-        r.clients.append(new_client)
+        self.clients[var].append(new_client)
 
-    def __remove_client__(self, r, client_to_remove, reason=None):
-        """
-        Removes all from the clients list of r.
+    def remove_client(self, var, client_to_remove, reason=None):
+        """Recursively removes clients of a variable.
 
-        This is the main method to remove variable or apply node from
-        an FunctionGraph.
+        This is the main method to remove variables or `Apply` nodes from
+        a `FunctionGraph`.
 
-        Remove r from this fgraph if it don't have clients left. If it
-        have an owner and all the outputs of the owner have no
-        clients, it will be removed.
+        This will remove `var` from the `FunctionGraph` if it doesn't have any
+        clients remaining. If it has an owner and all the outputs of the owner
+        have no clients, it will also be removed.
 
         Parameters
         ----------
-        r : Variable
-            The clients of r will be removed.
-        client_to_remove : (op, i) pair
-            (op, i) pair such that node.inputs[i] is not r anymore.
+        var : Variable
+            The clients of `var` that will be removed.
+        client_to_remove : pair of (Apply, int)
+            A `(node, i)` pair such that `node.inputs[i]` will no longer be
+            `var` in this `FunctionGraph`.
 
         """
-        l = [(r, client_to_remove)]
-        while l:
-            r, client_to_remove = l.pop()
-            r.clients.remove(client_to_remove)
-            # entry should be uniq in r. No need to assert it as it is
-            # already asserted in __add_client__.
-            # assert entry not in r.clients
-            if r.clients:
+
+        removal_stack = [(var, client_to_remove)]
+        while removal_stack:
+            var, client_to_remove = removal_stack.pop()
+
+            try:
+                var_clients = self.clients[var]
+                var_clients.remove(client_to_remove)
+            except ValueError:
+                # In this case, the original `var` could've been removed from
+                # the current `var`'s client list before this call.
+                # There's nothing inherently wrong with that, so we continue as
+                # if it were removed here.
+                var_clients = None
+
+            if var_clients:
                 continue
 
-            # r have no more clients, so check if we need to remove it
-            # and its parent.
-            variable = r
-            if not variable.owner:
-                # A Constant or input without client. Remove it.
-                self.variables.remove(variable)
-                # This allow to quickly know if a var is still in the fgraph
-                # or not.
-                del variable.fgraph
+            # Now, `var` has no more clients, so check if we need to remove it
+            # and its `Apply` node
+            if not var.owner:
+                # The `var` is a `Constant` or an input without a client, so we
+                # remove it
+                self.variables.remove(var)
             else:
-                apply_node = variable.owner
-                used = [output for output in apply_node.outputs if output.clients]
-                # If the apply node is not used and is not an output
-                if not used:
+                apply_node = var.owner
+                if not any(
+                    output for output in apply_node.outputs if self.clients[output]
+                ):
+                    # The `Apply` node is not used and is not an output, so we
+                    # remove it and its outputs
                     if not hasattr(apply_node.tag, "removed_by"):
                         apply_node.tag.removed_by = []
+
                     apply_node.tag.removed_by.append(str(reason))
+
                     self.apply_nodes.remove(apply_node)
-                    # del apply_node.fgraph
+
                     self.variables.difference_update(apply_node.outputs)
-                    # for var in apply_node.outputs:
-                    #     del var.fgraph
+
                     self.execute_callbacks("on_prune", apply_node, reason)
 
-                    for i, input in enumerate(apply_node.inputs):
-                        l.append((input, (apply_node, i)))
+                    for i, in_var in enumerate(apply_node.inputs):
+                        removal_stack.append((in_var, (apply_node, i)))
 
-    def __import_r__(self, variable, reason):
-        """
-        Import variables to this FunctionGraph and also their apply_node,
-        if those nodes are not in this graph.
+    def import_var(self, var, reason):
+        """Import variables into this `FunctionGraph`.
+
+        This will also import the `variable`'s `Apply` node.
 
         Parameters:
         ----------
-        reason
-            reason is the name of the optimization or operation in progress.
+        variable : theano.gof.graph.Variable
+            The variable to be imported.
+        reason : str
+            The name of the optimization or operation in progress.
         """
         # Imports the owners of the variables
-        if variable.owner and variable.owner not in self.apply_nodes:
-            self.__import__(variable.owner, reason=reason)
+        if var.owner and var.owner not in self.apply_nodes:
+            self.import_node(var.owner, reason=reason)
         elif (
-            variable.owner is None
-            and not isinstance(variable, graph.Constant)
-            and variable not in self.inputs
+            var.owner is None
+            and not isinstance(var, Constant)
+            and var not in self.inputs
         ):
-            global NullType
-            if NullType is None:
-                from .null_type import NullType
-            if isinstance(variable.type, NullType):
-                raise TypeError(
-                    "Computation graph contains a NaN. " + variable.type.why_null
-                )
-            raise MissingInputError("Undeclared input", variable=variable)
-        if not getattr(variable, "fgraph", None) is self:
-            self.__setup_r__(variable)
-        self.variables.add(variable)
+            from theano.gof.null_type import NullType
 
-    def __import__(self, apply_node, check=True, reason=None):
-        """
-        Given an apply_node, recursively search from this node to know graph,
-        and then add all unknown variables and apply_nodes to this graph.
+            if isinstance(var.type, NullType):
+                raise TypeError(
+                    "Computation graph contains a NaN. " + var.type.why_null
+                )
+            raise MissingInputError("Undeclared input", variable=var)
+        self.setup_var(var)
+        self.variables.add(var)
+
+    def import_node(self, apply_node, check=True, reason=None):
+        """Recursively import everything between an `Apply` node and the `FunctionGraph`'s outputs.
+
+        Parameters:
+        ----------
+        apply_node : theano.gof.graph.Apply
+            The node to be imported.
+        check : bool
+            Check that the inputs for the imported nodes are also present in
+            the `FunctionGraph`.
+        reason : str
+            The name of the optimization or operation in progress.
         """
         node = apply_node
 
@@ -352,124 +364,128 @@ class FunctionGraph(utils.object2):
         # in new nodes, so we use all variables we know of as if they were the input set.
         # (the functions in the graph module only use the input set to
         # know where to stop going down)
-        new_nodes = graph.io_toposort(self.variables, apply_node.outputs)
+        new_nodes = io_toposort(self.variables, apply_node.outputs)
 
         if check:
             for node in new_nodes:
-                if hasattr(node, "fgraph") and node.fgraph is not self:
-                    raise Exception("%s is already owned by another fgraph" % node)
-                for r in node.inputs:
-                    if hasattr(r, "fgraph") and r.fgraph is not self:
-                        raise Exception("%s is already owned by another fgraph" % r)
+                for var in node.inputs:
                     if (
-                        r.owner is None
-                        and not isinstance(r, graph.Constant)
-                        and r not in self.inputs
+                        var.owner is None
+                        and not isinstance(var, Constant)
+                        and var not in self.inputs
                     ):
                         # Standard error message
                         error_msg = (
-                            "Input %d of the graph (indices start "
-                            "from 0), used to compute %s, was not "
+                            f"Input {int(node.inputs.index(var))} of the graph (indices start "
+                            f"from 0), used to compute {node}, was not "
                             "provided and not given a value. Use the "
                             "Theano flag exception_verbosity='high', "
                             "for more information on this error."
-                            % (node.inputs.index(r), str(node))
                         )
-                        raise MissingInputError(error_msg, variable=r)
+                        raise MissingInputError(error_msg, variable=var)
 
         for node in new_nodes:
             assert node not in self.apply_nodes
-            self.__setup_node__(node)
+            self.setup_node(node)
             self.apply_nodes.add(node)
             if not hasattr(node.tag, "imported_by"):
                 node.tag.imported_by = []
             node.tag.imported_by.append(str(reason))
             for output in node.outputs:
-                self.__setup_r__(output)
+                self.setup_var(output)
                 self.variables.add(output)
             for i, input in enumerate(node.inputs):
                 if input not in self.variables:
-                    self.__setup_r__(input)
+                    self.setup_var(input)
                     self.variables.add(input)
-                self.__add_client__(input, (node, i))
-            assert node.fgraph is self
+                self.add_client(input, (node, i))
             self.execute_callbacks("on_import", node, reason)
 
-    # change input #
-    def change_input(self, node, i, new_r, reason=None):
-        """
-        Changes node.inputs[i] to new_r.
+    def change_input(self, node, i, new_var, reason=None):
+        """Change ``node.inputs[i]`` to `new_var`.
 
-        new_r.type == old_r.type must be True, where old_r is the
-        current value of node.inputs[i] which we want to replace.
+        ``new_var.type == old_var.type`` must be ``True``, where ``old_var`` is the
+        current value of ``node.inputs[i]`` which we want to replace.
 
-        For each feature that has a 'on_change_input' method, calls:
-        feature.on_change_input(function_graph, node, i, old_r, new_r, reason)
+        For each feature that has an `on_change_input` method, this method calls:
+        ``feature.on_change_input(function_graph, node, i, old_var, new_var, reason)``
+
+        Parameters
+        ----------
+        node : theano.gof.graph.Apply or str
+            The node for which an input is to be changed.  If the value is
+            the string ``"output"`` then the ``self.outputs`` will be used
+            instead of ``node.inputs``.
+        i : int
+            The index in `node.inputs` that we want to change.
+        new_var : theano.gof.graph.Variable
+            The new variable to take the place of ``node.inputs[i]``.
 
         """
         # TODO: ERROR HANDLING FOR LISTENERS (should it complete the change or revert it?)
         if node == "output":
             r = self.outputs[i]
-            if not r.type == new_r.type:
+            if not r.type == new_var.type:
                 raise TypeError(
                     "The type of the replacement must be the"
                     " same as the type of the original Variable.",
                     r,
-                    new_r,
+                    new_var,
                 )
-            self.outputs[i] = new_r
+            self.outputs[i] = new_var
         else:
-            if node.fgraph is not self:
-                raise Exception(
-                    "Cannot operate on %s because it does not"
-                    " belong to this FunctionGraph" % node
-                )
             r = node.inputs[i]
-            if not r.type == new_r.type:
+            if not r.type == new_var.type:
                 raise TypeError(
                     "The type of the replacement must be the"
                     " same as the type of the original Variable.",
                     r,
-                    new_r,
+                    new_var,
                 )
-            node.inputs[i] = new_r
+            node.inputs[i] = new_var
 
-        if r is new_r:
+        if r is new_var:
             return
 
-        self.__import_r__(new_r, reason=reason)
-        self.__add_client__(new_r, (node, i))
-        self.__remove_client__(r, (node, i), reason=reason)
+        self.import_var(new_var, reason=reason)
+        self.add_client(new_var, (node, i))
+        self.remove_client(r, (node, i), reason=reason)
         # Precondition: the substitution is semantically valid
         # However it may introduce cycles to the graph,  in which case the
         # transaction will be reverted later.
-        self.execute_callbacks("on_change_input", node, i, r, new_r, reason=reason)
+        self.execute_callbacks("on_change_input", node, i, r, new_var, reason=reason)
 
-    # replace #
-    def replace(self, r, new_r, reason=None, verbose=None):
-        """
-        This is the main interface to manipulate the subgraph in FunctionGraph.
-        For every node that uses r as input, makes it use new_r instead.
+    def replace(self, var, new_var, reason=None, verbose=None):
+        """Replace a variable in the `FunctionGraph`.
+
+        This is the main interface to manipulate the subgraph in `FunctionGraph`.
+        For every node that uses `var` as input, makes it use `new_var` instead.
+
+        Parameters:
+        ----------
+        var : theano.gof.graph.Variable
+            The variable to be replaced.
+        new_var : theano.gof.graph.Variable
+            The variable to replace `var`.
+        reason : str
+            The name of the optimization or operation in progress.
+        verbose : bool
+            Print `reason`, `var`, and `new_var`.
 
         """
         if verbose is None:
             verbose = config.optimizer_verbose
         if verbose:
-            print(reason, r, new_r)
-        if hasattr(r, "fgraph") and r.fgraph is not self:
-            raise Exception(
-                "Cannot replace %s because it does not belong "
-                "to this FunctionGraph" % r,
-                str(reason),
-            )
-        if r.type != new_r.type:
-            new_r2 = r.type.convert_variable(new_r)
+            print(reason, var, new_var)
+
+        if var.type != new_var.type:
+            new_var_2 = var.type.convert_variable(new_var)
             # We still make sure that the type converts correctly
-            if new_r2 is None or new_r2.type != r.type:
+            if new_var_2 is None or new_var_2.type != var.type:
                 done = dict()
                 used_ids = dict()
                 old = theano.compile.debugmode.debugprint(
-                    r,
+                    var,
                     prefix="  ",
                     depth=6,
                     file=StringIO(),
@@ -478,7 +494,7 @@ class FunctionGraph(utils.object2):
                     used_ids=used_ids,
                 ).getvalue()
                 new = theano.compile.debugmode.debugprint(
-                    new_r,
+                    new_var,
                     prefix="  ",
                     depth=6,
                     file=StringIO(),
@@ -487,16 +503,17 @@ class FunctionGraph(utils.object2):
                     used_ids=used_ids,
                 ).getvalue()
                 raise toolbox.BadOptimization(
-                    r,
-                    new_r,
+                    var,
+                    new_var,
                     None,
                     None,
                     str(reason) + ". The type of the replacement must be the same.",
                     old,
                     new,
                 )
-            new_r = new_r2
-        if r not in self.variables:
+            new_var = new_var_2
+
+        if var not in self.variables:
             # this variable isn't in the graph... don't raise an
             # exception here, just return silently because it makes it
             # easier to implement some optimizations for
@@ -505,8 +522,8 @@ class FunctionGraph(utils.object2):
 
         if theano.config.compute_test_value != "off":
             try:
-                tval = theano.gof.op.get_test_value(r)
-                new_tval = theano.gof.op.get_test_value(new_r)
+                tval = theano.gof.op.get_test_value(var)
+                new_tval = theano.gof.op.get_test_value(new_var)
             except TestValueError:
                 pass
             else:
@@ -516,29 +533,19 @@ class FunctionGraph(utils.object2):
                     raise AssertionError(
                         "The replacement variable has a test value with "
                         "a shape different from the original variable's "
-                        "test value. Original: %s, new: %s"
-                        % (tval_shape, new_tval_shape),
-                        r,
-                        new_r,
-                        str(reason),
+                        f"test value. Original: {tval_shape}, new: {new_tval_shape}"
                     )
 
-        for node, i in list(r.clients):  # copy the client list for iteration
-            assert (node == "output" and self.outputs[i] is r) or (node.inputs[i] is r)
-            self.change_input(node, i, new_r, reason=reason)
-
-        # sometimes the following is triggered.  If you understand why, please explain to James.
-        # He's curious... -JB20090331
-        # if len(r.clients) != 0:
-        #    print >> sys.stderr, "WARNING: CLIENTS LEFT AFTER REPLACE", r, r.clients
+        for node, i in list(self.clients[var]):
+            assert (node == "output" and self.outputs[i] is var) or (
+                node.inputs[i] is var
+            )
+            self.change_input(node, i, new_var, reason=reason)
 
     def replace_all(self, pairs, reason=None):
-        """
-        For every node that uses r as input, makes it use new_r instead
-
-        """
-        for r, new_r in pairs:
-            self.replace(r, new_r, reason=reason)
+        """Replace variables in the `FunctionGraph` according to `(var, new_var)` pairs in a list."""
+        for var, new_var in pairs:
+            self.replace(var, new_var, reason=reason)
 
     def attach_feature(self, feature):
         """
@@ -587,7 +594,6 @@ class FunctionGraph(utils.object2):
         if detach is not None:
             detach(self)
 
-    # callback utils #
     def execute_callbacks(self, name, *args, **kwargs):
         """Execute callbacks
 
@@ -625,7 +631,6 @@ class FunctionGraph(utils.object2):
             d[feature] = fn(*args)
         return d
 
-    # misc #
     def toposort(self):
         """Toposort
 
@@ -650,22 +655,21 @@ class FunctionGraph(utils.object2):
 
         ords = self.orderings()
 
-        order = graph.io_toposort(fg.inputs, fg.outputs, ords)
+        order = io_toposort(fg.inputs, fg.outputs, ords)
 
         return order
 
     def orderings(self):
-        """
-        Return dict d s.t. d[node] is a list of nodes that must be evaluated
-        before node itself can be evaluated.
+        """Return `dict` `d` s.t. `d[node]` is a list of nodes that must be evaluated before `node` itself can be evaluated.
 
         This is used primarily by the destroy_handler feature to ensure that
-        all clients of any destroyed inputs have already computed their outputs.
+        the clients of any destroyed inputs have already computed their
+        outputs.
 
         Notes
         -----
-        This only calls the orderings() fct on all features. It does not
-        take care of computing dependencies by itself.
+        This only calls the `orderings()` function on all features. It does not
+        take care of computing the dependencies by itself.
 
         """
         assert isinstance(self._features, list)
@@ -706,7 +710,7 @@ class FunctionGraph(utils.object2):
         Call this for a diagnosis if things go awry.
 
         """
-        nodes = graph.ops(self.inputs, self.outputs)
+        nodes = ops_between(self.inputs, self.outputs)
         if self.apply_nodes != nodes:
             missing = nodes.difference(self.apply_nodes)
             excess = self.apply_nodes.difference(nodes)
@@ -716,20 +720,13 @@ class FunctionGraph(utils.object2):
                 excess,
             )
         for node in nodes:
-            if node.fgraph is not self:
-                raise Exception("Node should belong to the FunctionGraph.", node)
             for i, variable in enumerate(node.inputs):
-                if variable.fgraph is not self:
+                clients = self.clients[variable]
+                if (node, i) not in clients:
                     raise Exception(
-                        "Input of node should belong to the FunctionGraph.",
-                        variable,
-                        (node, i),
+                        f"Inconsistent clients list {(node, i)} in {clients}"
                     )
-                if (node, i) not in variable.clients:
-                    raise Exception(
-                        "Inconsistent clients list.", (node, i), variable.clients
-                    )
-        variables = set(graph.variables(self.inputs, self.outputs))
+        variables = set(variables_between(self.inputs, self.outputs))
         if set(self.variables) != variables:
             missing = variables.difference(self.variables)
             excess = self.variables.difference(variables)
@@ -742,34 +739,28 @@ class FunctionGraph(utils.object2):
             if (
                 variable.owner is None
                 and variable not in self.inputs
-                and not isinstance(variable, graph.Constant)
+                and not isinstance(variable, Constant)
             ):
-                raise Exception("Undeclared input.", variable)
-            if variable.fgraph is not self:
-                raise Exception(
-                    "Variable should belong to the FunctionGraph.", variable
-                )
-            for node, i in variable.clients:
+                raise Exception(f"Undeclared input: {variable}")
+            for node, i in self.clients[variable]:
                 if node == "output":
                     if self.outputs[i] is not variable:
                         raise Exception(
-                            "Inconsistent clients list.", variable, self.outputs[i]
+                            f"Inconsistent clients list: {variable}, {self.outputs[i]}"
                         )
                     continue
                 if node not in nodes:
-                    raise Exception("Client not in FunctionGraph.", variable, (node, i))
+                    raise Exception(
+                        f"Client not in FunctionGraph: {variable}, {(node, i)}"
+                    )
                 if node.inputs[i] is not variable:
                     raise Exception(
-                        "Inconsistent clients list.", variable, node.inputs[i]
+                        f"Inconsistent clients list: {variable}, {node.inputs[i]}"
                     )
 
-    def __str__(self):
-        return "[%s]" % ", ".join(graph.as_string(self.inputs, self.outputs))
-
     def __repr__(self):
-        return self.__str__()
+        return f"FunctionGraph({', '.join(graph_as_string(self.inputs, self.outputs))})"
 
-    # clone #
     def clone(self, check_integrity=True):
         """
         Clone the graph and get a memo( a dict )that map old node to new node
@@ -793,7 +784,7 @@ class FunctionGraph(utils.object2):
             equiv: dict
                 A dict that map old node to new node.
         """
-        equiv = graph.clone_get_equiv(self.inputs, self.outputs)
+        equiv = clone_get_equiv(self.inputs, self.outputs)
 
         if check_integrity:
             self.check_integrity()
@@ -834,3 +825,11 @@ class FunctionGraph(utils.object2):
         for feature in self._features:
             if hasattr(feature, "unpickle"):
                 feature.unpickle(self)
+
+    def __contains__(self, item):
+        if isinstance(item, Variable):
+            return item in self.variables
+        elif isinstance(item, Apply):
+            return item in self.apply_nodes
+        else:
+            raise TypeError()
