@@ -30,10 +30,8 @@ class Node(object2):
     """A `Node` in a Theano graph.
 
     Currently, graphs contain two kinds of `Nodes`: `Variable`s and `Apply`s.
-    Edges in the graph are not explicitly represented.
-    Instead each `Node` keeps track of its parents via
-    `Variable.owner` / `Apply.inputs` and its children
-    via Variable.clients / Apply.outputs.
+    Edges in the graph are not explicitly represented.  Instead each `Node`
+    keeps track of its parents via `Variable.owner` / `Apply.inputs`.
 
     """
 
@@ -108,8 +106,7 @@ class Apply(Node):
                 self.inputs.append(input)
             else:
                 raise TypeError(
-                    "The 'inputs' argument to Apply must contain Variable instances, not %s"
-                    % input
+                    f"The 'inputs' argument to Apply must contain Variable instances, not {input}"
                 )
         self.outputs = []
         # filter outputs to make sure each element is a Variable
@@ -125,8 +122,7 @@ class Apply(Node):
                 self.outputs.append(output)
             else:
                 raise TypeError(
-                    "The 'outputs' argument to Apply must contain Variable instances with no owner, not %s"
-                    % output
+                    f"The 'outputs' argument to Apply must contain Variable instances with no owner, not {output}"
                 )
 
     def run_params(self):
@@ -169,13 +165,11 @@ class Apply(Node):
             if len(self.outputs) == 1:
                 return self.outputs[0]
             else:
-                raise ValueError(
-                    "%s.default_output should be an output index." % self.op
-                )
+                raise ValueError(f"{self.op}.default_output should be an output index.")
         elif not isinstance(do, int):
-            raise ValueError("%s.default_output should be an int or long" % self.op)
+            raise ValueError(f"{self.op}.default_output should be an int or long")
         elif do < 0 or do >= len(self.outputs):
-            raise ValueError("%s.default_output is out of range." % self.op)
+            raise ValueError(f"{self.op}.default_output is out of range.")
         return self.outputs[do]
 
     out = property(default_output, doc="alias for self.default_output()")
@@ -291,46 +285,46 @@ class Variable(Node):
     - :literal:`type` a `Type` instance defining the kind of value this
       `Variable` can have,
 
-    - :literal:`owner` either None (for graph roots) or the `Apply` instance
+    - :literal:`owner` either `None` (for graph roots) or the `Apply` instance
       of which `self` is an output,
 
     - :literal:`index` the integer such that :literal:`owner.outputs[index] is
-      this_variable` (ignored if `owner` is None),
+      this_variable` (ignored if `owner` is `None`),
 
     - :literal:`name` a string to use in pretty-printing and debugging.
 
-    There are a few kinds of Variables to be aware of: A Variable which is the
-    output of a symbolic computation has a reference to the Apply instance to
+    There are a few kinds of `Variable`s to be aware of: A `Variable` which is the
+    output of a symbolic computation has a reference to the `Apply` instance to
     which it belongs (property: owner) and the position of itself in the owner's
     output list (property: index).
 
     - `Variable` (this base type) is typically the output of a symbolic
       computation.
 
-    - `Constant` (a subclass) which adds a default and un-replaceable
+    - `Constant`: a subclass which adds a default and un-replaceable
       :literal:`value`, and requires that owner is None.
 
-    - `TensorVariable` subclass of Variable that represents a numpy.ndarray
+    - `TensorVariable` subclass of `Variable` that represents a `numpy.ndarray`
        object.
 
-    - `TensorSharedVariable` Shared version of TensorVariable.
+    - `TensorSharedVariable`: a shared version of `TensorVariable`.
 
-    - `SparseVariable` subclass of Variable that represents
-      a scipy.sparse.{csc,csr}_matrix object.
+    - `SparseVariable`: a subclass of `Variable` that represents
+      a `scipy.sparse.{csc,csr}_matrix` object.
 
-    - `GpuArrayVariable` subclass of Variable that represents our object on
-      the GPU that is a subset of numpy.ndarray.
+    - `GpuArrayVariable`: a subclass of `Variable` that represents our object on
+      the GPU that is a subset of `numpy.ndarray`.
 
     - `RandomVariable`.
 
-    A Variable which is the output of a symbolic computation will have an owner
+    A `Variable` which is the output of a symbolic computation will have an owner
     not equal to None.
 
-    Using the Variables' owner field and the Apply nodes' inputs fields, one can
-    navigate a graph from an output all the way to the inputs. The opposite
-    direction is not possible until a FunctionGraph has annotated the Variables
-    with the clients field, ie, before the compilation process has begun a
-    Variable does not know which Apply nodes take it as input.
+    Using the `Variables`' owner field and the `Apply` nodes' inputs fields,
+    one can navigate a graph from an output all the way to the inputs. The
+    opposite direction is possible with a `FunctionGraph` and its
+    `FunctionGraph.clients` `dict`, which maps `Variable`s to a list of their
+    clients.
 
     Parameters
     ----------
@@ -411,9 +405,7 @@ class Variable(Node):
         """
         if not hasattr(self.tag, "test_value"):
             detailed_err_msg = get_variable_trace_string(self)
-            raise TestValueError(
-                "{} has no test value {}".format(self, detailed_err_msg)
-            )
+            raise TestValueError(f"{self} has no test value {detailed_err_msg}")
 
         return self.tag.test_value
 
@@ -428,7 +420,7 @@ class Variable(Node):
             else:
                 return str(self.owner.op) + "." + str(self.index)
         else:
-            return "<%s>" % str(self.type)
+            return f"<{self.type}>"
 
     def __repr_test_value__(self):
         """Return a repr of the test value.
@@ -559,8 +551,7 @@ class Variable(Node):
             if not type(config).pickle_test_value.is_default:
                 warnings.warn(
                     "pickle_test_value is not defaut value (True).\n"
-                    "Test value of variable %s(%s) will not be dumped."
-                    % (d["auto_name"], d["name"])
+                    f"Test value of variable {d['auto_name']}({d['name']}) will not be dumped."
                 )
             t = copy(d["tag"])
             del t.test_value
@@ -1150,7 +1141,7 @@ default_leaf_formatter = str
 
 
 def default_node_formatter(op, argstrings):
-    return "{}({})".format(op.op, ", ".join(argstrings))
+    return f"{op.op}({', '.join(argstrings)})"
 
 
 def io_connection_pattern(inputs, outputs):
@@ -1297,14 +1288,14 @@ def as_string(
             if len(op.outputs) == 1:
                 idxs = ""
             else:
-                idxs = "::%i" % idx
+                idxs = f"::{idx}"
             if op in done:
-                return "*%i%s" % (multi_index(op), idxs)
+                return f"*{multi_index(op)}{idxs}"
             else:
                 done.add(op)
                 s = node_formatter(op, [describe(input) for input in op.inputs])
                 if op in multi:
-                    return "*%i -> %s" % (multi_index(op), s)
+                    return f"*{multi_index(op)} -> {s}"
                 else:
                     return s
         else:
