@@ -62,7 +62,7 @@ try:
             if os.path.exists(init_file):
                 pass  # has already been created
             else:
-                e.args += ("{} exist? {}".format(location, os.path.exists(location)),)
+                e.args += (f"{location} exist? {os.path.exists(location)}",)
                 raise
 
     _need_reload = False
@@ -75,9 +75,8 @@ try:
         if version != actual_version:
             raise ImportError(
                 "Version check of the existing lazylinker compiled file."
-                " Looking for version %s, but found %s. "
-                "Extra debug information: force_compile=%s, _need_reload=%s"
-                % (version, actual_version, force_compile, _need_reload)
+                f" Looking for version {version}, but found {actual_version}. "
+                f"Extra debug information: force_compile={force_compile}, _need_reload={_need_reload}"
             )
 except ImportError:
     get_lock()
@@ -98,10 +97,8 @@ except ImportError:
             if version != actual_version:
                 raise ImportError(
                     "Version check of the existing lazylinker compiled file."
-                    " Looking for version %s, but found %s. "
-                    "Extra debug information: force_compile=%s,"
-                    " _need_reload=%s"
-                    % (version, actual_version, force_compile, _need_reload)
+                    f" Looking for version {version}, but found {actual_version}. "
+                    f"Extra debug information: force_compile={force_compile}, _need_reload={_need_reload}"
                 )
         except ImportError:
             # It is useless to try to compile if there isn't any
@@ -140,7 +137,7 @@ except ImportError:
             # Save version into the __init__.py file.
             init_py = os.path.join(loc, "__init__.py")
             with open(init_py, "w") as f:
-                f.write("_version = %s\n" % version)
+                f.write(f"_version = {version}\n")
             # If we just compiled the module for the first time, then it was
             # imported at the same time: we need to make sure we do not
             # reload the now outdated __init__.pyc below.
@@ -152,7 +149,7 @@ except ImportError:
             from lazylinker_ext import lazylinker_ext as lazy_c
 
             assert lazylinker_ext._version == lazy_c.get_version()
-            _logger.info("New version %s", lazylinker_ext._version)
+            _logger.info(f"New version {lazylinker_ext._version}")
     finally:
         # Release lock on compilation directory.
         release_lock()
