@@ -3,6 +3,7 @@ import traceback
 from copy import copy, deepcopy
 from io import StringIO
 from sys import getsizeof
+from warnings import warn
 
 import numpy as np
 
@@ -25,7 +26,7 @@ def log_thunk_trace(value, f=sys.stderr):
     # in future, consider accepting `write` as arg rather than file
     # to support writing to a logger
     def write(msg):
-        print("log_thunk_trace: %s" % msg.strip(), file=f)
+        print(f"log_thunk_trace: {msg.strip()}", file=f)
 
     if hasattr(value, "__thunk_trace__"):
         trace2 = value.__thunk_trace__
@@ -46,7 +47,7 @@ def log_thunk_trace(value, f=sys.stderr):
                 write(line)
             write(
                 "For the full definition stack trace set"
-                " the Theano flags traceback.limit to -1"
+                " the Theano flags traceback__limit to -1"
             )
 
 
@@ -83,7 +84,7 @@ sys.excepthook = thunk_hook
 
 
 # TODO: Make this work with linker defined schedule
-def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
+def raise_with_op(fgraph, node, thunk=None, exc_info=None, storage_map=None):
     """
     Re-raise an exception while annotating the exception object with
     debug info.
@@ -132,7 +133,7 @@ def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
             trace = ()
     exc_value.__thunk_trace__ = trace
     exc_value.__op_instance__ = node
-    topo = node.fgraph.toposort()
+    topo = fgraph.toposort()
     if node in topo:
         node_index = topo.index(node)
     else:
@@ -142,10 +143,10 @@ def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
     hints = []
     detailed_err_msg = "\nApply node that caused the error: " + str(node)
     if exc_value.__applynode_index__ is not None:
-        detailed_err_msg += "\nToposort index: %d" % node_index
+        detailed_err_msg += f"\nToposort index: {int(node_index)}"
 
     types = [getattr(ipt, "type", "No type") for ipt in node.inputs]
-    detailed_err_msg += "\nInputs types: %s\n" % types
+    detailed_err_msg += f"\nInputs types: {types}\n"
 
     if thunk is not None:
         if hasattr(thunk, "inputs"):
@@ -161,20 +162,20 @@ def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
             shapes = "The thunk don't have an inputs attributes."
             strides = "So we can't access the strides of inputs values"
             scalar_values = "And can't print its inputs scalar value"
-        clients = [[c[0] for c in var.clients] for var in node.outputs]
+        clients = [[c[0] for c in fgraph.clients[var]] for var in node.outputs]
         detailed_err_msg += (
-            "Inputs shapes: %s" % shapes
-            + "\nInputs strides: %s" % strides
-            + "\nInputs values: %s" % scalar_values
+            f"Inputs shapes: {shapes}"
+            + f"\nInputs strides: {strides}"
+            + f"\nInputs values: {scalar_values}"
         )
         if theano.config.exception_verbosity == "high":
             detailed_err_msg += "\nInputs type_num: %s" % str(
                 [getattr(getattr(i[0], "dtype", ""), "num", "") for i in thunk.inputs]
             )
         if hasattr(node.op, "__input_name__"):
-            detailed_err_msg += "\nInputs name: %s\n" % str(node.op.__input_name__)
+            detailed_err_msg += f"\nInputs name: {node.op.__input_name__}\n"
 
-        detailed_err_msg += "\nOutputs clients: %s\n" % clients
+        detailed_err_msg += f"\nOutputs clients: {clients}\n"
     else:
         hints.append(
             "HINT: Use another linker then the c linker to"
@@ -184,7 +185,7 @@ def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
     # Print node backtraces
     tr = getattr(node.outputs[0].tag, "trace", [])
     if isinstance(tr, list) and len(tr) > 0:
-        detailed_err_msg += "\nBacktrace when the node is created(use Theano flag traceback.limit=N to make it longer):\n"
+        detailed_err_msg += "\nBacktrace when the node is created(use Theano flag traceback__limit=N to make it longer):\n"
 
         # Print separate message for each element in the list of batcktraces
         sio = StringIO()
@@ -212,12 +213,12 @@ def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
         detailed_err_msg += "\nStorage map footprint:\n"
         shared_input_list = [
             item
-            for item in node.fgraph.inputs
+            for item in fgraph.inputs
             if isinstance(item, theano.compile.SharedVariable)
         ]
         nonshared_input_list = [
             item
-            for item in node.fgraph.inputs
+            for item in fgraph.inputs
             if not isinstance(item, theano.compile.SharedVariable)
         ]
         storage_map_list = []
@@ -308,10 +309,10 @@ def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
             elif item[4] is False:
                 detailed_err_msg += "Input, "
             if item[1] is not None:
-                detailed_err_msg += "Shape: %s, " % str(item[1])
-            detailed_err_msg += "ElemSize: %s Byte(s)" % item[2]
+                detailed_err_msg += f"Shape: {item[1]}, "
+            detailed_err_msg += f"ElemSize: {item[2]} Byte(s)"
             if item[3] is not None:
-                detailed_err_msg += ", TotalSize: %s Byte(s)\n" % item[3]
+                detailed_err_msg += f", TotalSize: {item[3]} Byte(s)\n"
             else:
                 detailed_err_msg += "\n"
         detailed_err_msg += " TotalSize: {} Byte(s) {:.3f} GB\n".format(
@@ -334,10 +335,7 @@ def raise_with_op(node, thunk=None, exc_info=None, storage_map=None):
             str(exc_value) + detailed_err_msg + "\n" + "\n".join(hints)
         )
     except TypeError:
-        print(
-            "WARNING: %s error does not allow us to add extra error message"
-            % str(exc_type)
-        )
+        warn(f"{exc_type} error does not allow us to add extra error message")
         # Some exception need extra parameter in inputs. So forget the
         # extra long error message in that case.
     raise exc_value.with_traceback(exc_trace)
@@ -405,11 +403,7 @@ class Linker:
 
         def execute(*args):
             def e_arity(takes, got):
-                return "Function call takes exactly %i %s (%i given)" % (
-                    takes,
-                    ["argument", "arguments"][takes > 1],
-                    got,
-                )
+                return f"Function call takes exactly {takes} {['argument', 'arguments'][takes > 1]} ({got} given)"
 
             if len(args) != len(inputs):
                 raise TypeError(e_arity(len(inputs), len(args)))
@@ -482,7 +476,7 @@ class Container:
 
     def __set__(self, value):
         if self.readonly:
-            raise Exception("Cannot set readonly storage: %s" % self.name)
+            raise Exception(f"Cannot set readonly storage: {self.name}")
         try:
             if value is None:
                 self.storage[0] = None
@@ -501,7 +495,7 @@ class Container:
                 self.storage[0] = self.type.filter(value, **kwargs)
 
         except Exception as e:
-            e.args = e.args + (('Container name "%s"' % self.name),)
+            e.args = e.args + (f'Container name "{self.name}"',)
             raise
 
     data = property(__get__, __set__)
@@ -699,7 +693,7 @@ def streamline(
                     for old_s in old_storage:
                         old_s[0] = None
             except Exception:
-                raise_with_op(node, thunk)
+                raise_with_op(fgraph, node, thunk)
 
         f = streamline_default_f
     elif nice_errors:
@@ -711,7 +705,7 @@ def streamline(
                 for thunk, node in zip(thunks, order):
                     thunk()
             except Exception:
-                raise_with_op(node, thunk)
+                raise_with_op(fgraph, node, thunk)
 
         f = streamline_nice_errors_f
     else:
@@ -953,7 +947,7 @@ class WrapLinker(Linker):
         For each node in the graph, each linker will provide a
         thunk.  This class makes it possible to iterate over each linker's
         program in parallel.
-    wrapper : lambda (i, i_node, i_thunk1, i_thunk2, ...) : None
+    wrapper : lambda (fgraph, i, i_node, i_thunk1, i_thunk2, ...) : None
         Does some user-defined action for the i'th element of the program.
         i_thunk<n> is the thunk returned by the n'th linker. (If you want
         to run the program, make sure to call the necessary thunks in this
@@ -1067,9 +1061,9 @@ class WrapLinker(Linker):
             pre(self, [input.data for input in input_lists[0]], order, thunk_groups)
             for i, (thunks, node) in enumerate(zip(thunk_groups, order)):
                 try:
-                    wrapper(i, node, *thunks)
+                    wrapper(self.fgraph, i, node, *thunks)
                 except Exception:
-                    raise_with_op(node, *thunks)
+                    raise_with_op(self.fgraph, node, *thunks)
 
         f.thunk_groups = thunk_groups
 
