@@ -43,10 +43,10 @@ class DB:
             tags specified will enable that optimization.
 
         """
-        # N.B. obj is not an instance of class Optimizer.
+        # N.B. obj is not an instance of class `GlobalOptimizer`.
         # It is an instance of a DB.In the tests for example,
         # this is not always the case.
-        if not isinstance(obj, (DB, opt.Optimizer, opt.LocalOptimizer)):
+        if not isinstance(obj, (DB, opt.GlobalOptimizer, opt.LocalOptimizer)):
             raise TypeError("Object cannot be registered in OptDB", obj)
         if name in self.__db__:
             raise ValueError(
@@ -66,10 +66,9 @@ class DB:
         # something in the DB is there only once.
         if obj.name in self.__db__:
             raise ValueError(
-                """You can\'t register the same optimization
-multiple time in a DB. Tryed to register "%s" again under the new name "%s".
+                f"""You can\'t register the same optimization
+multiple time in a DB. Tryed to register "{obj.name}" again under the new name "{name}".
  Use theano.gof.ProxyDB to work around that"""
-                % (obj.name, name)
             )
         self.__db__[name] = OrderedSet([obj])
         self._names.add(name)
@@ -153,9 +152,9 @@ multiple time in a DB. Tryed to register "%s" again under the new name "%s".
     def __getitem__(self, name):
         variables = self.__db__[name]
         if not variables:
-            raise KeyError("Nothing registered for '%s'" % name)
+            raise KeyError(f"Nothing registered for '{name}'")
         elif len(variables) > 1:
-            raise ValueError("More than one match for %s (please use query)" % name)
+            raise ValueError(f"More than one match for {name} (please use query)")
         for variable in variables:
             return variable
 
@@ -163,7 +162,7 @@ multiple time in a DB. Tryed to register "%s" again under the new name "%s".
         return name in self.__db__
 
     def print_summary(self, stream=sys.stdout):
-        print("%s (id %i)" % (self.__class__.__name__, id(self)), file=stream)
+        print(f"{self.__class__.__name__} (id {id(self)})", file=stream)
         print("  names", self._names, file=stream)
         print("  db", self.__db__, file=stream)
 
@@ -286,8 +285,8 @@ class EquilibriumDB(DB):
 
     Notes
     -----
-    We can put LocalOptimizer and Optimizer as EquilibriumOptimizer
-    suppor both.
+    We can use `LocalOptimizer` and `GlobalOptimizer` since `EquilibriumOptimizer`
+    supports both.
 
     It is probably not a good idea to have ignore_newtrees=False and
     tracks_on_change_inputs=True
@@ -321,7 +320,7 @@ class EquilibriumDB(DB):
             cleanup_opts = None
         return opt.EquilibriumOptimizer(
             opts,
-            max_use_ratio=config.optdb.max_use_ratio,
+            max_use_ratio=config.optdb__max_use_ratio,
             ignore_newtrees=self.ignore_newtrees,
             tracks_on_change_inputs=self.tracks_on_change_inputs,
             failure_callback=opt.NavigatorOptimizer.warn_inplace,
@@ -374,7 +373,7 @@ class SequenceDB(DB):
         """
         opts = super().query(*tags, **kwtags)
 
-        position_cutoff = kwtags.pop("position_cutoff", config.optdb.position_cutoff)
+        position_cutoff = kwtags.pop("position_cutoff", config.optdb__position_cutoff)
         position_dict = self.__position__
 
         if len(tags) >= 1 and isinstance(tags[0], Query):
@@ -393,7 +392,7 @@ class SequenceDB(DB):
                     # class name for descriptiveness and id to avoid name
                     # collisions)
                     opt, position = extra_opt
-                    opt.name = "%s_%i" % (opt.__class__, id(opt))
+                    opt.name = f"{opt.__class__}_{id(opt)}"
 
                     # Add the extra optimization to the optimization sequence
                     if position < position_cutoff:
@@ -411,7 +410,7 @@ class SequenceDB(DB):
         return ret
 
     def print_summary(self, stream=sys.stdout):
-        print(self.__class__.__name__ + " (id %i)" % id(self), file=stream)
+        print(f"{self.__class__.__name__ } (id {id(self)})", file=stream)
         positions = list(self.__position__.items())
 
         def c(a, b):
@@ -474,7 +473,7 @@ class LocalGroupDB(DB):
 class TopoDB(DB):
     """
 
-    Generate a Global Optimizer of type TopoOptimizer.
+    Generate a `GlobalOptimizer` of type TopoOptimizer.
 
     """
 
