@@ -22,7 +22,7 @@ class AlreadyThere(Exception):
     """
 
 
-class ReplacementDidntRemovedError(Exception):
+class ReplacementDidNotRemoveError(Exception):
     """
     This exception should be thrown by replace_all_validate_remove
     when an optimization wanted to remove a Variable or a Node from
@@ -216,8 +216,8 @@ class BadOptimization(Exception):
         print("  New Graph:", file=sio)
         print(self.new_graph, file=sio)
         print("", file=sio)
-        print("Hint: relax the tolerance by setting tensor.cmp_sloppy=1", file=sio)
-        print("  or even tensor.cmp_sloppy=2 for less-strict comparison", file=sio)
+        print("Hint: relax the tolerance by setting tensor__cmp_sloppy=1", file=sio)
+        print("  or even tensor__cmp_sloppy=2 for less-strict comparison", file=sio)
         return sio.getvalue()
 
 
@@ -235,62 +235,62 @@ class Feature:
 
     """
 
-    def on_attach(self, function_graph):
+    def on_attach(self, fgraph):
         """
-        Called by FunctionGraph.attach_feature, the method that attaches
-        the feature to the FunctionGraph. Since this is called after the
-        FunctionGraph is initially populated, this is where you should
-        run checks on the initial contents of the FunctionGraph.
+        Called by `FunctionGraph.attach_feature`, the method that attaches the
+        feature to the `FunctionGraph`. Since this is called after the
+        `FunctionGraph` is initially populated, this is where you should run
+        checks on the initial contents of the `FunctionGraph`.
 
-        The on_attach method may raise the AlreadyThere exception to cancel
+        The on_attach method may raise the `AlreadyThere` exception to cancel
         the attach operation if it detects that another Feature instance
-        implementing the same functionality is already atttached to the
-        FunctionGraph.
+        implementing the same functionality is already attached to the
+        `FunctionGraph`.
 
-        The feature has great freedom in what it can do with the
-        function_graph: it may, for example, add methods to it dynamically.
+        The feature has great freedom in what it can do with the `fgraph`: it
+        may, for example, add methods to it dynamically.
 
         """
 
-    def on_detach(self, function_graph):
+    def on_detach(self, fgraph):
         """
-        Called by remove_feature(feature).  Should remove any dynamically-added
-        functionality that it installed into the function_graph.
+        Called by `FunctionGraph.remove_feature`.  Should remove any
+        dynamically-added functionality that it installed into the fgraph.
 
         """
 
-    def on_import(self, function_graph, node, reason):
+    def on_import(self, fgraph, node, reason):
         """
-        Called whenever a node is imported into function_graph, which is
-        just before the node is actually connected to the graph.
-        Note: on_import is not called when the graph is created. If you
-        want to detect the first nodes to be implemented to the graph,
-        you should do this by implementing on_attach.
+        Called whenever a node is imported into `fgraph`, which is just before
+        the node is actually connected to the graph.
+
+        Note: this is not called when the graph is created. If you want to
+        detect the first nodes to be implemented to the graph, you should do
+        this by implementing `on_attach`.
 
         """
 
-    def on_prune(self, function_graph, node, reason):
+    def on_change_input(self, fgraph, node, i, var, new_var, reason=None):
         """
-        Called whenever a node is pruned (removed) from the function_graph,
-        after it is disconnected from the graph.
-
-        """
-
-    def on_change_input(self, function_graph, node, i, r, new_r, reason=None):
-        """
-        Called whenever node.inputs[i] is changed from r to new_r.
-        At the moment the callback is done, the change has already
-        taken place.
+        Called whenever ``node.inputs[i]`` is changed from `var` to `new_var`.
+        At the moment the callback is done, the change has already taken place.
 
         If you raise an exception in this function, the state of the graph
         might be broken for all intents and purposes.
 
         """
 
-    def orderings(self, function_graph):
+    def on_prune(self, fgraph, node, reason):
         """
-        Called by toposort. It should return a dictionary of
-        {node: predecessors} where predecessors is a list of
+        Called whenever a node is pruned (removed) from the `fgraph`, after it
+        is disconnected from the graph.
+
+        """
+
+    def orderings(self, fgraph):
+        """
+        Called by `FunctionGraph.toposort`. It should return a dictionary of
+        ``{node: predecessors}`` where ``predecessors`` is a list of
         nodes that should be computed before the key node.
 
         If you raise an exception in this function, the state of the graph
@@ -461,11 +461,7 @@ class Validator(Feature):
                 if verbose:
                     r = uf.f_locals.get("r", "")
                     reason = uf_info.function
-                    print(
-                        "validate failed on node {}.\n Reason: {}, {}".format(
-                            r, reason, e
-                        )
-                    )
+                    print(f"validate failed on node {r}.\n Reason: {reason}, {e}")
                 raise
         t1 = time.time()
         if fgraph.profile:
@@ -532,7 +528,7 @@ class ReplaceValidate(History, Validator):
         chk = fgraph.checkpoint()
         if verbose is None:
             verbose = config.optimizer_verbose
-        if config.scan.debug:
+        if config.scan__debug:
             from theano.scan.op import Scan
 
             scans = [n for n in fgraph.apply_nodes if isinstance(n.op, Scan)]
@@ -574,11 +570,9 @@ class ReplaceValidate(History, Validator):
         except Exception as e:
             fgraph.revert(chk)
             if verbose:
-                print(
-                    "validate failed on node {}.\n Reason: {}, {}".format(r, reason, e)
-                )
+                print(f"validate failed on node {r}.\n Reason: {reason}, {e}")
             raise
-        if config.scan.debug:
+        if config.scan__debug:
             from theano.scan.op import Scan
 
             scans2 = [n for n in fgraph.apply_nodes if isinstance(n.op, Scan)]
@@ -616,18 +610,16 @@ class ReplaceValidate(History, Validator):
             if rm in fgraph.apply_nodes or rm in fgraph.variables:
                 fgraph.revert(chk)
                 if warn:
-                    out = sys.stderr
-                    print(
-                        "WARNING: An optimization wanted to replace a Variable"
+                    warn(
+                        "An optimization wanted to replace a Variable"
                         " in the graph, but the replacement for it doesn't"
                         " remove it. We disabled the optimization."
                         " Your function runs correctly, but it would be"
                         " appreciated if you submit this problem to the"
-                        " mailing list theano-users so that we can fix it.",
-                        file=out,
+                        " mailing list theano-users so that we can fix it."
+                        f"{reason}: {replacements}",
                     )
-                    print(reason, replacements, file=out)
-                raise ReplacementDidntRemovedError()
+                raise ReplacementDidNotRemoveError()
 
     def __getstate__(self):
         d = self.__dict__.copy()
@@ -703,7 +695,7 @@ class NodeFinder(Bookkeeper):
             all = self.d.get(op, [])
         except TypeError:
             raise TypeError(
-                "%s in unhashable and cannot be queried by the" " optimizer" % op
+                f"{op} in unhashable and cannot be queried by the optimizer"
             )
         all = list(all)
         return all
@@ -727,15 +719,15 @@ class PrintListener(Feature):
 
     def on_import(self, fgraph, node, reason):
         if self.active:
-            print("-- importing: {}, reason: {}".format(node, reason))
+            print(f"-- importing: {node}, reason: {reason}")
 
     def on_prune(self, fgraph, node, reason):
         if self.active:
-            print("-- pruning: {}, reason: {}".format(node, reason))
+            print(f"-- pruning: {node}, reason: {reason}")
 
     def on_change_input(self, fgraph, node, i, r, new_r, reason=None):
         if self.active:
-            print("-- changing ({}.inputs[{}]) from {} to {}".format(node, i, r, new_r))
+            print(f"-- changing ({node}.inputs[{i}]) from {r} to {new_r}")
 
 
 class PreserveNames(Feature):
