@@ -83,12 +83,12 @@ def add_tag_trace(thing, user_line=None):
 
     Notes
     -----
-    We also use config.traceback.limit for the maximum number of stack level
+    We also use config.traceback__limit for the maximum number of stack level
     we look.
 
     """
     if user_line is None:
-        user_line = config.traceback.limit
+        user_line = config.traceback__limit
 
     if user_line == -1:
         user_line = None
@@ -111,7 +111,7 @@ def add_tag_trace(thing, user_line=None):
         "theano\\typed_list\\",
     ]
 
-    if config.traceback.compile_limit > 0:
+    if config.traceback__compile_limit > 0:
         skips = []
 
     tr = simple_extract_stack(limit=user_line, skips=skips)
@@ -140,7 +140,7 @@ def get_variable_trace_string(v):
             # backtraces
             for idx, subtr in enumerate(tr):
                 if len(tr) > 1:
-                    print("trace %d" % idx, file=sio)
+                    print(f"trace {int(idx)}", file=sio)
                 traceback.print_list(subtr, sio)
     return sio.getvalue()
 
@@ -218,7 +218,7 @@ class MetaObject(type):
                 if len(props) == 0:
 
                     def __str__(self):
-                        return "{}".format(self.__class__.__name__)
+                        return f"{self.__class__.__name__}"
 
                 else:
 
@@ -257,9 +257,9 @@ class Scratchpad:
         return "scratchpad" + str(self.__dict__)
 
     def info(self):
-        print("<theano.gof.utils.scratchpad instance at %i>" % id(self))
+        print(f"<theano.gof.utils.scratchpad instance at {id(self)}>")
         for k, v in self.__dict__.items():
-            print("  {}: {}".format(k, v))
+            print(f"  {k}: {v}")
 
 
 class ValidatingScratchpad(Scratchpad):
@@ -284,6 +284,78 @@ class D:
         self.__dict__.update(d)
 
 
+class AssocList:
+    """An associative list.
+
+    This class is like a `dict` that accepts unhashable keys by using an
+    assoc list for internal use only
+    """
+
+    def __init__(self):
+        self._dict = {}
+        self._list = []
+
+    def __getitem__(self, item):
+        return self.get(item, None)
+
+    def __setitem__(self, item, value):
+        try:
+            self._dict[item] = value
+        except Exception:
+            for i, (key, val) in enumerate(self._list):
+                if key == item:
+                    self._list[i] = (item, value)
+                    return
+            self._list.append((item, value))
+
+    def __delitem__(self, item):
+        try:
+            if item in self._dict:
+                del self._dict[item]
+                return
+        except TypeError as e:
+            assert "unhashable type" in str(e)
+        for i, (key, val) in enumerate(self._list):
+            if key == item:
+                del self._list[i]
+                return
+            raise KeyError(item)
+
+    def discard(self, item):
+        try:
+            if item in self._dict:
+                del self._dict[item]
+                return
+        except TypeError as e:
+            assert "unhashable type" in str(e)
+        for i, (key, val) in enumerate(self._list):
+            if key == item:
+                del self._list[i]
+                return
+
+    def get(self, item, default):
+        try:
+            return self._dict[item]
+        except Exception:
+            for item2, value in self._list:
+                try:
+                    if item == item2:
+                        return value
+                    if item.equals(item2):
+                        return value
+                except Exception:
+                    if item is item2:
+                        return value
+            return default
+
+    def clear(self):
+        self._dict = {}
+        self._list = []
+
+    def __repr__(self):
+        return f"AssocList({self._dict}, {self._list})"
+
+
 def memoize(f):
     """
     Cache the return value for each tuple of arguments (which must be hashable).
@@ -304,36 +376,6 @@ def memoize(f):
     return rval
 
 
-def deprecated(filename, msg=""):
-    """
-    Decorator which will print a warning message on the first call.
-
-    Use it like this::
-
-      @deprecated('myfile', 'do something different...')
-      def fn_name(...)
-          ...
-
-    And it will print::
-
-      WARNING myfile.fn_name deprecated. do something different...
-
-    """
-
-    def _deprecated(f):
-        printme = [True]
-
-        def g(*args, **kwargs):
-            if printme[0]:
-                print("WARNING: {}.{} deprecated. {}".format(filename, f.__name__, msg))
-                printme[0] = False
-            return f(*args, **kwargs)
-
-        return g
-
-    return _deprecated
-
-
 def uniq(seq):
     """
     Do not use set, this must always return the same value at the same index.
@@ -433,10 +475,10 @@ class Keyword:
         return self.nonzero
 
     def __str__(self):
-        return "<%s>" % self.name
+        return f"<{self.name}>"
 
     def __repr__(self):
-        return "<%s>" % self.name
+        return f"<{self.name}>"
 
 
 ABORT = Keyword("ABORT", False)
@@ -545,10 +587,6 @@ def flatten(a):
         return [a]
 
 
-def unique(x):
-    return len(set(x)) == len(x)
-
-
 def hist(coll):
     counts = {}
     for elem in coll:
@@ -556,31 +594,6 @@ def hist(coll):
     return counts
 
 
-@deprecated("theano.gof.utils", msg="Use a_theano_variable.auto_name instead")
-def give_variables_names(variables):
-    """
-    Gives unique names to an iterable of variables. Modifies input.
-
-    This function is idempotent.
-
-    """
-    names = [var.name for var in variables]
-    h = hist(names)
-
-    def bad_var(var):
-        return not var.name or h[var.name] > 1
-
-    for i, var in enumerate(filter(bad_var, variables)):
-        var.name = (var.name or "") + "_%d" % i
-
-    if not unique([str(v) for v in variables]):
-        raise ValueError(
-            "Not all variables have unique names. Maybe you've "
-            "named some of the variables identically"
-        )
-    return variables
-
-
 def remove(predicate, coll):
     """
     Return those items of collection for which predicate(item) is true.
