@@ -24,11 +24,21 @@ try:
 except ImportError:
     pygpu = None
 
-from . import ctc, dnn, extra_ops, fft, multinomial, opt, reduction, rng_mrg, sort
-from .basic_ops import as_gpuarray_variable
+from theano.gpuarray import (
+    ctc,
+    dnn,
+    extra_ops,
+    fft,
+    multinomial,
+    opt,
+    reduction,
+    rng_mrg,
+    sort,
+)
+from theano.gpuarray.basic_ops import as_gpuarray_variable
 
 # This is for documentation not to depend on the availability of pygpu
-from .type import (
+from theano.gpuarray.type import (
     ContextNotDefined,
     GpuArrayConstant,
     GpuArraySharedVariable,
@@ -65,7 +75,7 @@ def pygpu_parse_version(version_string):
         patch = int(pieces[2].split("+", 1)[0])
     else:  # Maybe it end with .devN
         patch = int(pieces[2].split(".", 1)[0])
-    fullversion = "%d.%d.%s" % (major, minor, pieces[2])
+    fullversion = f"{int(major)}.{int(minor)}.{pieces[2]}"
     return version_type(major=major, minor=minor, patch=patch, fullversion=fullversion)
 
 
@@ -93,26 +103,24 @@ def init_dev(dev, name=None, preallocate=None):
     if gpuarray_version_major_detected != gpuarray_version_major_supported:
         raise ValueError(
             "Your installed version of libgpuarray is not in sync with the current Theano"
-            " version. The installed libgpuarray version supports API version %d,"
-            " while current Theano supports API version %d. Change the version of"
+            f" version. The installed libgpuarray version supports API version {int(gpuarray_version_major_detected)},"
+            f" while current Theano supports API version {int(gpuarray_version_major_supported)}. Change the version of"
             " libgpuarray or Theano to fix this problem.",
-            gpuarray_version_major_detected,
-            gpuarray_version_major_supported,
         )
     if dev not in init_dev.devmap:
         args = dict()
-        if config.gpuarray.cache_path != "":
-            args["kernel_cache_path"] = config.gpuarray.cache_path
+        if config.gpuarray__cache_path != "":
+            args["kernel_cache_path"] = config.gpuarray__cache_path
         if preallocate is None:
-            preallocate = config.gpuarray.preallocate
+            preallocate = config.gpuarray__preallocate
         if preallocate < 0:
             args["max_cache_size"] = 0
         else:
             args["initial_cache_size"] = preallocate
         context = pygpu.init(
             dev,
-            sched=config.gpuarray.sched,
-            single_stream=config.gpuarray.single_stream,
+            sched=config.gpuarray__sched,
+            single_stream=config.gpuarray__single_stream,
             **args,
         )
         os.environ["THEANO_GPU_IS_ALREADY_ACTIVE"] = "Yes"
@@ -129,12 +137,11 @@ def init_dev(dev, name=None, preallocate=None):
             # not even try a clear error.
             if avail and context.free_gmem < 75 * MB:
                 raise RuntimeError(
-                    "Can not enable cuDNN as there is only %d MB of free GPU memory."
-                    % (context.free_gmem / MB)
+                    f"Can not enable cuDNN as there is only {int(context.free_gmem / MB)} MB of free GPU memory."
                 )
             elif avail:
                 context.cudnn_handle = dnn._make_handle(context)
-            elif config.dnn.enabled == "True":
+            elif config.dnn__enabled == "True":
                 raise RuntimeError(
                     "You enabled cuDNN, but we aren't able to use it: %s"
                     % dnn.dnn_available.msg
@@ -142,17 +149,16 @@ def init_dev(dev, name=None, preallocate=None):
             if config.print_active_device:
                 if avail:
                     print(
-                        "Using cuDNN version %d on context %s" % (dnn.version(), name),
+                        f"Using cuDNN version {int(dnn.version())} on context {name}",
                         file=sys.stderr,
                     )
                 else:
                     print(
-                        "Can not use cuDNN on context %s: %s"
-                        % (name, dnn.dnn_available.msg),
+                        f"Can not use cuDNN on context {name}: {dnn.dnn_available.msg}",
                         file=sys.stderr,
                     )
         if preallocate < 0:
-            print("Disabling allocation cache on {}".format(dev))
+            print(f"Disabling allocation cache on {dev}")
         elif preallocate > 0:
             if preallocate <= 1:
                 gmem = min(preallocate, 0.95) * context.total_gmem
@@ -160,12 +166,12 @@ def init_dev(dev, name=None, preallocate=None):
                 gmem = preallocate * MB
             if gmem > context.free_gmem:
                 raise RuntimeError(
-                    "Trying to preallocate %d MB of GPU memory while only"
-                    " %d MB are available." % (gmem / MB, context.free_gmem / MB)
+                    f"Trying to preallocate {int(gmem / MB)} MB of GPU memory while only"
+                    f" {int(context.free_gmem / MB)} MB are available."
                 )
             elif gmem > context.free_gmem - 50 * MB:
-                print(
-                    "WARNING: Preallocating too much memory can prevent cudnn and cublas from working properly"
+                warnings.warn(
+                    "Preallocating too much memory can prevent cudnn and cublas from working properly"
                 )
 
             # This will allocate and immediately free an object of size gmem
@@ -173,13 +179,7 @@ def init_dev(dev, name=None, preallocate=None):
             pygpu.empty((gmem,), dtype="int8", context=context)
             if config.print_active_device:
                 print(
-                    "Preallocating %d/%d Mb (%f) on %s"
-                    % (
-                        gmem // MB,
-                        context.total_gmem // MB,
-                        gmem / context.total_gmem,
-                        dev,
-                    ),
+                    f"Preallocating {int(gmem // MB)}/{int(context.total_gmem // MB)} Mb ({gmem / context.total_gmem}) on {dev}",
                     file=sys.stderr,
                 )
 
@@ -200,8 +200,7 @@ def init_dev(dev, name=None, preallocate=None):
             unique_id = ""
 
         print(
-            "Mapped name %s to device %s: %s %s"
-            % (name, dev, context.devname, unique_id),
+            f"Mapped name {name} to device {dev}: {context.devname} {unique_id}",
             file=sys.stderr,
         )
     pygpu_activated = True
@@ -237,7 +236,7 @@ def use(
         If gpu init succeeded, put new shared variables on the gpu.
     preallocate
         If specified, will use this value for preallocation instead of
-        gpuarray.preallocate.
+        gpuarray__preallocate.
 
     """
     if force:
