@@ -98,9 +98,9 @@ class IfElse(Op):
             args.append("inplace")
         if self.gpu:
             args.append("gpu")
-        return "if{%s}" % ",".join(args)
+        return "if{{{','.join(args)}}}"
 
-    def infer_shape(self, node, inputs_shapes):
+    def infer_shape(self, fgraph, node, inputs_shapes):
         # By construction, corresponding then/else pairs have the same number
         # of dimensions
 
@@ -159,10 +159,7 @@ class IfElse(Op):
     def make_node(self, c, *args):
         assert (
             len(args) == 2 * self.n_outs
-        ), "Wrong number of arguments to make_node: " "expected %d, got %d" % (
-            2 * self.n_outs,
-            len(args),
-        )
+        ), f"Wrong number of arguments to make_node: expected {int(2 * self.n_outs)}, got {len(args)}"
         c = theano.tensor.as_tensor_variable(c)
         if not self.gpu:
             # When gpu is true, we are given only gpuarrays, and we want
@@ -345,14 +342,12 @@ def ifelse(condition, then_branch, else_branch, name=None):
     """
 
     rval_type = None
-    if type(then_branch) is list:
-        rval_type = list
-    elif type(then_branch) is tuple:
-        rval_type = tuple
-
-    if type(then_branch) not in (list, tuple):
+    if isinstance(then_branch, (list, tuple)):
+        rval_type = type(then_branch)
+    else:
         then_branch = [then_branch]
-    if type(else_branch) not in (list, tuple):
+
+    if not isinstance(else_branch, (list, tuple)):
         else_branch = [else_branch]
 
     # Some of the elements might be converted into another type,
@@ -388,10 +383,10 @@ def ifelse(condition, then_branch, else_branch, name=None):
                 # If the types still don't match, there is a problem.
                 raise TypeError(
                     "The two branches should have identical types, but "
-                    "they are %s and %s respectively. This error could be "
+                    f"they are {then_branch_elem.type} and {else_branch_elem.type} respectively. This error could be "
                     "raised if for example you provided a one element "
                     "list on the `then` branch but a tensor on the `else` "
-                    "branch." % (then_branch_elem.type, else_branch_elem.type)
+                    "branch."
                 )
 
         new_then_branch.append(then_branch_elem)
@@ -402,8 +397,8 @@ def ifelse(condition, then_branch, else_branch, name=None):
             "The number of values on the `then` branch"
             " should have the same number of variables as "
             "the `else` branch : (variables on `then` "
-            "%d" % len(then_branch) + ", variables on `else` "
-            "%d" % len(else_branch) + ")"
+            f"{len(then_branch)}, variables on `else` "
+            f"{len(else_branch)})"
         )
 
     new_ifelse = IfElse(n_outs=len(then_branch), as_view=False, gpu=False, name=name)
@@ -420,7 +415,7 @@ def ifelse(condition, then_branch, else_branch, name=None):
 
 
 @gof.local_optimizer([IfElse])
-def cond_make_inplace(node):
+def cond_make_inplace(fgraph, node):
     op = node.op
     if (
         isinstance(op, IfElse)
@@ -429,7 +424,7 @@ def cond_make_inplace(node):
         # For big graph, do not make inplace scalar to speed up
         # optimization.
         (
-            len(node.fgraph.apply_nodes) < 500
+            len(fgraph.apply_nodes) < 500
             or not all([getattr(o.type, "ndim", -1) == 0 for o in node.outputs])
         )
     ):
@@ -497,7 +492,7 @@ acceptable_ops = (
 
 
 @gof.local_optimizer(acceptable_ops)
-def ifelse_lift_single_if_through_acceptable_ops(main_node):
+def ifelse_lift_single_if_through_acceptable_ops(fgraph, main_node):
     """This optimization lifts up certain ifelse instances.
 
         op(ifelse(c, x, y)) -> ifelse(c, op(x), op(y))
@@ -544,7 +539,7 @@ def ifelse_lift_single_if_through_acceptable_ops(main_node):
 
 
 @gof.local_optimizer([IfElse])
-def cond_merge_ifs_true(node):
+def cond_merge_ifs_true(fgraph, node):
     op = node.op
     if not isinstance(op, IfElse):
         return False
@@ -571,7 +566,7 @@ def cond_merge_ifs_true(node):
 
 
 @gof.local_optimizer([IfElse])
-def cond_merge_ifs_false(node):
+def cond_merge_ifs_false(fgraph, node):
     op = node.op
     if not isinstance(op, IfElse):
         return False
@@ -597,7 +592,7 @@ def cond_merge_ifs_false(node):
     return op(*old_ins, **dict(return_list=True))
 
 
-class CondMerge(gof.Optimizer):
+class CondMerge(gof.GlobalOptimizer):
     """ Graph Optimizer that merges different cond ops """
 
     def add_requirements(self, fgraph):
@@ -650,7 +645,7 @@ class CondMerge(gof.Optimizer):
 
 
 @gof.local_optimizer([IfElse])
-def cond_remove_identical(node):
+def cond_remove_identical(fgraph, node):
     op = node.op
 
     if not isinstance(op, IfElse):
@@ -696,7 +691,7 @@ def cond_remove_identical(node):
 
 
 @gof.local_optimizer([IfElse])
-def cond_merge_random_op(main_node):
+def cond_merge_random_op(fgraph, main_node):
     if isinstance(main_node.op, IfElse):
         return False
 
