@@ -104,12 +104,12 @@ class PersistentNdarrayID:
 
     def _resolve_name(self, obj):
         """Determine the name the object should be saved under."""
-        name = "array_{}".format(self.count)
+        name = f"array_{self.count}"
         self.count += 1
         return name
 
     def __call__(self, obj):
-        if type(obj) is np.ndarray:
+        if isinstance(obj, np.ndarray):
             if id(obj) not in self.seen:
 
                 def write_array(f):
@@ -117,7 +117,7 @@ class PersistentNdarrayID:
 
                 name = self._resolve_name(obj)
                 zipadd(write_array, self.zip_file, name)
-                self.seen[id(obj)] = "ndarray.{}".format(name)
+                self.seen[id(obj)] = f"ndarray.{name}"
             return self.seen[id(obj)]
 
 
@@ -139,7 +139,7 @@ class PersistentGpuArrayID(PersistentNdarrayID):
 
                 name = self._resolve_name(obj)
                 zipadd(write_array, self.zip_file, name)
-                self.seen[id(obj)] = "gpuarray.{}".format(name)
+                self.seen[id(obj)] = f"gpuarray.{name}"
             return self.seen[id(obj)]
         return super().__call__(obj)
 
@@ -183,10 +183,9 @@ class PersistentSharedVariableID(PersistentGpuArrayID):
             if count:
                 if not self.allow_duplicates:
                     raise ValueError(
-                        "multiple shared variables with the name "
-                        "`{}` found".format(name)
+                        f"multiple shared variables with the name `{name}` found"
                     )
-                name = "{}_{}".format(name, count + 1)
+                name = f"{name}_{count + 1}"
             return name
         return super()._resolve_name(obj)
 
@@ -197,7 +196,7 @@ class PersistentSharedVariableID(PersistentGpuArrayID):
                     ValueError("can't pickle shared variable with name `pkl`")
                 self.ndarray_names[id(obj.container.storage[0])] = obj.name
             elif not self.allow_unnamed:
-                raise ValueError("unnamed shared variable, {}".format(obj))
+                raise ValueError(f"unnamed shared variable, {obj}")
         return super().__call__(obj)
 
 
@@ -226,10 +225,10 @@ class PersistentNdarrayLoad:
             with self.zip_file.open(name) as f:
                 ctx_name = pickle.load(f)
                 array = np.lib.format.read_array(f)
-            if config.experimental.unpickle_gpu_on_cpu:
+            if config.experimental__unpickle_gpu_on_cpu:
                 # directly return numpy array
                 warnings.warn(
-                    "config.experimental.unpickle_gpu_on_cpu is set "
+                    "config.experimental__unpickle_gpu_on_cpu is set "
                     "to True. Unpickling GpuArray as numpy.ndarray"
                 )
                 ret = array
