@@ -66,7 +66,6 @@ def debugprint(
     stop_on_name=False,
     done=None,
     print_storage=False,
-    print_clients=False,
     used_ids=None,
 ):
     """Print a computation graph as text to stdout or a file.
@@ -94,10 +93,6 @@ def debugprint(
     :param print_storage: If True, this will print the storage map
         for Theano functions. Combined with allow_gc=False, after the
         execution of a Theano function, we see the intermediate result.
-    :type print_clients: bool
-    :param print_clients: If True, this will print for Apply node that
-         have more then 1 clients its clients. This help find who use
-         an Apply node.
     :type used_ids: dict or None
     :param used_ids: the id to use for some object, but maybe we only
          referred to it yet.
@@ -220,7 +215,6 @@ N.B.:
             profile=p,
             smap=s,
             used_ids=used_ids,
-            print_clients=print_clients,
         )
 
     if len(scan_ops) > 0:
@@ -254,7 +248,6 @@ N.B.:
                 scan_ops=scan_ops,
                 stop_on_name=stop_on_name,
                 scan_inner_to_outer_inputs=inner_to_outer_inputs,
-                print_clients=print_clients,
                 used_ids=used_ids,
             )
             if hasattr(s.owner.op, "fn"):
@@ -280,7 +273,6 @@ N.B.:
                     prefix_child=new_prefix_child,
                     scan_ops=scan_ops,
                     scan_inner_to_outer_inputs=inner_to_outer_inputs,
-                    print_clients=print_clients,
                     used_ids=used_ids,
                 )
 
@@ -422,9 +414,9 @@ class OperatorPrinter:
         if len(input_strings) == 1:
             s = self.operator + input_strings[0]
         else:
-            s = (" %s " % self.operator).join(input_strings)
+            s = f" {self.operator} ".join(input_strings)
         if parenthesize:
-            r = "(%s)" % s
+            r = f"({s})"
         else:
             r = s
         pstate.memo[output] = r
@@ -515,11 +507,11 @@ class IgnorePrinter:
         node = output.owner
         if node is None:
             raise TypeError(
-                "function %s cannot represent a variable that is"
-                " not the result of an operation" % self.function
+                f"function {self.function} cannot represent a variable that is"
+                " not the result of an operation"
             )
         input = node.inputs[0]
-        r = "%s" % pprinter.process(input, pstate)
+        r = f"{pprinter.process(input, pstate)}"
         pstate.memo[output] = r
         return r
 
@@ -627,9 +619,7 @@ class PPrinter:
             for output in node.outputs:
                 if output in inv_updates:
                     name = str(inv_updates[output])
-                    strings.append(
-                        (i + 1000, "{} <- {}".format(name, pprinter.process(output)))
-                    )
+                    strings.append((i + 1000, f"{name} <- {pprinter.process(output)}"))
                     i += 1
                 if output.name is not None or output in outputs:
                     if output.name is None:
@@ -645,11 +635,9 @@ class PPrinter:
                     except ValueError:
                         idx = i
                     if len(outputs) == 1 and outputs[0] is output:
-                        strings.append((idx, "return %s" % pprinter.process(output)))
+                        strings.append((idx, f"return {pprinter.process(output)}"))
                     else:
-                        strings.append(
-                            (idx, "{} = {}".format(name, pprinter.process(output)))
-                        )
+                        strings.append((idx, f"{name} = {pprinter.process(output)}"))
                     i += 1
         strings.sort()
         return "\n".join(s[1] for s in strings)
@@ -816,12 +804,14 @@ def pydotprint(
 
     if isinstance(fct, Function):
         profile = getattr(fct, "profile", None)
-        outputs = fct.maker.fgraph.outputs
-        topo = fct.maker.fgraph.toposort()
+        fgraph = fct.maker.fgraph
+        outputs = fgraph.outputs
+        topo = fgraph.toposort()
     elif isinstance(fct, gof.FunctionGraph):
         profile = None
         outputs = fct.outputs
         topo = fct.toposort()
+        fgraph = fct
     else:
         if isinstance(fct, gof.Variable):
             fct = [fct]
@@ -833,6 +823,7 @@ def pydotprint(
         profile = None
         outputs = fct.outputs
         topo = fct.toposort()
+        fgraph = fct
     if not pydot_imported:
         raise RuntimeError(
             "Failed to import pydot. You must install graphviz"
@@ -898,7 +889,7 @@ def pydotprint(
             dstr = "val=" + str(np.asarray(var.data))
             if "\n" in dstr:
                 dstr = dstr[: dstr.index("\n")]
-            varstr = "{} {}".format(dstr, str(var.type))
+            varstr = f"{dstr} {var.type}"
         elif var in input_update and input_update[var].name is not None:
             varstr = input_update[var].name
             if not var_with_name_simple:
@@ -924,13 +915,13 @@ def pydotprint(
             return apply_name_cache[node], apply_name_id[node]
         prof_str = ""
         if profile:
-            time = profile.apply_time.get(node, 0)
+            time = profile.apply_time.get((fgraph, node), 0)
             # second, %fct time in profiler
             if profile.fct_callcount == 0 or profile.fct_call_time == 0:
                 pf = 0
             else:
                 pf = time * 100 / profile.fct_call_time
-            prof_str = "   ({:.3f}s,{:.3f}%)".format(time, pf)
+            prof_str = f"   ({time:.3f}s,{pf:.3f}%)"
         applystr = str(node.op).replace(":", "_")
         applystr += prof_str
         if (applystr in all_strings) or with_ids:
@@ -960,7 +951,7 @@ def pydotprint(
     # it, we must copy it.
     outputs = list(outputs)
     if isinstance(fct, Function):
-        function_inputs = zip(fct.maker.expanded_inputs, fct.maker.fgraph.inputs)
+        function_inputs = zip(fct.maker.expanded_inputs, fgraph.inputs)
         for i, fg_ii in reversed(list(function_inputs)):
             if i.update is not None:
                 k = outputs.pop()
@@ -1076,7 +1067,7 @@ def pydotprint(
                             shape=var_shape,
                         )
                     )
-            elif len(var.clients) == 0:
+            elif len(fgraph.clients[var]) == 0:
                 g.add_edge(pd.Edge(aid, varid, **param))
                 # grey mean that output var isn't used
                 if high_contrast:
