@@ -19,7 +19,7 @@ from theano.compile.ops import (
 )
 from theano.gof import FunctionGraph
 from theano.ifelse import IfElse
-from theano.scalar.basic import Cast, Clip, Composite, Identity, ScalarOp
+from theano.scalar.basic import Cast, Clip, Composite, Identity, ScalarOp, Second
 from theano.scan.op import Scan
 from theano.scan.utils import scan_args as ScanArgs
 from theano.tensor.basic import (
@@ -93,10 +93,13 @@ incsubtensor_ops = (IncSubtensor, AdvancedIncSubtensor1)
 def compose_jax_funcs(out_node, fgraph_inputs, memo=None):
     """Compose JAX implementations of node operations.
 
+    This function walks the graph given by the `Apply` node, `out_node`, and
+    creates JAX JIT-able functions for its input and output variables.
+
     Parameters
     ----------
-    out_node: Node
-        The output node.
+    out_node: theano.gof.graph.Apply
+        The node for which we want to construct a JAX JIT-able function.
     fgraph_inputs: List[Variable]
         The inputs--in a `FunctionGraph` sense--to `out_node`.
     memo: Mapping (Optional)
@@ -116,9 +119,13 @@ def compose_jax_funcs(out_node, fgraph_inputs, memo=None):
 
     jax_return_func = jax_funcify(out_node.op)
 
+    # We create a list of JAX-able functions that produce the values of each
+    # input variable for `out_node`.
     input_funcs = []
     for i in out_node.inputs:
         if i in fgraph_inputs:
+            # This input is a top-level input (i.e. an input to the
+            # `FunctionGraph` in which this `out_node` resides)
             idx = fgraph_inputs.index(i)
 
             i_dtype = getattr(i, "dtype", None)
@@ -129,6 +136,7 @@ def compose_jax_funcs(out_node, fgraph_inputs, memo=None):
             input_f = jax_inputs_func
 
         elif i.owner is None:
+            # This input is something like a `theano.gof.graph.Constant`
 
             i_dtype = getattr(i, "dtype", None)
             i_data = i.data
@@ -141,8 +149,24 @@ def compose_jax_funcs(out_node, fgraph_inputs, memo=None):
 
             input_f = jax_data_func
         else:
+            # This input is the output of another node, so we need to
+            # generate a JAX-able function for its subgraph
             input_f = compose_jax_funcs(i.owner, fgraph_inputs, memo)
 
+            if i.owner.nout > 1:
+                # This input is one of multiple outputs from the `i.owner`
+                # node, and we need to determine exactly which one it is and
+                # create a JAX-able function that returns only it.
+                out_idx = i.owner.outputs.index(i)
+                (out_fn,) = input_f
+
+                def jax_multiout_func(*inputs, out_idx=out_idx, out_fn=out_fn):
+                    return out_fn(*inputs)[out_idx]
+
+                input_f = jax_multiout_func
+
+        assert callable(input_f)
+
         input_funcs.append(input_f)
 
     if not isinstance(jax_return_func, Sequence):
@@ -153,6 +177,7 @@ def compose_jax_funcs(out_node, fgraph_inputs, memo=None):
 
         def jax_func(*inputs):
             func_args = [fn(*inputs) for fn in input_funcs]
+            # func_args = jax.tree_map(lambda fn: fn(*inputs), input_funcs)
             return return_func(*func_args)
 
         jax_funcs.append(update_wrapper(jax_func, return_func))
@@ -168,7 +193,7 @@ def compose_jax_funcs(out_node, fgraph_inputs, memo=None):
 @dispatch
 def jax_funcify(op):
     """Create a JAX "perform" function for a Theano `Variable` and its `Op`."""
-    raise NotImplementedError("No JAX conversion for the given `Op`: {}".format(op))
+    raise NotImplementedError(f"No JAX conversion for the given `Op`: {op}")
 
 
 @jax_funcify.register(MakeSlice)
@@ -232,6 +257,14 @@ def jax_funcify_ScalarSoftplus(op):
     return scalarsoftplus
 
 
+@jax_funcify.register(Second)
+def jax_funcify_Second(op):
+    def second(x, y):
+        return jnp.broadcast_to(y, x.shape)
+
+    return second
+
+
 @jax_funcify.register(AllocEmpty)
 def jax_funcify_AllocEmpty(op):
     def allocempty(*shape):
@@ -274,7 +307,7 @@ def jnp_safe_copy(x):
         if hasattr(x, "copy"):
             res = jnp.array(x.copy())
         else:
-            warn("Object has no `copy` method: {}".format(x))
+            warn(f"Object has no `copy` method: {x}")
             res = x
 
     return res
@@ -388,7 +421,7 @@ def jax_funcify_Scan(op):
 
     def scan(*outer_inputs):
         scan_args = ScanArgs(
-            outer_inputs, [None] * op.n_outs, op.inputs, op.outputs, op.info
+            list(outer_inputs), [None] * op.n_outs, op.inputs, op.outputs, op.info
         )
 
         # `outer_inputs` is a list with the following composite form:
@@ -403,9 +436,9 @@ def jax_funcify_Scan(op):
         n_steps = scan_args.n_steps
         seqs = scan_args.outer_in_seqs
 
-        n_non_seqs = len(scan_args.outer_in_non_seqs)
+        # TODO: mit_mots
+        mit_mot_in_slices = []
 
-        # TODO: sit_sots
         mit_sot_in_slices = []
         for tap, seq in zip(scan_args.mit_sot_in_slices, scan_args.outer_in_mit_sot):
             neg_taps = [abs(t) for t in tap if t < 0]
@@ -415,7 +448,15 @@ def jax_funcify_Scan(op):
             init_slice = seq[: max_neg + max_pos]
             mit_sot_in_slices.append(init_slice)
 
-        init_carry = [mit_sot_in_slices, scan_args.outer_in_non_seqs]
+        sit_sot_in_slices = [seq[0] for seq in scan_args.outer_in_sit_sot]
+
+        init_carry = (
+            mit_mot_in_slices,
+            mit_sot_in_slices,
+            sit_sot_in_slices,
+            scan_args.outer_in_shared,
+            scan_args.outer_in_non_seqs,
+        )
 
         def jax_args_to_inner_scan(op, carry, x):
             # `carry` contains all inner-output taps, non_seqs, and shared
@@ -438,15 +479,22 @@ def jax_funcify_Scan(op):
             # + inner_in_sit_sot
             # + inner_in_shared
             # + inner_in_non_seqs
-            inner_scan_inputs = [
-                inner_in_seqs,
-                inner_in_mit_mot,
-                inner_in_mit_sot,
-                inner_in_sit_sot,
-                inner_in_non_seqs,
-            ]
+            inner_in_mit_sot_flatten = []
+            for array, index in zip(inner_in_mit_sot, scan_args.mit_sot_in_slices):
+                inner_in_mit_sot_flatten.extend(array[jnp.array(index)])
+
+            inner_scan_inputs = sum(
+                [
+                    inner_in_seqs,
+                    inner_in_mit_mot,
+                    inner_in_mit_sot_flatten,
+                    inner_in_sit_sot,
+                    inner_in_shared,
+                    inner_in_non_seqs,
+                ],
+                [],
+            )
 
-            raise NotImplementedError()
             return inner_scan_inputs
 
         def inner_scan_outs_to_jax_outs(
@@ -454,47 +502,66 @@ def jax_funcify_Scan(op):
             old_carry,
             inner_scan_outs,
         ):
-            # `inner_scan_outs` is a list with the following
-            # composite form:
-            # outer_out_mit_mot
-            # + outer_out_mit_sot
-            # + outer_out_sit_sot
-            # + outer_out_nit_sot
-            # + outer_out_shared
-            # + cond
             (
-                outer_out_mit_mot,
-                outer_out_mit_sot,
-                outer_out_sit_sot,
-                outer_out_nit_sot,
-                outer_out_shared,
-                cond,
-            ) = inner_scan_outs
-            outer_out_non_seqs = old_carry[:-n_non_seqs]
+                inner_in_mit_mot,
+                inner_in_mit_sot,
+                inner_in_sit_sot,
+                inner_in_shared,
+                inner_in_non_seqs,
+            ) = old_carry
+
+            def update_mit_sot(mit_sot, new_val):
+                return jnp.concatenate([mit_sot[1:], new_val[None, ...]], axis=0)
+
+            inner_out_mit_sot = [
+                update_mit_sot(mit_sot, new_val)
+                for mit_sot, new_val in zip(inner_in_mit_sot, inner_scan_outs)
+            ]
 
             # This should contain all inner-output taps, non_seqs, and shared
             # terms
-            carry = [
-                outer_out_mit_mot,
-                outer_out_mit_sot,
-                outer_out_sit_sot,
-                outer_out_shared,
-                outer_out_non_seqs,
-            ]
-            # This should contain all inner-outputs that produce
-            # outer-outputs
-            y = []
+            if not inner_in_sit_sot:
+                inner_out_sit_sot = []
+            else:
+                inner_out_sit_sot = inner_scan_outs
+            new_carry = (
+                inner_in_mit_mot,
+                inner_out_mit_sot,
+                inner_out_sit_sot,
+                inner_in_shared,
+                inner_in_non_seqs,
+            )
 
-            raise NotImplementedError()
-            return (carry, y)
+            return new_carry
 
         def jax_inner_func(carry, x):
             inner_args = jax_args_to_inner_scan(op, carry, x)
-            inner_scan_outs = jax_tt_inner_func(*inner_args)
-            new_carry, y = inner_scan_outs_to_jax_outs(op, inner_scan_outs)
-            return new_carry, y
+            inner_scan_outs = [fn(*inner_args) for fn in jax_tt_inner_func]
+            new_carry = inner_scan_outs_to_jax_outs(op, carry, inner_scan_outs)
+            return new_carry, inner_scan_outs
 
-        return jax.lax.scan(jax_inner_func, init_carry, seqs, length=n_steps)
+        _, scan_out = jax.lax.scan(jax_inner_func, init_carry, seqs, length=n_steps)
+
+        # We need to prepend the initial values so that the JAX output will
+        # match the raw `Scan` `Op` output and, thus, work with a downstream
+        # `Subtensor` `Op` introduced by the `scan` helper function.
+        def append_scan_out(scan_in_part, scan_out_part):
+            return jnp.concatenate([scan_in_part[:-n_steps], scan_out_part], axis=0)
+
+        if scan_args.outer_in_mit_sot:
+            scan_out_final = [
+                append_scan_out(init, out)
+                for init, out in zip(scan_args.outer_in_mit_sot, scan_out)
+            ]
+        elif scan_args.outer_in_sit_sot:
+            scan_out_final = [
+                append_scan_out(init, out)
+                for init, out in zip(scan_args.outer_in_sit_sot, scan_out)
+            ]
+
+        if len(scan_out_final) == 1:
+            scan_out_final = scan_out_final[0]
+        return scan_out_final
 
     return scan
 
@@ -504,11 +571,9 @@ def jax_funcify_IfElse(op):
     n_outs = op.n_outs
 
     def ifelse(cond, *args, n_outs=n_outs):
-        if cond:
-            res = args[:n_outs]
-        else:
-            res = args[n_outs:]
-
+        res = jax.lax.cond(
+            cond, lambda _: args[:n_outs], lambda _: args[n_outs:], operand=None
+        )
         return res if n_outs > 1 else res[0]
 
     return ifelse
@@ -556,7 +621,7 @@ _ = [jax_funcify.register(op, jax_funcify_Subtensor) for op in subtensor_ops]
 
 def jax_funcify_IncSubtensor(op):
 
-    idx_list = op.idx_list
+    idx_list = getattr(op, "idx_list", None)
 
     if getattr(op, "set_instead_of_inc", False):
         jax_fn = jax.ops.index_update
@@ -565,7 +630,11 @@ def jax_funcify_IncSubtensor(op):
 
     def incsubtensor(x, y, *ilist, jax_fn=jax_fn, idx_list=idx_list):
         _ilist = list(ilist)
-        cdata = tuple(convert_indices(_ilist, idx) for idx in idx_list)
+        cdata = (
+            tuple(convert_indices(_ilist, idx) for idx in idx_list)
+            if idx_list
+            else _ilist
+        )
         if len(cdata) == 1:
             cdata = cdata[0]
 
@@ -695,7 +764,9 @@ def jax_funcify_Join(op):
         else:
             ndim = tensors[0].ndim
             if axis < -ndim:
-                raise IndexError("Join axis %d out of bounds [0, %d)" % (axis, ndim))
+                raise IndexError(
+                    f"Join axis {int(axis)} out of bounds [0, {int(ndim)})"
+                )
 
             return jnp.concatenate(tensors, axis=axis)
 
