@@ -269,7 +269,7 @@ def scan(
 
     allow_gc
         Set the value of allow gc for the internal graph of scan.  If
-        set to None, this will use the value of config.scan.allow_gc.
+        set to None, this will use the value of config.scan__allow_gc.
 
         The full scan behavior related to allocation is determined by
         this value and the Theano flag allow_gc. If the flag allow_gc
@@ -356,9 +356,7 @@ def scan(
 
     # Check n_steps is an int
     if hasattr(n_steps, "dtype") and str(n_steps.dtype) not in tt.integer_dtypes:
-        raise ValueError(
-            " n_steps must be an int. dtype provided " "is %s" % n_steps.dtype
-        )
+        raise ValueError(f" n_steps must be an int. dtype provided is {n_steps.dtype}")
 
     # compute number of sequences and number of outputs
     n_seqs = len(seqs)
@@ -379,9 +377,8 @@ def scan(
     for i in range(n_outs):
         if outs_info[i] is not None:
             if isinstance(outs_info[i], dict):
-                # DEPRECATED :
                 if outs_info[i].get("return_steps", None) is not None:
-                    raise ValueError(
+                    raise DeprecationWarning(
                         "Using `return_steps` has been deprecated. "
                         "Simply select the entries you need using a "
                         "subtensor. Scan will optimize memory "
@@ -398,12 +395,9 @@ def scan(
             ):
                 # ^ no initial state but taps provided
                 raise ValueError(
-                    (
-                        "If you are using slices of an output "
-                        "you need to provide a initial state "
-                        "for it"
-                    ),
-                    outs_info[i],
+                    "If you are using slices of an output "
+                    "you need to provide a initial state "
+                    f"for it: {outs_info[i]}"
                 )
             elif (
                 outs_info[i].get("initial", None) is not None
@@ -413,10 +407,8 @@ def scan(
                 if "taps" in outs_info[i]:
                     # ^ explicitly provided a None for taps
                     _logger.warning(
-                        "Output %s ( index %d) has a initial "
+                        f"Output {getattr(outs_info[i]['initial'], 'name', 'None')} (index {i}) has a initial "
                         "state but taps is explicitly set to None ",
-                        getattr(outs_info[i]["initial"], "name", "None"),
-                        i,
                     )
                 outs_info[i]["taps"] = [-1]
             elif outs_info[i].get("taps", None) is not None:
@@ -503,11 +495,11 @@ def scan(
                 # that is if the input already has a name
                 if getattr(seq["input"], "name", None) is not None:
                     if k > 0:
-                        nw_name = seq["input"].name + "[t+%d]" % k
+                        nw_name = seq["input"].name + f"[t+{int(k)}]"
                     elif k == 0:
                         nw_name = seq["input"].name + "[t]"
                     else:
-                        nw_name = seq["input"].name + "[t%d]" % k
+                        nw_name = seq["input"].name + f"[t{int(k)}]"
                     nw_slice.name = nw_name
 
                 start = k - mintap_proxy
@@ -515,12 +507,12 @@ def scan(
                 if k == maxtap_proxy:
                     nw_seq = seq["input"][start:]
                     if getattr(seq["input"], "name", None) is not None:
-                        nw_name = seq["input"].name + "[%d:]" % start
+                        nw_name = seq["input"].name + f"[{int(start)}:]"
                 else:
                     end = -(maxtap_proxy - k)
                     nw_seq = seq["input"][start:end]
                     if getattr(seq["input"], "name", None) is not None:
-                        nw_name = seq["input"].name + "[%d:%d]" % (start, end)
+                        nw_name = seq["input"].name + f"[{int(start)}:{int(end)}]"
 
                 if go_backwards:
                     nw_seq = nw_seq[::-1]
@@ -691,11 +683,11 @@ def scan(
                 # give it a name or debugging and pretty printing
                 if getattr(init_out["initial"], "name", None) is not None:
                     if k > 0:
-                        nw_slice.name = init_out["initial"].name + "[t+%d]" % k
+                        nw_slice.name = init_out["initial"].name + f"[t+{int(k)}]"
                     elif k == 0:
                         nw_slice.name = init_out["initial"].name + "[t]"
                     else:
-                        nw_slice.name = init_out["initial"].name + "[t%d]" % k
+                        nw_slice.name = init_out["initial"].name + f"[t{int(k)}]"
                 mit_sot_inner_inputs.append(nw_slice)
                 mit_sot_inner_slices.append(actual_nw_slice)
         # NOTE: there is another case, in which we do not want to provide
@@ -1036,7 +1028,7 @@ def scan(
 
     tap_array = mit_sot_tap_array + [[-1] for x in range(n_sit_sot)]
     if allow_gc is None:
-        allow_gc = config.scan.allow_gc
+        allow_gc = config.scan__allow_gc
     info = OrderedDict()
 
     info["tap_array"] = tap_array
