@@ -173,12 +173,7 @@ def hash_listsDictsTuples(x):
     return hash_value
 
 
-DEPRECATED_ARG = object()
-
-
-def clone(
-    output, replace=None, strict=True, share_inputs=True, copy_inputs=DEPRECATED_ARG
-):
+def clone(output, replace=None, strict=True, share_inputs=True):
     """
     Function that allows replacing subgraphs of a computational graph.
 
@@ -196,17 +191,8 @@ def clone(
         graph. If False, clone them. Note that cloned shared variables still
         use the same underlying storage, so they will always have the same
         value.
-    copy_inputs
-        Deprecated, use share_inputs.
 
     """
-    if copy_inputs is not DEPRECATED_ARG:
-        warnings.warn(
-            "In `clone()` function, the argument `copy_inputs` has been deprecated and renamed into `share_inputs`"
-        )
-        assert share_inputs  # since we used `copy_inputs` we should have default value for `share_inputs`
-        share_inputs = copy_inputs
-
     if isinstance(replace, dict):
         items = list(replace.items())
     elif isinstance(replace, (list, tuple)):
@@ -217,10 +203,9 @@ def clone(
         raise ValueError(
             (
                 "replace is neither a dictionary, list, "
-                "tuple or None ! The value provided is %s,"
-                "of type %s"
+                f"tuple or None ! The value provided is {replace},"
+                f"of type {type(replace)}"
             )
-            % (str(replace), str(type(replace)))
         )
     tmp_replace = [(x, x.type()) for x, y in items]
     new_replace = [(x, y) for ((_, x), (_, y)) in zip(tmp_replace, items)]
@@ -287,7 +272,7 @@ def map_variables(replacer, graphs, additional_inputs=None):
     # perform any desired replacement of input variables.  these
     # aren't replaced by the local optimizer approach because they are
     # not outputs of any Apply node.
-    new_inputs = list(map(wrapped_replacer, inputs_))
+    new_inputs = [wrapped_replacer(i) for i in inputs_]
     replacements = [
         (input_, new_input)
         for input_, new_input in zip(inputs_, new_inputs)
@@ -296,23 +281,12 @@ def map_variables(replacer, graphs, additional_inputs=None):
     graphs = clone(graphs, share_inputs=True, replace=replacements)
     inputs_ = list(set(gof.graph.inputs(graphs) + list(additional_inputs)))
 
-    # clone cached constants or FunctionGraph will complain.  this has
-    # to occur in a separate pass from the replacement above because
-    # both may suggest different replacements for the same variables.
-    # since the replacements introduced above may involve cached
-    # constants, the replacement of said constants has to come after.
-    cached_constants = [x for x in inputs_ if getattr(x, "cached", False)]
-    copied_constants = clone(cached_constants, share_inputs=False)
-    replacements = list(zip(cached_constants, copied_constants))
-    inputs_ = list(set(inputs_) - set(cached_constants)) + list(copied_constants)
-    graphs = clone(graphs, share_inputs=True, replace=replacements)
-
     fg = gof.fg.FunctionGraph(inputs_, graphs, clone=False)
 
     nodes_seen = set()
 
     @gof.opt.local_optimizer(None)
-    def local_transform(node):
+    def local_transform(fgraph, node):
         if node in nodes_seen:
             return False
 
@@ -352,7 +326,13 @@ def map_variables(replacer, graphs, additional_inputs=None):
             return new_node.outputs
         else:
             nodes_seen.add(node)
-            return list(map(wrapped_replacer, node.outputs))
+            replacements = [wrapped_replacer(o) for o in node.outputs]
+
+            # Add inputs to replacement graphs as inputs to this `fgraph`
+            for i in gof.graph.inputs(replacements):
+                fgraph.add_input(i)
+
+            return replacements
 
     topo_transform = gof.opt.TopoOptimizer(local_transform, "out_to_in")
     topo_transform.optimize(fg)
@@ -410,7 +390,7 @@ def _map_variables_inner(
         # `fg` can take ownership of
         for input_ in constants:
             new_input = input_.clone()
-            new_input.name = "%s_copied" % new_input.name
+            new_input.name = f"{new_input.name}_copied"
             replacements.append((input_, new_input))
 
         for outer_input in foreign_inputs:
@@ -424,10 +404,10 @@ def _map_variables_inner(
                 # OpFromGraph are not supported at all, so we don't support
                 # introducing those either.
                 raise NotImplementedError(
-                    "Replacement introduces shared variable %s "
+                    f"Replacement introduces shared variable {outer_input} "
                     "which has an update associated with it into "
-                    "the inner graph of %s. This is not currently "
-                    "supported." % (outer_input, containing_op)
+                    f"the inner graph of {containing_op}. This is not currently "
+                    "supported."
                 )
             # if this foreign input is not already available
             # as an inner input, connect it through a new
@@ -437,10 +417,6 @@ def _map_variables_inner(
                 outer_to_inner[outer_input] = inner_input
                 extra_inner_inputs.append(inner_input)
                 extra_outer_inputs.append(outer_input)
-                # the inner FunctionGraph wants to know its inputs
-                # beforehand, but we don't always know.  so add them
-                # as we discover them.
-                graph.owner.fgraph.add_input(inner_input)
 
         replacements.extend(outer_to_inner.items())
 
@@ -538,8 +514,7 @@ def get_updates_and_outputs(ls):
     if is_updates(ls):
         return None, [], OrderedDict(ls)
     error_msg = (
-        "Scan cannot parse the return value of your lambda "
-        "expression, which is: %s" % (ls,)
+        f"Scan cannot parse the return value of your lambda expression, which is: {ls}"
     )
     if not isinstance(ls, (list, tuple)):
         raise ValueError(error_msg)
@@ -686,19 +661,7 @@ class Validator:
 
             if out.owner is None:
                 if isinstance(out, tensor.TensorConstant):
-                    if hasattr(out, "fgraph") or getattr(out, "cached", False):
-                        # If out have an fgraph, we aren't sure if it
-                        # is from the inner graph or outer graph, so
-                        # clone it.
-                        # As it will be used as is in an FunctionGraph
-                        # (won't be cloned later), it can't be a
-                        # cached variable
-                        cloned_out = out.clone()
-                        self.valid.add(cloned_out)
-                        self.invalid.add(out)
-                        self.valid_equivalent[out] = cloned_out
-                    else:
-                        self.valid.add(out)
+                    self.valid.add(out)
                     continue
                 else:
                     # This is an input node and it has not been
@@ -1075,8 +1038,9 @@ class scan_args:
             if k in info:
                 self.other_info[k] = info[k]
 
-    inner_inputs = property(
-        lambda self: (
+    @property
+    def inner_inputs(self):
+        return (
             self.inner_in_seqs
             + sum(self.inner_in_mit_mot, [])
             + sum(self.inner_in_mit_sot, [])
@@ -1084,10 +1048,10 @@ class scan_args:
             + self.inner_in_shared
             + self.inner_in_non_seqs
         )
-    )
 
-    outer_inputs = property(
-        lambda self: (
+    @property
+    def outer_inputs(self):
+        return (
             [self.n_steps]
             + self.outer_in_seqs
             + self.outer_in_mit_mot
@@ -1097,10 +1061,10 @@ class scan_args:
             + self.outer_in_nit_sot
             + self.outer_in_non_seqs
         )
-    )
 
-    inner_outputs = property(
-        lambda self: (
+    @property
+    def inner_outputs(self):
+        return (
             sum(self.inner_out_mit_mot, [])
             + self.inner_out_mit_sot
             + self.inner_out_sit_sot
@@ -1108,20 +1072,20 @@ class scan_args:
             + self.inner_out_shared
             + self.cond
         )
-    )
 
-    outer_outputs = property(
-        lambda self: (
+    @property
+    def outer_outputs(self):
+        return (
             self.outer_out_mit_mot
             + self.outer_out_mit_sot
             + self.outer_out_sit_sot
             + self.outer_out_nit_sot
             + self.outer_out_shared
         )
-    )
 
-    info = property(
-        lambda self: OrderedDict(
+    @property
+    def info(self):
+        return OrderedDict(
             n_seqs=len(self.outer_in_seqs),
             n_mit_mot=len(self.outer_in_mit_mot),
             n_mit_sot=len(self.outer_in_mit_sot),
@@ -1137,7 +1101,6 @@ class scan_args:
             mit_mot_out_slices=self.mit_mot_out_slices,
             **self.other_info,
         )
-    )
 
     def __copy__(self):
         res = object.__new__(type(self))
