@@ -95,9 +95,7 @@ class SearchsortedOp(Op):
         if side == "left" or side == "right":
             self.side = side
         else:
-            raise ValueError(
-                "'%(side)s' is an invalid value for keyword 'side'" % locals()
-            )
+            raise ValueError(f"'{side}' is an invalid value for keyword 'side'")
 
     def get_params(self, node):
         return self.side
@@ -122,7 +120,7 @@ class SearchsortedOp(Op):
                 raise TypeError("sorter must be an integer vector", sorter.type)
             return theano.Apply(self, [x, v, sorter], [out_type()])
 
-    def infer_shape(self, node, shapes):
+    def infer_shape(self, fgraph, node, shapes):
         return [shapes[1]]
 
     def perform(self, node, inputs, output_storage, params):
@@ -139,12 +137,9 @@ class SearchsortedOp(Op):
         )
 
     def c_support_code_struct(self, node, name):
-        return (
-            """
-            int right_%(name)s;
+        return f"""
+            int right_{name};
         """
-            % locals()
-        )
 
     def c_init_code_struct(self, node, name, sub):
         side = sub["params"]
@@ -274,7 +269,7 @@ class CumOp(Op):
 
     def __init__(self, axis=None, mode="add"):
         if mode not in ("add", "mul"):
-            raise ValueError('{}: Unknown mode "{}"'.format(type(self).__name__, mode))
+            raise ValueError(f'{type(self).__name__}: Unknown mode "{mode}"')
         self.axis = axis
         self.mode = mode
 
@@ -287,7 +282,7 @@ class CumOp(Op):
         if self.axis is None:
             out_type = theano.tensor.vector(dtype=x.dtype)  # Flatten
         elif self.axis >= x.ndim or self.axis < -x.ndim:
-            raise ValueError("axis(={}) out of bounds".format(self.axis))
+            raise ValueError(f"axis(={self.axis}) out of bounds")
 
         return theano.Apply(self, [x], [out_type])
 
@@ -311,8 +306,7 @@ class CumOp(Op):
                 return [cumsum((fx * gi)[::-1])[::-1].reshape(x.shape) / x]
             else:
                 raise NotImplementedError(
-                    '%s: unknown gradient for mode "%s"'
-                    % (type(self).__name__, self.mode)
+                    f'{type(self).__name__}: unknown gradient for mode "{self.mode}"'
                 )
 
         reverse_slicing = [slice(None, None, None)] * gi.ndim
@@ -327,12 +321,10 @@ class CumOp(Op):
             return [cumsum((fx * gi)[reverse_slicing], self.axis)[reverse_slicing] / x]
         else:
             raise NotImplementedError(
-                '{}: unknown gradient for mode "{}"'.format(
-                    type(self).__name__, self.mode
-                )
+                f'{type(self).__name__}: unknown gradient for mode "{self.mode}"'
             )
 
-    def infer_shape(self, node, shapes):
+    def infer_shape(self, fgraph, node, shapes):
         if self.axis is None:
             return [(basic.prod(shapes[0]),)]  # Flatten
 
@@ -393,7 +385,7 @@ class CumOp(Op):
         return (8,)
 
     def __str__(self):
-        return "{}{{{}, {}}}".format(self.__class__.__name__, self.axis, self.mode)
+        return f"{self.__class__.__name__}{{{self.axis}, {self.mode}}}"
 
 
 def cumsum(x, axis=None):
@@ -499,7 +491,7 @@ class DiffOp(Op):
             z = _grad_helper(z)
         return [z]
 
-    def infer_shape(self, node, ins_shapes):
+    def infer_shape(self, fgraph, node, ins_shapes):
         i0_shapes = ins_shapes[0]
         out_shape = list(i0_shapes)
         out_shape[self.axis] = out_shape[self.axis] - self.n
@@ -732,7 +724,7 @@ class RepeatOp(Op):
         else:
             raise ValueError()
 
-    def infer_shape(self, node, ins_shapes):
+    def infer_shape(self, fgraph, node, ins_shapes):
         i0_shapes = ins_shapes[0]
         repeats = node.inputs[1]
         out_shape = list(i0_shapes)
@@ -840,10 +832,10 @@ class Bartlett(Op):
     def make_node(self, M):
         M = basic.as_tensor_variable(M)
         if M.ndim != 0:
-            raise TypeError("%s only works on scalar input" % self.__class__.__name__)
+            raise TypeError(f"{self.__class__.__name__} only works on scalar input")
         elif M.dtype not in theano.tensor.integer_dtypes:
             # dtype is a theano attribute here
-            raise TypeError("%s only works on integer input" % self.__class__.__name__)
+            raise TypeError(f"{self.__class__.__name__} only works on integer input")
         return Apply(self, [M], [basic.dvector()])
 
     def perform(self, node, inputs, out_):
@@ -851,7 +843,7 @@ class Bartlett(Op):
         (out,) = out_
         out[0] = np.bartlett(M)
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         temp = node.inputs[0]
         M = basic.switch(basic.lt(temp, 0), basic.cast(0, temp.dtype), temp)
         return [[M]]
@@ -895,7 +887,7 @@ class FillDiagonal(Op):
     # See function fill_diagonal for docstring
     __props__ = ()
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         return [in_shapes[0]]
 
     def make_node(self, a, val):
@@ -908,7 +900,7 @@ class FillDiagonal(Op):
             )
         elif val.ndim != 0:
             raise TypeError(
-                "%s: second parameter must be a scalar" % self.__class__.__name__
+                f"{self.__class__.__name__}: second parameter must be a scalar"
             )
         val = basic.cast(val, dtype=upcast(a.dtype, val.dtype))
         if val.dtype != a.dtype:
@@ -997,7 +989,7 @@ class FillDiagonalOffset(Op):
     # See function fill_diagonal_offset for docstring
     __props__ = ()
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         return [in_shapes[0]]
 
     def make_node(self, a, val, offset):
@@ -1011,11 +1003,11 @@ class FillDiagonalOffset(Op):
             )
         elif val.ndim != 0:
             raise TypeError(
-                "%s: second parameter must be a scalar" % self.__class__.__name__
+                f"{self.__class__.__name__}: second parameter must be a scalar"
             )
         elif offset.ndim != 0:
             raise TypeError(
-                "%s: third parameter must be a scalar" % self.__class__.__name__
+                f"{self.__class__.__name__}: third parameter must be a scalar"
             )
         val = basic.cast(val, dtype=upcast(a.dtype, val.dtype))
         if val.dtype != a.dtype:
@@ -1025,9 +1017,8 @@ class FillDiagonalOffset(Op):
             )
         elif offset.dtype not in theano.tensor.integer_dtypes:
             raise TypeError(
-                "%s: type of third parameter must be as integer"
+                f"{self.__class__.__name__}: type of third parameter must be as integer"
                 " use theano.tensor.cast( input, 'int32/int64')"
-                % self.__class__.__name__
             )
 
         return Apply(self, [a, val, offset], [a.type()])
@@ -1201,8 +1192,7 @@ class Unique(Op):
             raise RuntimeError(
                 "Numpy version = "
                 + np.__version__
-                + ". Option 'axis={}' works starting"
-                " from version 1.13.0.".format(axis)
+                + f". Option 'axis={axis}' works starting from version 1.13.0."
             )
 
     def make_node(self, x):
@@ -1255,8 +1245,8 @@ class Unique(Op):
             for i in range(len(outs)):
                 z[i][0] = outs[i]
 
-    def infer_shape(self, node, i0_shapes):
-        ret = node.fgraph.shape_feature.default_infer_shape(node, i0_shapes)
+    def infer_shape(self, fgraph, node, i0_shapes):
+        ret = fgraph.shape_feature.default_infer_shape(fgraph, node, i0_shapes)
         if self.axis is not None:
             self_axis = self.axis
             ndim = len(i0_shapes[0])
@@ -1264,14 +1254,10 @@ class Unique(Op):
                 self_axis += ndim
             if self_axis < 0 or self_axis >= ndim:
                 raise RuntimeError(
-                    "Unique axis `{}` is outside of input ndim = "
-                    "{}.".format(self.axis, ndim)
+                    f"Unique axis `{self.axis}` is outside of input ndim = {ndim}."
                 )
             ret[0] = tuple(
-                [
-                    node.fgraph.shape_feature.shape_ir(i, node.outputs[0])
-                    for i in range(ndim)
-                ]
+                [fgraph.shape_feature.shape_ir(i, node.outputs[0]) for i in range(ndim)]
             )
         if self.return_inverse:
             if self.axis is None:
@@ -1306,12 +1292,10 @@ class UnravelIndex(Op):
 
         if indices.dtype not in basic.int_dtypes:
             raise TypeError(
-                "'%s' object cannot be interpreted as an index" % str(indices.dtype)
+                f"'{indices.dtype}' object cannot be interpreted as an index"
             )
         if dims.dtype not in basic.int_dtypes:
-            raise TypeError(
-                "'%s' object cannot be interpreted as an index" % str(dims.dtype)
-            )
+            raise TypeError(f"'{dims.dtype}' object cannot be interpreted as an index")
         if dims.ndim != 1:
             raise TypeError("dims must be a 1D array")
 
@@ -1324,7 +1308,7 @@ class UnravelIndex(Op):
             ],
         )
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [input_shapes[0]] * len(node.outputs)
 
     def perform(self, node, inp, out):
@@ -1389,13 +1373,9 @@ class RavelMultiIndex(Op):
 
         for i in multi_index:
             if i.dtype not in basic.int_dtypes:
-                raise TypeError(
-                    "'%s' object cannot be interpreted as an index" % str(i.dtype)
-                )
+                raise TypeError(f"'{i.dtype}' object cannot be interpreted as an index")
         if dims.dtype not in basic.int_dtypes:
-            raise TypeError(
-                "'%s' object cannot be interpreted as an index" % str(dims.dtype)
-            )
+            raise TypeError(f"'{dims.dtype}' object cannot be interpreted as an index")
         if dims.ndim != 1:
             raise TypeError("dims must be a 1D array")
 
@@ -1409,7 +1389,7 @@ class RavelMultiIndex(Op):
             ],
         )
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [input_shapes[0]]
 
     def perform(self, node, inp, out):
@@ -1601,7 +1581,7 @@ class BroadcastTo(Op):
             grad_undefined(self, i, shp) for i, shp in enumerate(shape, 1)
         ]
 
-    def infer_shape(self, node, ins_shapes):
+    def infer_shape(self, fgraph, node, ins_shapes):
         return [node.inputs[1:]]
 
 
