@@ -125,13 +125,13 @@ class BaseCorrMM(gof.OpenMPOp):
         self.filter_dilation = tuple(filter_dilation)
         self.unshared = unshared
 
-        if not theano.config.blas.ldflags:
+        if not theano.config.blas__ldflags:
             # Theano will use a NumPy C implementation of [sd]gemm_ instead.
             self.blas_type = ""
         else:
-            if "openblas" in theano.config.blas.ldflags:
+            if "openblas" in theano.config.blas__ldflags:
                 self.blas_type = "openblas"
-            elif "mkl" in theano.config.blas.ldflags:
+            elif "mkl" in theano.config.blas__ldflags:
                 self.blas_type = "mkl"
             else:
                 self.blas_type = ""
@@ -311,7 +311,7 @@ class BaseCorrMM(gof.OpenMPOp):
         # of bottom and weights from top, so we require them to be given.
         # Similarly, when border_mode="half", we cannot infer the weight size.
         if height:
-            height = "(*(npy_int64 *)(PyArray_DATA(%s)))" % height
+            height = f"(*(npy_int64 *)(PyArray_DATA({height})))"
         else:
             if ((self.direction != 0) and (self.dH != 1)) or (
                 (self.direction == 1) and (self.padH_l == -1 or self.padH_r == -1)
@@ -321,7 +321,7 @@ class BaseCorrMM(gof.OpenMPOp):
                 )
             height = "-1"
         if width:
-            width = "(*(npy_int64 *)(PyArray_DATA(%s)))" % width
+            width = f"(*(npy_int64 *)(PyArray_DATA({width})))"
         else:
             if ((self.direction != 0) and (self.dW != 1)) or (
                 (self.direction == 1) and (self.padW_l == -1 or self.padW_r == -1)
@@ -697,7 +697,7 @@ class CorrMM(BaseCorrMM):
         dtype = img.type.dtype
         return Apply(self, [img, kern], [TensorType(dtype, broadcastable)()])
 
-    def infer_shape(self, node, input_shape):
+    def infer_shape(self, fgraph, node, input_shape):
         imshp = input_shape[0]
         kshp = input_shape[1]
         res = get_conv_output_shape(
@@ -786,7 +786,7 @@ class CorrMM_gradWeights(BaseCorrMM):
             self, [img, topgrad] + height_width, [TensorType(dtype, broadcastable)()]
         )
 
-    def infer_shape(self, node, input_shape):
+    def infer_shape(self, fgraph, node, input_shape):
         if self.border_mode == "half":
             padH_l = padH_r = padW_l = padW_r = -1
         elif self.border_mode == "full":
@@ -914,7 +914,7 @@ class CorrMM_gradInputs(BaseCorrMM):
             self, [kern, topgrad] + height_width, [TensorType(dtype, broadcastable)()]
         )
 
-    def infer_shape(self, node, input_shape):
+    def infer_shape(self, fgraph, node, input_shape):
         if self.border_mode == "half":
             padH_l = padH_r = padW_l = padW_r = -1
         elif self.border_mode == "full":
