@@ -111,13 +111,13 @@ class BaseCorr3dMM(gof.OpenMPOp):
             raise ValueError("Number of groups should be greater than 0")
         self.num_groups = num_groups
 
-        if not theano.config.blas.ldflags:
+        if not theano.config.blas__ldflags:
             # Theano will use a NumPy C implementation of [sd]gemm_ instead.
             self.blas_type = ""
         else:
-            if "openblas" in theano.config.blas.ldflags:
+            if "openblas" in theano.config.blas__ldflags:
                 self.blas_type = "openblas"
-            elif "mkl" in theano.config.blas.ldflags:
+            elif "mkl" in theano.config.blas__ldflags:
                 self.blas_type = "mkl"
             else:
                 self.blas_type = ""
@@ -300,7 +300,7 @@ class BaseCorr3dMM(gof.OpenMPOp):
         # of bottom and weights from top, so we require them to be given.
         # Similarly, when border_mode="half", we cannot infer the weight size.
         if height:
-            height = "(*(npy_int64 *)(PyArray_DATA(%s)))" % height
+            height = f"(*(npy_int64 *)(PyArray_DATA({height})))"
         else:
             if ((self.direction != 0) and (self.dH != 1)) or (
                 (self.direction == 1) and (self.padH == -1)
@@ -310,7 +310,7 @@ class BaseCorr3dMM(gof.OpenMPOp):
                 )
             height = "-1"
         if width:
-            width = "(*(npy_int64 *)(PyArray_DATA(%s)))" % width
+            width = f"(*(npy_int64 *)(PyArray_DATA({width})))"
         else:
             if ((self.direction != 0) and (self.dW != 1)) or (
                 (self.direction == 1) and (self.padW == -1)
@@ -320,7 +320,7 @@ class BaseCorr3dMM(gof.OpenMPOp):
                 )
             width = "-1"
         if depth:
-            depth = "(*(npy_int64 *)(PyArray_DATA(%s)))" % depth
+            depth = f"(*(npy_int64 *)(PyArray_DATA({depth})))"
         else:
             if ((self.direction != 0) and (self.dD != 1)) or (
                 (self.direction == 1) and (self.padD == -1)
@@ -637,7 +637,7 @@ class Corr3dMM(BaseCorr3dMM):
         dtype = img.type.dtype
         return Apply(self, [img, kern], [TensorType(dtype, broadcastable)()])
 
-    def infer_shape(self, node, input_shape):
+    def infer_shape(self, fgraph, node, input_shape):
         imshp = input_shape[0]
         kshp = input_shape[1]
         res = get_conv_output_shape(
@@ -718,7 +718,7 @@ class Corr3dMMGradWeights(BaseCorr3dMM):
             [TensorType(dtype, broadcastable)()],
         )
 
-    def infer_shape(self, node, input_shape):
+    def infer_shape(self, fgraph, node, input_shape):
         if self.border_mode == "half":
             padH = padW = padD = -1
         elif self.border_mode == "full":
@@ -841,7 +841,7 @@ class Corr3dMMGradInputs(BaseCorr3dMM):
             [TensorType(dtype, broadcastable)()],
         )
 
-    def infer_shape(self, node, input_shape):
+    def infer_shape(self, fgraph, node, input_shape):
         if self.border_mode == "half":
             padH = padW = padD = -1
         elif self.border_mode == "full":
