@@ -1,9 +1,8 @@
 """Define random number Type (`RandomStateType`) and Op (`RandomFunction`)."""
 
-
-import sys
 from copy import copy
 from functools import reduce
+from warnings import warn
 
 import numpy as np
 
@@ -200,10 +199,8 @@ class RandomFunction(gof.Op):
         assert shape.type.ndim == 1
         assert (shape.type.dtype == "int64") or (shape.type.dtype == "int32")
         if not isinstance(r.type, RandomStateType):
-            print(
-                "WARNING: RandomState instances should be in RandomStateType",
-                file=sys.stderr,
-            )
+            warn("RandomState instances should be in RandomStateType")
+
         # the following doesn't work because we want to ignore the
         # broadcastable flags in shape.type
         # assert shape.type == tensor.lvector
@@ -214,7 +211,7 @@ class RandomFunction(gof.Op):
 
         return gof.Apply(self, [r, shape] + args, [r.type(), self.outtype()])
 
-    def infer_shape(self, node, i_shapes):
+    def infer_shape(self, fgraph, node, i_shapes):
         r, shp = node.inputs[0:2]
 
         # if shp is a constant array of len 0, then it means 'automatic shape'
@@ -250,9 +247,8 @@ class RandomFunction(gof.Op):
 
         if shape is not None and self.outtype.ndim != len(shape) + self.ndim_added:
             raise ValueError(
-                "Shape mismatch: self.outtype.ndim (%i) !="
-                " len(shape) (%i) + self.ndim_added (%i)"
-                % (self.outtype.ndim, len(shape), self.ndim_added)
+                f"Shape mismatch: self.outtype.ndim ({int(self.outtype.ndim)}) !="
+                f" len(shape) ({len(shape)}) + self.ndim_added ({self.ndim_added})"
             )
         if not self.inplace:
             r = copy(r)
@@ -339,8 +335,7 @@ def _infer_ndim_bcast(ndim, shape, *args):
             if shape_ndim != ndim:
                 raise ValueError(
                     "ndim should be equal to len(shape), but\n",
-                    "ndim = %s, len(shape) = %s, shape = %s"
-                    % (ndim, shape_ndim, shape),
+                    f"ndim = {ndim}, len(shape) = {shape_ndim}, shape = {shape}",
                 )
 
         bcast = []
@@ -400,7 +395,7 @@ def _infer_ndim_bcast(ndim, shape, *args):
         v_shape = tensor.as_tensor_variable(shape)
         if v_shape.ndim != 1:
             raise TypeError(
-                "shape must be a vector or list of scalar, got '%s'" % v_shape
+                f"shape must be a vector or list of scalar, got '{v_shape}'"
             )
 
         if ndim is None:
@@ -408,7 +403,7 @@ def _infer_ndim_bcast(ndim, shape, *args):
         bcast = [False] * ndim
 
     if v_shape.ndim != 1:
-        raise TypeError("shape must be a vector or list of scalar, got '%s'" % v_shape)
+        raise TypeError(f"shape must be a vector or list of scalar, got '{v_shape}'")
 
     if v_shape.dtype not in theano.tensor.integer_dtypes:
         raise TypeError("shape must be an integer vector or list", v_shape.dtype)
@@ -534,9 +529,9 @@ def binomial(random_state, size=None, n=1, p=0.5, ndim=None, dtype="int64", prob
     """
     if prob is not None:
         p = prob
-        print(
-            "DEPRECATION WARNING: the parameter prob to the binomal fct have been renamed to p to have the same name as np.",
-            file=sys.stderr,
+        warn(
+            "The parameter prob to the binomal fct have been renamed to p to have the same name as np.",
+            category=DeprecationWarning,
         )
     n = tensor.as_tensor_variable(n)
     p = tensor.as_tensor_variable(p)
@@ -932,7 +927,7 @@ def multinomial(random_state, size=None, n=1, pvals=None, ndim=None, dtype="int6
 
 
 @gof.local_optimizer([RandomFunction])
-def random_make_inplace(node):
+def random_make_inplace(fgraph, node):
     op = node.op
     if isinstance(op, RandomFunction) and not op.inplace:
         # Read op_fn from op.state, not from op.fn, since op.fn
@@ -966,9 +961,9 @@ class RandomStreamsBase:
         """
         if prob is not None:
             p = prob
-            print(
-                "DEPRECATION WARNING: the parameter prob to the binomal fct have been renamed to p to have the same name as numpy.",
-                file=sys.stderr,
+            warn(
+                "The parameter prob to the binomal fct have been renamed to p to have the same name as numpy.",
+                category=DeprecationWarning,
             )
         return self.gen(binomial, size, n, p, ndim=ndim, dtype=dtype)
 
