@@ -112,11 +112,11 @@ def conv2d(
 
     # flatten to 3D tensor if convolving with single filter or single image
     if input.ndim == 2 and filters.ndim == 2:
-        if theano.config.warn.signal_conv2d_interface:
+        if theano.config.warn__signal_conv2d_interface:
             warnings.warn(
                 "theano.tensor.signal.conv2d() now outputs a 2d tensor when both"
                 " inputs are 2d. To disable this warning, set the Theano flag"
-                " warn.signal_conv2d_interface to False",
+                " warn__signal_conv2d_interface to False",
                 stacklevel=3,
             )
 
